@@ -38,7 +38,7 @@
 #include <Rmath.h>
 #endif
 
-#if defined (BUILD_WIN32)
+#if defined (BUILD_WIN32) || defined (BUILD_WIN64)
 #include <windows.h>
 #endif
 
@@ -71,7 +71,7 @@ BOOL_T match_string (char *x, char *c, char stop)
 
 FILE *a68g_fopen (char *fn, char *mode, char *new_fn)
 {
-#if defined (BUILD_WIN32) || !defined (HAVE_DIRENT_H)
+#if defined (BUILD_WIN32) || defined (BUILD_WIN64) || !defined (HAVE_DIRENT_H)
   ASSERT (a68g_bufprt (new_fn, SNPRINTF_SIZE, "%s", fn) >= 0);
   return fopen (new_fn, mode);
 #else
@@ -248,7 +248,7 @@ void install_signal_handlers (void)
 
 REAL_T wall_seconds (void)
 {
-#if defined (BUILD_LINUX)
+#if defined (HAVE_RTLIB)
   struct timespec ts;
   clock_gettime (CLOCK_MONOTONIC, &ts);
   return ts.tv_sec + ts.tv_nsec * 1e-9; 
@@ -270,7 +270,7 @@ REAL_T seconds (void)
 
 int a68g_usleep (unsigned delay)
 {
-#if defined (BUILD_WIN32)
+#if defined (BUILD_WIN32) || defined (BUILD_WIN64)
   errno = ENOSYS; // Function not implemented.
   return -1; 
 #else
@@ -385,7 +385,7 @@ void stack_backtrace (void)
 #define DEPTH 16
   void *array[DEPTH];
   WRITE_TXT (2, "\n++++ Top of call stack:");
-  int size = backtrace (array, DEPTH);
+  size_t size = backtrace (array, DEPTH);
   if (size > 0) {
     WRITE_TXT (2, "\n");
     backtrace_symbols_fd (array, size, 2);
