@@ -117,20 +117,24 @@ void pretty_diag (FILE_T f, char *p)
 
 void abend (char *reason, char *info, char *file, int line)
 {
-  ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "%s: exiting: %s: %d: %s", A68G (a68g_cmd_name), file, line, reason) >= 0);
+#if defined (BUILD_WIN32) || defined (BUILD_WIN64)
+  printf_s ("%s: abend: %s.\n", A68G (a68g_cmd_name), reason);
+  exit (EXIT_FAILURE);
+#else
+  ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "%s: exiting: %s (%s: %d", A68G (a68g_cmd_name), reason, basename (file), line) >= 0);
   if (info != NO_TEXT) {
     a68g_bufcat (A68G (output_line), ", ", BUFFER_SIZE);
     a68g_bufcat (A68G (output_line), info, BUFFER_SIZE);
   }
   if (errno != 0) {
-    a68g_bufcat (A68G (output_line), " (", BUFFER_SIZE);
+    a68g_bufcat (A68G (output_line), ", ", BUFFER_SIZE);
     a68g_bufcat (A68G (output_line), error_specification (), BUFFER_SIZE);
-    a68g_bufcat (A68G (output_line), ")", BUFFER_SIZE);
   }
-  a68g_bufcat (A68G (output_line), "\n", BUFFER_SIZE);
+  a68g_bufcat (A68G (output_line), ")\n", BUFFER_SIZE);
   io_close_tty_line ();
   pretty_diag (A68G_STDERR, A68G (output_line));
   a68g_exit (EXIT_FAILURE);
+#endif
 }
 
 //! @brief Position in line .
@@ -183,11 +187,13 @@ void write_source_line (FILE_T f, LINE_T * p, NODE_T * nwhere, int mask)
 {
   int line_width = (f == A68G_STDERR || f == A68G_STDOUT ? A68G (term_width) : MAX_TERM_WIDTH);
 // Terminate properly.
-  if ((STRING (p))[strlen (STRING (p)) - 1] == NEWLINE_CHAR) {
-    (STRING (p))[strlen (STRING (p)) - 1] = NULL_CHAR;
-    if ((STRING (p))[strlen (STRING (p)) - 1] == CR_CHAR) {
-      (STRING (p))[strlen (STRING (p)) - 1] = NULL_CHAR;
-    }
+  size_t len = strlen (STRING (p));
+  if (len > 0 && (STRING (p))[len - 1] == NEWLINE_CHAR) {
+    (STRING (p))[len - 1] = NULL_CHAR;
+  }
+  len = strlen (STRING (p));
+  if (len > 0 && (STRING (p))[len - 1] == CR_CHAR) {
+    (STRING (p))[len - 1] = NULL_CHAR;
   }
 // Print line number.
   if (f == A68G_STDERR || f == A68G_STDOUT) {
@@ -208,7 +214,7 @@ void write_source_line (FILE_T f, LINE_T * p, NODE_T * nwhere, int mask)
   int continuations = 0;
   BOOL_T line_ended = A68G_FALSE;
   while (!line_ended) {
-    int len = 0;
+    len = 0;
     char *new_pos = NO_TEXT;
     if (c[0] == NULL_CHAR) {
       a68g_bufcpy (A68G (output_line), "", BUFFER_SIZE);
@@ -237,7 +243,7 @@ void write_source_line (FILE_T f, LINE_T * p, NODE_T * nwhere, int mask)
         new_pos = &c[1];
       } else if (unprintable (c[0])) {
         a68g_bufcpy (A68G (output_line), ctrl_char ((int) c[0]), BUFFER_SIZE);
-        len = (int) strlen (A68G (output_line));
+        len = strlen (A68G (output_line));
         new_pos = &c[1];
         col++;
       } else {
@@ -293,7 +299,7 @@ void write_source_line (FILE_T f, LINE_T * p, NODE_T * nwhere, int mask)
             }
           } else {
             if (unprintable (c1[0])) {
-              int n = (int) strlen (ctrl_char (c1[0]));
+              size_t n = strlen (ctrl_char (c1[0]));
               col_2 += 1;
               a68g_bufcpy (A68G (output_line), "", BUFFER_SIZE);
               while (n--) {
@@ -402,7 +408,7 @@ void scan_error_info (LINE_T * u, char *v, char *txt, char *info)
   if (info != NO_TEXT) {
     size_t len = strlen (txt) + 3;
     char *txti = a68g_alloc(len, __FILE__, __LINE__);
-    ABEND (txti == NO_TEXT, ERROR_OUT_OF_CORE, __func__);
+    ABEND (txti == NO_TEXT, ERROR_MEMORY_FULL, __func__);
     a68g_bufcpy (txti, txt, len);
     a68g_bufcat (txti, " Z", len);
     if (errno != 0) {
@@ -486,7 +492,7 @@ void write_diagnostic (int sev, char *b)
 void add_diagnostic (LINE_T * line, char *pos, NODE_T * p, int sev, char *b)
 {
 // Add diagnostic and choose GNU style or non-GNU style.
-  DIAGNOSTIC_T *msg = (DIAGNOSTIC_T *) get_heap_space ((size_t) SIZE_ALIGNED (DIAGNOSTIC_T));
+  DIAGNOSTIC_T *msg = (DIAGNOSTIC_T *) get_heap_space (SIZE_ALIGNED (DIAGNOSTIC_T));
   DIAGNOSTIC_T **ref_msg;
   BUFFER a, nst;
   char st[SMALL_BUFFER_SIZE];
@@ -579,11 +585,9 @@ void diagnostic (STATUS_MASK_T sev, NODE_T * p, char *loc_str, ...)
   va_list args;
   MOID_T *moid = NO_MOID;
   char *t = loc_str, b[BUFFER_SIZE];
-  BOOL_T force, compose = A68G_TRUE, issue = A68G_TRUE;
+  BOOL_T compose = A68G_TRUE, issue = A68G_TRUE;
   va_start (args, loc_str);
   b[0] = NULL_CHAR;
-  force = (BOOL_T) ((sev & A68G_FORCE_DIAGNOSTICS) != 0);
-  sev &= ~A68G_FORCE_DIAGNOSTICS;
 // Node or line?
   LINE_T *line = NO_LINE;
   char *pos = NO_TEXT;
@@ -592,15 +596,15 @@ void diagnostic (STATUS_MASK_T sev, NODE_T * p, char *loc_str, ...)
     pos = va_arg (args, char *);
   }
 // No warnings or notices?
-  if (!force && sev == A68G_NOTICE && OPTION_NO_NOTICES (&A68G_JOB)) {
+  if (sev == A68G_NOTICE && OPTION_NO_NOTICES (&A68G_JOB)) {
     va_end (args);
     return;
   }
-  if (!force && sev == A68G_WARNING && OPTION_NO_WARNINGS (&A68G_JOB)) {
+  if (sev == A68G_WARNING && OPTION_NO_WARNINGS (&A68G_JOB)) {
     va_end (args);
     return;
   }
-  if (!force && sev == A68G_MATH_WARNING && OPTION_NO_WARNINGS (&A68G_JOB)) {
+  if (sev == A68G_MATH_WARNING && OPTION_NO_WARNINGS (&A68G_JOB)) {
     va_end (args);
     return;
   }
@@ -777,9 +781,10 @@ void diagnostic (STATUS_MASK_T sev, NODE_T * p, char *loc_str, ...)
             if (p != NO_NODE && NSYMBOL (p) != NO_TEXT) {
               char *txt = NSYMBOL (p);
               char *sym = NCHAR_IN_LINE (p);
-              int n = 0, size = (int) strlen (txt);
+              int n = 0;
+              size_t size = strlen (txt);
               a68g_bufcat (b, "\"", BUFFER_SIZE);
-              if (txt[0] != sym[0] || (int) strlen (sym) < size) {
+              if (txt[0] != sym[0] || strlen (sym) < size) {
                 a68g_bufcat (b, txt, BUFFER_SIZE);
               } else {
                 while (n < size) {
