@@ -67,20 +67,19 @@ char *read_string_from_tty (char *prompt)
 {
 #if defined (HAVE_READLINE)
   char *line = readline (prompt);
-  if (line != NO_TEXT && (int) strlen (line) > 0) {
+  if (line != NO_TEXT && strlen (line) > 0) {
     add_history (line);
   }
   a68g_bufcpy (A68G (input_line), line, BUFFER_SIZE);
-  A68G (chars_in_stdout) = (int) strlen (A68G (input_line));
+  A68G (chars_in_stdout) = strlen (A68G (input_line));
   a68g_free (line);
   return A68G (input_line);
 #else
-  int ch, k = 0, n;
   if (prompt != NO_TEXT) {
     io_close_tty_line ();
     io_write_string (A68G_STDOUT, prompt);
   }
-  ch = get_stdin_char ();
+  int ch = get_stdin_char (), k= 0;
   while (ch != NEWLINE_CHAR && k < BUFFER_SIZE - 1) {
     if (ch == EOF_CHAR) {
       A68G (input_line)[0] = EOF_CHAR;
@@ -93,7 +92,7 @@ char *read_string_from_tty (char *prompt)
     }
   }
   A68G (input_line)[k] = NULL_CHAR;
-  n = (int) strlen (A68G (input_line));
+  size_t n = strlen (A68G (input_line));
   A68G (chars_in_stdout) = (ch == NEWLINE_CHAR ? 0 : (n > 0 ? n : 1));
   return A68G (input_line);
 #endif
@@ -154,6 +153,8 @@ ssize_t io_read (FILE_T fd, void *buf, size_t n)
   while (to_do > 0) {
 #if defined (BUILD_WIN32)
     int bytes_read;
+#elif defined (BUILD_WIN64)
+    ssize_t bytes_read;
 #else
     ssize_t bytes_read;
 #endif
@@ -218,6 +219,8 @@ ssize_t io_read_conv (FILE_T fd, void *buf, size_t n)
   while (to_do > 0) {
 #if defined (BUILD_WIN32)
     int bytes_read;
+#elif defined (BUILD_WIN64)
+    ssize_t bytes_read;
 #else
     ssize_t bytes_read;
 #endif
