@@ -482,8 +482,8 @@ void tree_listing (FILE_T f, NODE_T * q, int x, LINE_T * l, int *ld, BOOL_T comm
               WRITE (f, A68G (output_line));
             }
           }
-          if (GINFO (p) != NO_GINFO && propagator_name ((const PROP_PROC *) UNIT (&GPROP (p))) != NO_TEXT) {
-            ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, ", %s", propagator_name ((const PROP_PROC *) UNIT (&GPROP (p)))) >= 0);
+          if (GINFO (p) != NO_GINFO && propagator_name ((PROP_PROC *) UNIT (&GPROP (p))) != NO_TEXT) {
+            ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, ", %s", propagator_name ((PROP_PROC *) UNIT (&GPROP (p)))) >= 0);
             WRITE (f, A68G (output_line));
           }
           if (GINFO (p) != NO_GINFO && COMPILE_NAME (GINFO (p)) != NO_TEXT) {
@@ -528,7 +528,7 @@ int leaves_to_print (NODE_T * p, LINE_T * l)
 
 void list_source_line (FILE_T f, LINE_T * line, BOOL_T tree)
 {
-  int k = (int) strlen (STRING (line)) - 1;
+  INT_T k = (INT_T) strlen (STRING (line)) - 1;
   if (NUMBER (line) <= 0) {
 // Mask the prelude and postlude.
     return;
