@@ -39,23 +39,72 @@
 //   [3] Command line options overrule [2].
 //   [4] Pragmat items overrule [3]. 
 
-//! @brief Set default core size.
+//! @brief Strip minus preceeding a string.
 
-void default_mem_sizes (int n)
+char *strip_sign (char *p)
 {
-#define SET_SIZE(m, n) {\
-  ABEND (OVER_2G (n), ERROR_OVER_2G, __func__);\
-  (m) = (n);\
+  char *q = p;
+  while (q[0] == '-' || q[0] == '+') {
+    q++;
+  }
+  if (strlen (q) > 0) {
+    return new_string (q, NO_TEXT);
+  } else {
+    return p;
+  }
 }
 
-  if (n < 0) {
-    n = 1;
+//! @brief Error handler for options.
+
+void option_error (LINE_T * l, char *option, char *info)
+{
+  if (option != NO_TEXT) {
+    ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "%s", strip_sign (option)) >= 0);
+    if (info != NO_TEXT) {
+      ASSERT (a68g_bufprt (A68G (edit_line), SNPRINTF_SIZE, "%s at option \"%s\"", info, A68G (output_line)) >= 0);
+    } else {
+      ASSERT (a68g_bufprt (A68G (edit_line), SNPRINTF_SIZE, "at option \"%s\"", A68G (output_line)) >= 0);
+    }
+  } else if (info != NO_TEXT) {
+    ASSERT (a68g_bufprt (A68G (edit_line), SNPRINTF_SIZE, "%s", info) >= 0);
+  } else {
+    ASSERT (a68g_bufprt (A68G (edit_line), SNPRINTF_SIZE, "at option") >= 0);
   }
-  SET_SIZE (A68G (frame_stack_size), 12 * n * MEGABYTE);
-  SET_SIZE (A68G (expr_stack_size), 4 * n * MEGABYTE);
-  SET_SIZE (A68G (heap_size), 32 * n * MEGABYTE);
-  SET_SIZE (A68G (handle_pool_size), 16 * n * MEGABYTE);
-  SET_SIZE (A68G (storage_overhead), MIN_MEM_SIZE);
+  scan_error (l, NO_TEXT, A68G (edit_line));
+}
+
+//! @brief Check overflow at integer multiplication.
+
+BOOL_T int_mul_overflow (UNSIGNED_T u, UNSIGNED_T v, UNSIGNED_T max_int)
+{
+  if (u == 0 || v == 0) {
+    return (A68G_FALSE);
+  } else {
+    return v > max_int / u;
+  }
+}
+
+//! @brief Set default core size.
+
+void default_mem_sizes (INT_T n, LINE_T *start_l, char *start_c)
+{
+  #define SET_SIZE(m, n) {\
+    if (int_mul_overflow (n, MEGABYTE, MAX_MEM_SIZE)) {\
+      option_error (start_l, start_c, ERROR_VALUE_TOO_LARGE);\
+      return;\
+    } else if ((n) * MEGABYTE + A68G (storage_overhead) > MAX_MEM_SIZE) {\
+      option_error (start_l, start_c, ERROR_VALUE_TOO_LARGE);\
+      return;\
+    } else {\
+      (m) = (n) * MEGABYTE + A68G (storage_overhead);\
+    }}
+
+  n = MAX (n, 1);
+  A68G (storage_overhead) = MEM_OVERHEAD;
+  SET_SIZE (A68G (frame_stack_size), 10 * n);
+  SET_SIZE (A68G (expr_stack_size), 5 * n);
+  SET_SIZE (A68G (heap_size), 65 * n);
+  SET_SIZE (A68G (handle_pool_size), 20 * n);
 #undef SET_SIZE
 }
 
@@ -71,8 +120,9 @@ void read_rc_options (void)
   if (f != NO_FILE) {
     while (!feof (f)) {
       if (fgets (A68G (input_line), BUFFER_SIZE, f) != NO_TEXT) {
-        if (A68G (input_line)[strlen (A68G (input_line)) - 1] == NEWLINE_CHAR) {
-          A68G (input_line)[strlen (A68G (input_line)) - 1] = NULL_CHAR;
+        size_t len = strlen (A68G (input_line));
+        if (len > 0 && A68G (input_line)[len - 1] == NEWLINE_CHAR) {
+          A68G (input_line)[len - 1] = NULL_CHAR;
         }
         isolate_options (A68G (input_line), NO_LINE);
       }
@@ -156,7 +206,7 @@ void default_options (MODULE_T * p)
   OPTION_CLOCK (p) = A68G_FALSE;
   OPTION_COMPILE_CHECK (p) = A68G_FALSE;
   OPTION_COMPILE (p) = A68G_FALSE;
-  OPTION_CONSERVATIVE_GC (p) = A68G_FALSE;
+  OPTION_CONSERVATIVE_GC (p) = A68G_GC_GO;
   OPTION_CROSS_REFERENCE (p) = A68G_FALSE;
   OPTION_DEBUG (p) = A68G_FALSE;
   OPTION_FOLD (p) = A68G_FALSE;
@@ -191,35 +241,12 @@ void default_options (MODULE_T * p)
   set_long_mp_digits (0);
 }
 
-//! @brief Error handler for options.
-
-void option_error (LINE_T * l, char *option, char *info)
-{
-  ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "%s", option) >= 0);
-  if (info != NO_TEXT) {
-    ASSERT (a68g_bufprt (A68G (edit_line), SNPRINTF_SIZE, "*error: %s option \"%s\"", info, A68G (output_line)) >= 0);
-  } else {
-    ASSERT (a68g_bufprt (A68G (edit_line), SNPRINTF_SIZE, "*error: in option \"%s\"", A68G (output_line)) >= 0);
-  }
-  scan_error (l, NO_TEXT, A68G (edit_line));
-}
-
-//! @brief Strip minus preceeding a string.
-
-char *strip_sign (char *p)
-{
-  while (p[0] == '-' || p[0] == '+') {
-    p++;
-  }
-  return new_string (p, NO_TEXT);
-}
-
 //! @brief Add an option to the list, to be processed later.
 
 void add_option_list (OPTION_LIST_T ** l, char *str, LINE_T * line)
 {
   if (*l == NO_OPTION_LIST) {
-    *l = (OPTION_LIST_T *) get_heap_space ((size_t) SIZE_ALIGNED (OPTION_LIST_T));
+    *l = (OPTION_LIST_T *) get_heap_space (SIZE_ALIGNED (OPTION_LIST_T));
     SCAN (*l) = SOURCE_SCAN (&A68G_JOB);
     STR (*l) = new_string (str, NO_TEXT);
     PROCESSED (*l) = A68G_FALSE;
@@ -245,7 +272,7 @@ void free_option_list (OPTION_LIST_T * l)
 
 void init_options (void)
 {
-  A68G (options) = (OPTIONS_T *) a68g_alloc ((size_t) SIZE_ALIGNED (OPTIONS_T), __func__, __LINE__);
+  A68G (options) = (OPTIONS_T *) a68g_alloc (SIZE_ALIGNED (OPTIONS_T), __func__, __LINE__);
   OPTION_LIST (&A68G_JOB) = NO_OPTION_LIST;
 }
 
@@ -263,11 +290,11 @@ static inline BOOL_T eq (char *p, char *q)
 
 //! @brief Process echoes gathered in the option list.
 
-void prune_echoes (OPTION_LIST_T * i)
+void prune_echoes (OPTION_LIST_T * ol)
 {
-  while (i != NO_OPTION_LIST) {
-    if (SCAN (i) == SOURCE_SCAN (&A68G_JOB)) {
-      char *p = strip_sign (STR (i));
+  while (ol != NO_OPTION_LIST) {
+    if (SCAN (ol) == SOURCE_SCAN (&A68G_JOB)) {
+      char *p = strip_sign (STR (ol));
 // ECHO echoes a string.
       if (eq (p, "ECHO")) {
         {
@@ -277,14 +304,14 @@ void prune_echoes (OPTION_LIST_T * i)
             ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "%s", &car[1]) >= 0);
             WRITE (A68G_STDOUT, A68G (output_line));
           } else {
-            FORWARD (i);
-            if (i != NO_OPTION_LIST) {
-              if (strcmp (STR (i), "=") == 0) {
-                FORWARD (i);
+            FORWARD (ol);
+            if (ol != NO_OPTION_LIST) {
+              if (strcmp (STR (ol), "=") == 0) {
+                FORWARD (ol);
               }
-              if (i != NO_OPTION_LIST) {
+              if (ol != NO_OPTION_LIST) {
                 io_close_tty_line ();
-                ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "%s", STR (i)) >= 0);
+                ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "%s", STR (ol)) >= 0);
                 WRITE (A68G_STDOUT, A68G (output_line));
               }
             }
@@ -293,15 +320,15 @@ void prune_echoes (OPTION_LIST_T * i)
       }
       a68g_free (p);
     }
-    if (i != NO_OPTION_LIST) {
-      FORWARD (i);
+    if (ol != NO_OPTION_LIST) {
+      FORWARD (ol);
     }
   }
 }
 
 //! @brief Translate integral option argument.
 
-int fetch_integral (char *p, OPTION_LIST_T ** i, BOOL_T * error)
+static UNSIGNED_T fetch_integral (char *p, OPTION_LIST_T ** i, BOOL_T * error, UNSIGNED_T max_int)
 {
   LINE_T *start_l = LINE (*i);
   char *start_c = STR (*i);
@@ -325,22 +352,29 @@ int fetch_integral (char *p, OPTION_LIST_T ** i, BOOL_T * error)
   }
 // Translate argument into integer.
   if (*error) {
-    option_error (start_l, start_c, "integer value required by");
+    option_error (start_l, start_c, ERROR_MISSING_STUFF);
     return 0;
   } else {
+    if (num[0] == '-') {
+      option_error (start_l, start_c, ERROR_INVALID_VALUE);
+      return 0;
+    }
     char *suffix;
     errno = 0;
-    INT_T k = (int) strtol (num, &suffix, 0); // Accept also octal and hex
-    INT_T mult = 1;
+    #if (A68G_LEVEL >= 3)
+      UNSIGNED_T mult = 1, value = (UNSIGNED_T) strtoul (num, &suffix, 0);
+    #else
+      UNSIGNED_T mult = 1, value = (UNSIGNED_T) strtoull (num, &suffix, 0);
+    #endif
     *error = (BOOL_T) (suffix == num);
     if (errno != 0 || *error) {
-      option_error (start_l, start_c, "conversion error in");
+      option_error (start_l, start_c, ERROR_INVALID_VALUE);
       *error = A68G_TRUE;
-    } else if (k < 0) {
-      option_error (start_l, start_c, "negative value in");
+    } else if (value < 0) {
+      option_error (start_l, start_c, ERROR_INVALID_VALUE);
       *error = A68G_TRUE;
     } else {
-// Accept suffix multipliers: 32k, 64M, 1G.
+// Accept suffix multipliers: 32k, 64M, 1G, (2T, 1P).
       if (suffix != NO_TEXT) {
         switch (suffix[0]) {
         case NULL_CHAR: {
@@ -362,23 +396,39 @@ int fetch_integral (char *p, OPTION_LIST_T ** i, BOOL_T * error)
             mult = GIGABYTE;
             break;
           }
+        #if defined (TERABYTE)
+          case 't':
+          case 'T': {
+              mult = TERABYTE;
+              break;
+            }
+        #endif
+        #if defined (PETABYTE)
+          case 'p':
+          case 'P': {
+              mult = PETABYTE;
+              break;
+            }
+        #endif
         default: {
-            option_error (start_l, start_c, "unknown suffix in");
+            option_error (start_l, start_c, ERROR_INVALID_VALUE);
             *error = A68G_TRUE;
             break;
           }
         }
         if (suffix[0] != NULL_CHAR && suffix[1] != NULL_CHAR) {
-          option_error (start_l, start_c, "unknown suffix in");
+          option_error (start_l, start_c, ERROR_INVALID_VALUE);
           *error = A68G_TRUE;
         }
       }
     }
-    if (OVER_2G ((REAL_T) k * (REAL_T) mult)) {
-      errno = ERANGE;
-      option_error (start_l, start_c, ERROR_OVER_2G);
+// Check overflow.
+    if (int_mul_overflow (value, mult, max_int)) {
+      option_error (start_l, start_c, ERROR_VALUE_TOO_LARGE);
+      return 0;
+    } else {
+      return value * mult;
     }
-    return k * mult;
   }
 }
 
@@ -387,34 +437,49 @@ int fetch_integral (char *p, OPTION_LIST_T ** i, BOOL_T * error)
 static void tech_stuff (void)
 {
   state_version (A68G_STDOUT);
-  ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "sizeof (A68G_REF) = %u", (unt) sizeof (A68G_REF)) >= 0);
+  ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "sizeof (A68G_REF) = " A68G_LU, (UNSIGNED_T) sizeof (A68G_REF)) >= 0);
   WRITELN (A68G_STDOUT, A68G (output_line));
-  ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "sizeof (A68G_PROCEDURE) = %u", (unt) sizeof (A68G_PROCEDURE)) >= 0);
+  ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "sizeof (A68G_PROCEDURE) = " A68G_LU, (UNSIGNED_T) sizeof (A68G_PROCEDURE)) >= 0);
   WRITELN (A68G_STDOUT, A68G (output_line));
 #if (A68G_LEVEL >= 3)
-  ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "sizeof (DOUBLE_T) = %u", (unt) sizeof (DOUBLE_T)) >= 0);
+  ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "sizeof (DOUBLE_T) = " A68G_LU, (UNSIGNED_T) sizeof (DOUBLE_T)) >= 0);
   WRITELN (A68G_STDOUT, A68G (output_line));
-  ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "sizeof (DOUBLE_NUM_T) = %u", (unt) sizeof (DOUBLE_NUM_T)) >= 0);
+  ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "sizeof (DOUBLE_NUM_T) = " A68G_LU, (UNSIGNED_T) sizeof (DOUBLE_NUM_T)) >= 0);
   WRITELN (A68G_STDOUT, A68G (output_line));
 #endif
-  ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "sizeof (A68G_INT) = %u", (unt) sizeof (A68G_INT)) >= 0);
+  ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "sizeof (A68G_INT) = " A68G_LU, (UNSIGNED_T) sizeof (A68G_INT)) >= 0);
   WRITELN (A68G_STDOUT, A68G (output_line));
-  ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "sizeof (A68G_REAL) = %u", (unt) sizeof (A68G_REAL)) >= 0);
+  ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "sizeof (A68G_REAL) = " A68G_LU, (UNSIGNED_T) sizeof (A68G_REAL)) >= 0);
   WRITELN (A68G_STDOUT, A68G (output_line));
-  ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "sizeof (A68G_BOOL) = %u", (unt) sizeof (A68G_BOOL)) >= 0);
+  ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "sizeof (A68G_BOOL) = " A68G_LU, (UNSIGNED_T) sizeof (A68G_BOOL)) >= 0);
   WRITELN (A68G_STDOUT, A68G (output_line));
-  ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "sizeof (A68G_CHAR) = %u", (unt) sizeof (A68G_CHAR)) >= 0);
+  ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "sizeof (A68G_CHAR) = " A68G_LU, (UNSIGNED_T) sizeof (A68G_CHAR)) >= 0);
   WRITELN (A68G_STDOUT, A68G (output_line));
-  ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "sizeof (A68G_BITS) = %u", (unt) sizeof (A68G_BITS)) >= 0);
+  ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "sizeof (A68G_BITS) = " A68G_LU, (UNSIGNED_T) sizeof (A68G_BITS)) >= 0);
   WRITELN (A68G_STDOUT, A68G (output_line));
 #if (A68G_LEVEL >= 3)
-  ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "sizeof (A68G_LONG_REAL) = %u", (unt) sizeof (A68G_LONG_REAL)) >= 0);
+  ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "sizeof (A68G_LONG_INT) = " A68G_LU, (UNSIGNED_T) sizeof (A68G_LONG_INT)) >= 0);
+  WRITELN (A68G_STDOUT, A68G (output_line));
+  ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "sizeof (A68G_LONG_REAL) = " A68G_LU, (UNSIGNED_T) sizeof (A68G_LONG_REAL)) >= 0);
   WRITELN (A68G_STDOUT, A68G (output_line));
 #else
-  ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "sizeof (A68G_LONG_REAL) = %u", (unt) size_mp ()) >= 0);
+  ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "sizeof (A68G_LONG_REAL) = " A68G_LU, (UNSIGNED_T) size_mp ()) >= 0);
   WRITELN (A68G_STDOUT, A68G (output_line));
 #endif
-  ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "sizeof (A68G_LONG_LONG_REAL) = %u", (unt) size_long_mp ()) >= 0);
+  ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "sizeof (A68G_LONG_LONG_REAL) = " A68G_LU, (UNSIGNED_T) (UNSIGNED_T) SIZE_MP (LONG_LONG_MP_DIGITS)) >= 0);
+  WRITELN (A68G_STDOUT, A68G (output_line));
+  WRITELN (A68G_STDOUT, "");
+  ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "sizeof (INT_T) = " A68G_LU, (UNSIGNED_T) sizeof (INT_T)) >= 0);
+  WRITELN (A68G_STDOUT, A68G (output_line));
+  ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "sizeof (UNSIGNED_T) = " A68G_LU, (UNSIGNED_T) sizeof (UNSIGNED_T)) >= 0);
+  WRITELN (A68G_STDOUT, A68G (output_line));
+  ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "sizeof (a68g_off_t) = " A68G_LU, (UNSIGNED_T) sizeof (a68g_off_t)) >= 0);
+  WRITELN (A68G_STDOUT, A68G (output_line));
+  ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "sizeof (size_t) = " A68G_LU, (UNSIGNED_T) sizeof (size_t)) >= 0);
+  WRITELN (A68G_STDOUT, A68G (output_line));
+  ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "sizeof (ssize_t) = " A68G_LU, (UNSIGNED_T) sizeof (ssize_t)) >= 0);
+  WRITELN (A68G_STDOUT, A68G (output_line));
+  ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "UPB size_t = " A68G_LU, (UNSIGNED_T) MAX_MEM_SIZE) >= 0);
   WRITELN (A68G_STDOUT, A68G (output_line));
   WRITELN (A68G_STDOUT, "");
   exit (EXIT_SUCCESS);
@@ -550,7 +615,7 @@ BOOL_T set_options (OPTION_LIST_T *i, BOOL_T cmd_line)
     } else {
       LINE_T *start_l = LINE (i);
       char *start_c = STR (i);
-      int n = (int) strlen (STR (i));
+      size_t n = strlen (STR (i));
 // Allow for spaces ending in # to have A68 comment syntax with '#!'.
       while (n > 0 && (IS_SPACE ((STR (i))[n - 1]) || (STR (i))[n - 1] == '#')) {
         (STR (i))[--n] = NULL_CHAR;
@@ -559,7 +624,6 @@ BOOL_T set_options (OPTION_LIST_T *i, BOOL_T cmd_line)
 // Accept UNIX '-option [=] value'.
         BOOL_T minus_sign = (BOOL_T) ((STR (i))[0] == '-');
         char *p = strip_sign (STR (i));
-        char *stale = p;
         if (!minus_sign && eq (p, "#")) {
           ;
         } else if (!minus_sign && cmd_line) {
@@ -568,7 +632,7 @@ BOOL_T set_options (OPTION_LIST_T *i, BOOL_T cmd_line)
             FILE_INITIAL_NAME (&A68G_JOB) = new_string (p, NO_TEXT);
             name_set = A68G_TRUE;
           } else {
-            option_error (NO_LINE, start_c, "multiple source file names at");
+            option_error (NO_LINE, start_c, ERROR_MULTIPLE_SOURCE_FILES);
           }
         } else if (eq (p, "INCLUDE")) {
 // Preprocessor items stop option processing.
@@ -588,7 +652,7 @@ BOOL_T set_options (OPTION_LIST_T *i, BOOL_T cmd_line)
           siga = A68G_FALSE;
         }
 // Empty item (from specifying '-' or '--') stops option processing.
-        else if (eq (p, "")) {
+        else if (eq (p, "-") || eq (p, "--")) {
           siga = A68G_FALSE;
         }
 // FILE accepts its argument as filename.
@@ -602,17 +666,17 @@ BOOL_T set_options (OPTION_LIST_T *i, BOOL_T cmd_line)
               FILE_INITIAL_NAME (&A68G_JOB) = new_string (STR (i), NO_TEXT);
               name_set = A68G_TRUE;
             } else {
-              option_error (start_l, start_c, "multiple source file names at");
+              option_error (start_l, start_c, ERROR_MULTIPLE_SOURCE_FILES);
             }
           } else {
-            option_error (start_l, start_c, "missing argument in");
+            option_error (start_l, start_c, ERROR_MISSING_STUFF);
           }
         }
 // NEED or LIBrary require the argument as environ.
         else if (eq (p, "NEED") || eq (p, "LIBrary")) {
           FORWARD (i);
           if (i == NO_OPTION_LIST) {
-            option_error (start_l, start_c, "missing argument in");
+            option_error (start_l, start_c, ERROR_MISSING_STUFF);
           } else {
             OPTION_LIST_T *save = i; BOOL_T good = A68G_FALSE;
             do {
@@ -635,10 +699,10 @@ BOOL_T set_options (OPTION_LIST_T *i, BOOL_T cmd_line)
               FILE_INITIAL_NAME (&A68G_JOB) = new_string (STR (i), NO_TEXT);
               name_set = A68G_TRUE;
             } else {
-              option_error (start_l, start_c, "multiple source file names at");
+              option_error (start_l, start_c, ERROR_MULTIPLE_SOURCE_FILES);
             }
           } else {
-            option_error (start_l, start_c, "missing argument in");
+            option_error (start_l, start_c, ERROR_MISSING_STUFF);
           }
           skip = A68G_TRUE;
         }
@@ -652,7 +716,7 @@ BOOL_T set_options (OPTION_LIST_T *i, BOOL_T cmd_line)
             ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "%s verification \"%s\" does not match script verification \"%s\"", A68G (a68g_cmd_name), PACKAGE_STRING, STR (i)) >= 0);
             ABEND (strcmp (PACKAGE_STRING, STR (i)) != 0, new_string (A68G (output_line), __func__), "outdated script");
           } else {
-            option_error (start_l, start_c, "missing argument in");
+            option_error (start_l, start_c, ERROR_MISSING_STUFF);
           }
         }
 // HELP gives online help.
@@ -682,7 +746,7 @@ BOOL_T set_options (OPTION_LIST_T *i, BOOL_T cmd_line)
 // EXECUTE and PRINT execute their argument as Algol 68 text.
         else if (eq (p, "Execute") || eq (p, "X") || eq (p, "Print")) {
           if (cmd_line == A68G_FALSE) {
-            option_error (start_l, start_c, "command-line-only");
+            option_error (start_l, start_c, ERROR_COMMAND_LINE);
           } else if ((FORWARD (i)) != NO_OPTION_LIST) {
             BOOL_T error = A68G_FALSE;
             if (strcmp (STR (i), "=") == 0) {
@@ -704,33 +768,35 @@ BOOL_T set_options (OPTION_LIST_T *i, BOOL_T cmd_line)
               ASSERT (fclose (f) == 0);
               FILE_INITIAL_NAME (&A68G_JOB) = new_string (new_name, NO_TEXT);
             } else {
-              option_error (start_l, start_c, "unit required by");
+              option_error (start_l, start_c, ERROR_MISSING_STUFF);
             }
           } else {
-            option_error (start_l, start_c, "missing argument in");
+            option_error (start_l, start_c, ERROR_MISSING_STUFF);
           }
         }
 // STORAGE, HEAP, HANDLES, STACK, FRAME and OVERHEAD set core allocation.
         else if (eq (p, "STOrage")) {
           BOOL_T error = A68G_FALSE;
-          int k = fetch_integral (p, &i, &error);
+          INT_T k = fetch_integral (p, &i, &error, MAX_MEM_SIZE);
+
 // Adjust size.
           if (error || errno > 0) {
-            option_error (start_l, start_c, "conversion error in");
+            option_error (start_l, start_c, ERROR_MISSING_STUFF);
           } else if (k > 0) {
-            default_mem_sizes (k);
+            default_mem_sizes (k, start_l, start_c);
           }
         } else if (eq (p, "HEAP") || eq (p, "HANDLES") || eq (p, "STACK") || eq (p, "FRAME") || eq (p, "OVERHEAD")) {
           BOOL_T error = A68G_FALSE;
-          int k = fetch_integral (p, &i, &error);
+          INT_T k = fetch_integral (p, &i, &error, MAX_MEM_SIZE);
 // Adjust size.
           if (error || errno > 0) {
-            option_error (start_l, start_c, "conversion error in");
+            option_error (start_l, start_c, ERROR_INVALID_VALUE);
           } else if (k > 0) {
-            if (k < MIN_MEM_SIZE) {
-              option_error (start_l, start_c, "value less than minimum in");
-              k = MIN_MEM_SIZE;
+            if (k < A68G (storage_overhead)) {
+              option_error (start_l, start_c, ERROR_INVALID_VALUE);
+              k = A68G (storage_overhead);
             }
+            storage_limit (k + A68G (storage_overhead));
             if (eq (p, "HEAP")) {
               A68G (heap_size) = k;
             } else if (eq (p, "HANDLES")) {
@@ -754,7 +820,7 @@ BOOL_T set_options (OPTION_LIST_T *i, BOOL_T cmd_line)
           }
           OPTION_RUN_SCRIPT (&A68G_JOB) = A68G_FALSE;
 #else
-          option_error (start_l, start_c, "linux-only option");
+          option_error (start_l, start_c, ERROR_PLATFORM);
 #endif
         } else if (eq (p, "NOCompile") || eq (p, "NO-Compile")) {
           OPTION_COMPILE (&A68G_JOB) = A68G_FALSE;
@@ -797,10 +863,10 @@ BOOL_T set_options (OPTION_LIST_T *i, BOOL_T cmd_line)
               FILE_INITIAL_NAME (&A68G_JOB) = new_string (STR (i), NO_TEXT);
               name_set = A68G_TRUE;
             } else {
-              option_error (start_l, start_c, "multiple source file names at");
+              option_error (start_l, start_c, ERROR_MULTIPLE_SOURCE_FILES);
             }
           } else {
-            option_error (start_l, start_c, "missing argument in");
+            option_error (start_l, start_c, ERROR_MISSING_STUFF);
           }
           skip = A68G_TRUE;
           OPTION_RUN_SCRIPT (&A68G_JOB) = A68G_TRUE;
@@ -808,7 +874,7 @@ BOOL_T set_options (OPTION_LIST_T *i, BOOL_T cmd_line)
           OPTION_NO_WARNINGS (&A68G_JOB) = A68G_TRUE;
           OPTION_COMPILE (&A68G_JOB) = A68G_FALSE;
 #else
-          option_error (start_l, start_c, "linux-only option");
+          option_error (start_l, start_c, ERROR_PLATFORM);
 #endif
         }
 // RUN-QUOTE-SCRIPT runs a compiled .sh script.
@@ -820,17 +886,17 @@ BOOL_T set_options (OPTION_LIST_T *i, BOOL_T cmd_line)
               FILE_INITIAL_NAME (&A68G_JOB) = new_string (STR (i), NO_TEXT);
               name_set = A68G_TRUE;
             } else {
-              option_error (start_l, start_c, "multiple source file names at");
+              option_error (start_l, start_c, ERROR_MULTIPLE_SOURCE_FILES);
             }
           } else {
-            option_error (start_l, start_c, "missing argument in");
+            option_error (start_l, start_c, ERROR_MISSING_STUFF);
           }
           skip = A68G_TRUE;
           OPTION_RUN_SCRIPT (&A68G_JOB) = A68G_TRUE;
           OPTION_STROPPING (&A68G_JOB) = QUOTE_STROPPING;
           OPTION_COMPILE (&A68G_JOB) = A68G_FALSE;
 #else
-          option_error (start_l, start_c, "linux-only option");
+          option_error (start_l, start_c, ERROR_PLATFORM);
 #endif
         }
 // RERUN re-uses an existing .so file.
@@ -1082,16 +1148,16 @@ BOOL_T set_options (OPTION_LIST_T *i, BOOL_T cmd_line)
 // PRECISION sets the LONG LONG precision.
         else if (eq (p, "PRECision")) {
           BOOL_T error = A68G_FALSE;
-          int N = fetch_integral (p, &i, &error);
+          INT_T N = fetch_integral (p, &i, &error, A68G_MAX_INT);
           int k = width_to_mp_digits (N);
           if (k <= 0 || error || errno > 0) {
-            option_error (start_l, start_c, "invalid value in");
+            option_error (start_l, start_c, ERROR_INVALID_VALUE);
           } else if (long_mp_digits () > 0 && long_mp_digits () != k) {
-            option_error (start_l, start_c, "different precision was already specified in");
+            option_error (start_l, start_c, ERROR_PRECISION_SET);
           } else if (k > mp_digits ()) {
             set_long_mp_digits (k);
           } else {
-            option_error (start_l, start_c, "attempt to set LONG LONG precision lower than LONG precision");
+            option_error (start_l, start_c, ERROR_PRECISION_TOO_LOW);
           }
         }
 // BACKTRACE and NOBACKTRACE switch on/off stack backtracing.
@@ -1122,26 +1188,24 @@ BOOL_T set_options (OPTION_LIST_T *i, BOOL_T cmd_line)
 // TIMELIMIT lets the interpreter stop after so-many seconds.
         else if (eq (p, "TImelimit") || eq (p, "TIME-Limit")) {
           BOOL_T error = A68G_FALSE;
-          int k = fetch_integral (p, &i, &error);
+          INT_T k = fetch_integral (p, &i, &error, A68G_MAX_INT);
           if (error || errno > 0) {
-            option_error (start_l, start_c, "conversion error in");
+            option_error (start_l, start_c, ERROR_INVALID_VALUE);
           } else if (k < 1) {
-            option_error (start_l, start_c, "invalid time span in");
+            option_error (start_l, start_c, ERROR_INVALID_VALUE);
           } else {
             OPTION_TIME_LIMIT (&A68G_JOB) = k;
           }
         }
 // Next undocumented option is for a68g development purposes.
-        else if (eq (p, "CONSERVATIVEgc") || eq (p, "CONSERVATIVE-gc")) {
-          OPTION_CONSERVATIVE_GC (&A68G_JOB) = A68G_TRUE;
-        }
-        else if (eq (p, "NOCONSERVATIVEgc") || eq (p, "NO-CONSERVATIVE-gc")) {
-          OPTION_CONSERVATIVE_GC (&A68G_JOB) = A68G_FALSE;
+        else if (eq (p, "SAFEGC") || eq (p, "SAFE-GC")) {
+          OPTION_CONSERVATIVE_GC (&A68G_JOB) = A68G_GC_SAFE;
+        } else if (eq (p, "NOGC") || eq (p, "NO-GC")) {
+          OPTION_CONSERVATIVE_GC (&A68G_JOB) = A68G_GC_HALT;
         } else {
 // Unrecognised.
-          option_error (start_l, start_c, "unrecognised");
+          option_error (start_l, start_c, ERROR_UNRECOGNISED_OPTION);
         }
-        a68g_free (stale);
       }
 // Go processing next item, if present.
       if (i != NO_OPTION_LIST) {
