@@ -27,7 +27,7 @@
 #include "a68g-prelude.h"
 #include "a68g-genie.h"
 
-#if defined (BUILD_WIN32)
+#if defined (BUILD_WIN32) || defined (BUILD_WIN64)
 #include <windows.h>
 #endif
 
@@ -35,11 +35,11 @@
 
 char *a68g_dirname (char *src)
 {
-  int len = (int) strlen (src) + 1;
+  size_t len = strlen (src) + 1;
   char *cpy = (char *) get_fixed_heap_space (len + 1);
   char *dst = (char *) get_fixed_heap_space (len + 1);
-  ABEND (cpy == NO_TEXT, ERROR_OUT_OF_CORE, __func__);
-  ABEND (dst == NO_TEXT, ERROR_OUT_OF_CORE, __func__);
+  ABEND (cpy == NO_TEXT, ERROR_MEMORY_FULL, __func__);
+  ABEND (dst == NO_TEXT, ERROR_MEMORY_FULL, __func__);
   a68g_bufcpy (cpy, src, len);
   a68g_bufcpy (dst, dirname (cpy), len);
   return dst;
@@ -49,11 +49,11 @@ char *a68g_dirname (char *src)
 
 char *a68g_basename (char *src)
 {
-  int len = (int) strlen (src) + 1;
+  size_t len = strlen (src) + 1;
   char *cpy = (char *) get_fixed_heap_space (len + 1);
   char *dst = (char *) get_fixed_heap_space (len + 1);
-  ABEND (cpy == NO_TEXT, ERROR_OUT_OF_CORE, __func__);
-  ABEND (dst == NO_TEXT, ERROR_OUT_OF_CORE, __func__);
+  ABEND (cpy == NO_TEXT, ERROR_MEMORY_FULL, __func__);
+  ABEND (dst == NO_TEXT, ERROR_MEMORY_FULL, __func__);
   a68g_bufcpy (cpy, src, len);
   a68g_bufcpy (dst, basename (cpy), len);
   return dst;
@@ -61,7 +61,7 @@ char *a68g_basename (char *src)
 
 //! @brief Compute relative path.
 
-#if defined (BUILD_WIN32)
+#if defined (BUILD_WIN32) || defined (BUILD_WIN64)
 
 static char *win32_slash (char *p)
 {
@@ -113,7 +113,7 @@ char *a68g_relpath (char *p1, char *p2, char *fn)
   ASSERT (p1 != NO_TEXT);
   ASSERT (p2 != NO_TEXT);
   ASSERT (fn != NO_TEXT);
-#if defined (BUILD_WIN32)
+#if defined (BUILD_WIN32) || defined (BUILD_WIN64)
   if (p2[0] == '\\') {
     a68g_bufcpy (q, p2, PATH_MAX);
   } else {
@@ -142,7 +142,7 @@ char *a68g_relpath (char *p1, char *p2, char *fn)
 #endif
 // Error handling in the caller!
   errno = 0;
-#if defined (BUILD_WIN32)
+#if defined (BUILD_WIN32) || defined (BUILD_WIN64)
   char *r = win32_realpath (q, NO_TEXT);
 #else
   char *r = realpath (q, NO_TEXT);
@@ -150,7 +150,7 @@ char *a68g_relpath (char *p1, char *p2, char *fn)
   if (r != NO_TEXT) {
     size_t len = strlen (r) + 1;
     char *rc = (char *) get_fixed_heap_space (len);
-    ABEND (rc == NO_TEXT, ERROR_OUT_OF_CORE, __func__);
+    ABEND (rc == NO_TEXT, ERROR_MEMORY_FULL, __func__);
     a68g_bufcpy (rc, r, len);
     free (r);
     return rc;
@@ -170,7 +170,7 @@ void genie_realpath (NODE_T * p)
     PUSH_REF (p, empty_string (p));
   } else {
 // Note that ~ is not resolved since that is the shell, not libc.
-#if defined (BUILD_WIN32)
+#if defined (BUILD_WIN32) || defined (BUILD_WIN64)
     char *out = win32_realpath (in, NO_TEXT);
 #else
     char *out = realpath (in, NO_TEXT);
