@@ -82,11 +82,11 @@
 #include "a68g-prelude-mathlib.h"
 
 #if defined (HAVE_MATHLIB)
-#include <Rmath.h>
+  #include <Rmath.h>
 #endif
 
 #if defined (HAVE_CURL)
-#include <curl/curl.h>
+  #include <curl/curl.h>
 #endif
 
 GLOBALS_T common;
@@ -108,20 +108,21 @@ void compiler_interpreter (void);
 
 void verbosity (void)
 {
-#if defined (A68G_DEBUG)
-  ;
-#else
-  ;
-#endif
+  #if defined (A68G_DEBUG)
+    ;
+  #else
+    ;
+  #endif
 }
 
 //! @brief State license of running a68g image.
 
 void state_license (FILE_T f)
 {
-#define PR(s)\
-  ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "%s\n", (s)) >= 0);\
-  WRITE (f, A68G (output_line));
+  #define PR(s)\
+    ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "%s\n", (s)) >= 0);\
+    WRITE (f, A68G (output_line));
+
   if (f == A68G_STDOUT) {
     io_close_tty_line ();
   }
@@ -147,87 +148,93 @@ void state_license (FILE_T f)
 
 void state_version (FILE_T f)
 {
-#define PR(s)\
-  ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "%s\n", (s)) >= 0);\
-  WRITE (f, A68G (output_line));
+  #define PR(s)\
+    ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "%s\n", (s)) >= 0);\
+    WRITE (f, A68G (output_line));
+
   if (f == A68G_STDOUT) {
     io_close_tty_line ();
   }
   state_license (f);
   PR ("");
-#if defined (BUILD_WIN32)
-  ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "WIN32 executable\n") >= 0);
-  WRITE (f, A68G (output_line));
-  WRITELN (f, "");
-#endif
-#if (A68G_LEVEL >= 3)
-  ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "With hardware support for long modes\n") >= 0);
-  WRITE (f, A68G (output_line));
-#endif
-#if defined (BUILD_A68G_COMPILER)
-  ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "With plugin-compilation support\n") >= 0);
-  WRITE (f, A68G (output_line));
-#endif
-#if defined (BUILD_PARALLEL_CLAUSE)
-  ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "With parallel-clause support\n") >= 0);
-  WRITE (f, A68G (output_line));
-#endif
-#if defined (HAVE_POSTGRESQL)
-  ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "With PostgreSQL support\n") >= 0);
-  WRITE (f, A68G (output_line));
-#endif
-#if defined (HAVE_CURL)
-  curl_version_info_data *data = curl_version_info(CURLVERSION_NOW);
-  ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "With curl %s\n", data->version) >= 0);
-  WRITE (f, A68G (output_line));
-#endif
-#if defined (HAVE_GNU_MPFR)
-  ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "With GNU MP %s\n", gmp_version) >= 0);
-  WRITE (f, A68G (output_line));
-  ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "With GNU MPFR %s\n", mpfr_get_version ()) >= 0);
-  WRITE (f, A68G (output_line));
-#endif
-#if defined (HAVE_MATHLIB)
-  ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "With mathlib from R %s\n", R_VERSION_STRING) >= 0);
-  WRITE (f, A68G (output_line));
-#endif
-#if defined (HAVE_GSL)
-  ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "With GNU Scientific Library %s\n", GSL_VERSION) >= 0);
-  WRITE (f, A68G (output_line));
-#endif
-#if defined (HAVE_GNU_PLOTUTILS)
-  ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "With GNU plotutils %s\n", PL_LIBPLOT_VER_STRING) >= 0);
-  WRITE (f, A68G (output_line));
-#endif
-#if defined (HAVE_CURSES)
-  #if defined (NCURSES_VERSION)
-    ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "With ncurses %s\n", NCURSES_VERSION) >= 0);
-  #else
-    ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "With curses support\n") >= 0);
+  #if defined (BUILD_WIN32)
+    ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "WIN32 executable\n") >= 0);
+    WRITE (f, A68G (output_line));
+    WRITELN (f, "");
   #endif
+  #if defined (BUILD_WIN64)
+    ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "WIN64 executable\n") >= 0);
+    WRITE (f, A68G (output_line));
+    WRITELN (f, "");
+  #endif
+  #if (A68G_LEVEL >= 3)
+    ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "With hardware support for long modes\n") >= 0);
+    WRITE (f, A68G (output_line));
+  #endif
+  #if defined (BUILD_A68G_COMPILER)
+    ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "With plugin-compilation support\n") >= 0);
+    WRITE (f, A68G (output_line));
+  #endif
+  #if defined (BUILD_PARALLEL_CLAUSE)
+    ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "With parallel-clause support\n") >= 0);
+    WRITE (f, A68G (output_line));
+  #endif
+  #if defined (HAVE_POSTGRESQL)
+    ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "With PostgreSQL support\n") >= 0);
+    WRITE (f, A68G (output_line));
+  #endif
+  #if defined (HAVE_CURL)
+    curl_version_info_data *data = curl_version_info(CURLVERSION_NOW);
+    ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "With curl %s\n", data->version) >= 0);
+    WRITE (f, A68G (output_line));
+  #endif
+  #if defined (HAVE_GNU_MPFR)
+    ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "With GNU MP %s\n", gmp_version) >= 0);
+    WRITE (f, A68G (output_line));
+    ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "With GNU MPFR %s\n", mpfr_get_version ()) >= 0);
+    WRITE (f, A68G (output_line));
+  #endif
+  #if defined (HAVE_MATHLIB)
+    ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "With mathlib from R %s\n", R_VERSION_STRING) >= 0);
+    WRITE (f, A68G (output_line));
+  #endif
+  #if defined (HAVE_GSL)
+    ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "With GNU Scientific Library %s\n", GSL_VERSION) >= 0);
+    WRITE (f, A68G (output_line));
+  #endif
+  #if defined (HAVE_GNU_PLOTUTILS)
+    ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "With GNU plotutils %s\n", PL_LIBPLOT_VER_STRING) >= 0);
+    WRITE (f, A68G (output_line));
+  #endif
+  #if defined (HAVE_CURSES)
+    #if defined (NCURSES_VERSION)
+      ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "With ncurses %s\n", NCURSES_VERSION) >= 0);
+    #else
+      ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "With curses support\n") >= 0);
+    #endif
+    WRITE (f, A68G (output_line));
+  #endif
+  #if defined (_CS_GNU_LIBC_VERSION) && defined (BUILD_UNIX)
+    if (confstr (_CS_GNU_LIBC_VERSION, A68G (input_line), BUFFER_SIZE) > (size_t) 0) {
+      ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "GNU libc version %s\n", A68G (input_line)) >= 0);
+      WRITE (f, A68G (output_line));
+    }
+  #if (defined (BUILD_PARALLEL_CLAUSE) && defined (_CS_GNU_LIBPTHREAD_VERSION))
+    if (confstr (_CS_GNU_LIBPTHREAD_VERSION, A68G (input_line), BUFFER_SIZE) > (size_t) 0) {
+      ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "GNU libpthread version %s\n", A68G (input_line)) >= 0);
+      WRITE (f, A68G (output_line));
+    }
+  #endif
+  #endif
+  #define RSIZE(n) (unt) (sizeof (n) / sizeof (int))
+  #if defined (BUILD_A68G_COMPILER) && defined (C_COMPILER)
+    ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "Build level %d.%x%x%x%x %s %s\n", A68G_LEVEL, RSIZE (INT_T), RSIZE (REAL_T), RSIZE (MP_INT_T), RSIZE (MP_REAL_T), C_COMPILER, __DATE__) >= 0);
+  #else
+    ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "Build level %d.%x%x%x%x %s\n", A68G_LEVEL, RSIZE (INT_T), RSIZE (REAL_T), RSIZE (MP_INT_T), RSIZE (MP_REAL_T), __DATE__) >= 0);
+  #endif
+  #undef RSIZE
   WRITE (f, A68G (output_line));
-#endif
-#if defined (_CS_GNU_LIBC_VERSION) && defined (BUILD_UNIX)
-  if (confstr (_CS_GNU_LIBC_VERSION, A68G (input_line), BUFFER_SIZE) > (size_t) 0) {
-    ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "GNU libc version %s\n", A68G (input_line)) >= 0);
-    WRITE (f, A68G (output_line));
-  }
-#if (defined (BUILD_PARALLEL_CLAUSE) && defined (_CS_GNU_LIBPTHREAD_VERSION))
-  if (confstr (_CS_GNU_LIBPTHREAD_VERSION, A68G (input_line), BUFFER_SIZE) > (size_t) 0) {
-    ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "GNU libpthread version %s\n", A68G (input_line)) >= 0);
-    WRITE (f, A68G (output_line));
-  }
-#endif
-#endif
-#define RSIZE(n) (unt) (sizeof (n) / sizeof (int))
-#if defined (BUILD_A68G_COMPILER) && defined (C_COMPILER)
-  ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "Build level %d.%x%x%x%x %s %s\n", A68G_LEVEL, RSIZE (INT_T), RSIZE (REAL_T), RSIZE (MP_INT_T), RSIZE (MP_REAL_T), C_COMPILER, __DATE__) >= 0);
-#else
-  ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "Build level %d.%x%x%x%x %s\n", A68G_LEVEL, RSIZE (INT_T), RSIZE (REAL_T), RSIZE (MP_INT_T), RSIZE (MP_REAL_T), __DATE__) >= 0);
-#endif
-#undef RSIZE
-WRITE (f, A68G (output_line));
-#undef PR
+  #undef PR
 }
 
 //! @brief Give brief help if someone types 'a68g --help'.
@@ -262,9 +269,9 @@ BOOL_T strip_extension (char *ext)
   if (ext == NO_TEXT) {
     return A68G_FALSE;
   }
-  int nlen = (int) strlen (FILE_SOURCE_NAME (&A68G_JOB)), xlen = (int) strlen (ext);
+  size_t nlen = strlen (FILE_SOURCE_NAME (&A68G_JOB)), xlen = strlen (ext);
   if (nlen > xlen && strcmp (&(FILE_SOURCE_NAME (&A68G_JOB)[nlen - xlen]), ext) == 0) {
-    char *fn = (char *) get_heap_space ((size_t) (nlen + 1));
+    char *fn = (char *) get_heap_space (nlen + 1);
     a68g_bufcpy (fn, FILE_SOURCE_NAME (&A68G_JOB), nlen);
     fn[nlen - xlen] = NULL_CHAR;
     a68g_free (FILE_GENERIC_NAME (&A68G_JOB));
@@ -282,15 +289,15 @@ void open_with_extensions (void)
 {
   FILE_SOURCE_FD (&A68G_JOB) = -1;
   for (int k = 0; k < EXTENSIONS && FILE_SOURCE_FD (&A68G_JOB) == -1; k++) {
-    int len;
+    size_t len;
     char *fn = NULL;
     if (extensions[k] == NO_TEXT) {
-      len = (int) strlen (FILE_INITIAL_NAME (&A68G_JOB)) + 1;
-      fn = (char *) get_heap_space ((size_t) len);
+      len = strlen (FILE_INITIAL_NAME (&A68G_JOB)) + 1;
+      fn = (char *) get_heap_space (len);
       a68g_bufcpy (fn, FILE_INITIAL_NAME (&A68G_JOB), len);
     } else {
-      len = (int) strlen (FILE_INITIAL_NAME (&A68G_JOB)) + (int) strlen (extensions[k]) + 1;
-      fn = (char *) get_heap_space ((size_t) len);
+      len = strlen (FILE_INITIAL_NAME (&A68G_JOB)) + strlen (extensions[k]) + 1;
+      fn = (char *) get_heap_space (len);
       a68g_bufcpy (fn, FILE_INITIAL_NAME (&A68G_JOB), len);
       a68g_bufcat (fn, extensions[k], len);
     }
@@ -399,33 +406,33 @@ void compiler_interpreter (void)
   ABEND (FILE_SOURCE_NAME (&A68G_JOB) == NO_TEXT, ERROR_INTERNAL_CONSISTENCY, __func__);
   ABEND (FILE_GENERIC_NAME (&A68G_JOB) == NO_TEXT, ERROR_INTERNAL_CONSISTENCY, __func__);
 // Object file.
-  int len = 1 + (int) strlen (FILE_GENERIC_NAME (&A68G_JOB)) + (int) strlen (OBJECT_EXTENSION);
-  FILE_OBJECT_NAME (&A68G_JOB) = (char *) get_heap_space ((size_t) len);
+  size_t len = 1 + strlen (FILE_GENERIC_NAME (&A68G_JOB)) + strlen (OBJECT_EXTENSION);
+  FILE_OBJECT_NAME (&A68G_JOB) = (char *) get_heap_space (len);
   a68g_bufcpy (FILE_OBJECT_NAME (&A68G_JOB), FILE_GENERIC_NAME (&A68G_JOB), len);
   a68g_bufcat (FILE_OBJECT_NAME (&A68G_JOB), OBJECT_EXTENSION, len);
 // Binary.
-  len = 1 + (int) strlen (FILE_GENERIC_NAME (&A68G_JOB)) + (int) strlen (PLUGIN_EXTENSION);
-  FILE_BINARY_NAME (&A68G_JOB) = (char *) get_heap_space ((size_t) len);
+  len = 1 + strlen (FILE_GENERIC_NAME (&A68G_JOB)) + strlen (PLUGIN_EXTENSION);
+  FILE_BINARY_NAME (&A68G_JOB) = (char *) get_heap_space (len);
   a68g_bufcpy (FILE_BINARY_NAME (&A68G_JOB), FILE_GENERIC_NAME (&A68G_JOB), len);
   a68g_bufcat (FILE_BINARY_NAME (&A68G_JOB), BINARY_EXTENSION, len);
 // Library file.
-  len = 1 + (int) strlen (FILE_GENERIC_NAME (&A68G_JOB)) + (int) strlen (PLUGIN_EXTENSION);
-  FILE_PLUGIN_NAME (&A68G_JOB) = (char *) get_heap_space ((size_t) len);
+  len = 1 + strlen (FILE_GENERIC_NAME (&A68G_JOB)) + strlen (PLUGIN_EXTENSION);
+  FILE_PLUGIN_NAME (&A68G_JOB) = (char *) get_heap_space (len);
   a68g_bufcpy (FILE_PLUGIN_NAME (&A68G_JOB), FILE_GENERIC_NAME (&A68G_JOB), len);
   a68g_bufcat (FILE_PLUGIN_NAME (&A68G_JOB), PLUGIN_EXTENSION, len);
 // Listing file.
-  len = 1 + (int) strlen (FILE_GENERIC_NAME (&A68G_JOB)) + (int) strlen (LISTING_EXTENSION);
-  FILE_LISTING_NAME (&A68G_JOB) = (char *) get_heap_space ((size_t) len);
+  len = 1 + strlen (FILE_GENERIC_NAME (&A68G_JOB)) + strlen (LISTING_EXTENSION);
+  FILE_LISTING_NAME (&A68G_JOB) = (char *) get_heap_space (len);
   a68g_bufcpy (FILE_LISTING_NAME (&A68G_JOB), FILE_GENERIC_NAME (&A68G_JOB), len);
   a68g_bufcat (FILE_LISTING_NAME (&A68G_JOB), LISTING_EXTENSION, len);
 // Pretty file.
-  len = 1 + (int) strlen (FILE_GENERIC_NAME (&A68G_JOB)) + (int) strlen (PRETTY_EXTENSION);
-  FILE_PRETTY_NAME (&A68G_JOB) = (char *) get_heap_space ((size_t) len);
+  len = 1 + strlen (FILE_GENERIC_NAME (&A68G_JOB)) + strlen (PRETTY_EXTENSION);
+  FILE_PRETTY_NAME (&A68G_JOB) = (char *) get_heap_space (len);
   a68g_bufcpy (FILE_PRETTY_NAME (&A68G_JOB), FILE_GENERIC_NAME (&A68G_JOB), len);
   a68g_bufcat (FILE_PRETTY_NAME (&A68G_JOB), PRETTY_EXTENSION, len);
 // Script file.
-  len = 1 + (int) strlen (FILE_GENERIC_NAME (&A68G_JOB)) + (int) strlen (SCRIPT_EXTENSION);
-  FILE_SCRIPT_NAME (&A68G_JOB) = (char *) get_heap_space ((size_t) len);
+  len = 1 + strlen (FILE_GENERIC_NAME (&A68G_JOB)) + strlen (SCRIPT_EXTENSION);
+  FILE_SCRIPT_NAME (&A68G_JOB) = (char *) get_heap_space (len);
   a68g_bufcpy (FILE_SCRIPT_NAME (&A68G_JOB), FILE_GENERIC_NAME (&A68G_JOB), len);
   a68g_bufcat (FILE_SCRIPT_NAME (&A68G_JOB), SCRIPT_EXTENSION, len);
 // Parser.
@@ -455,16 +462,16 @@ void compiler_interpreter (void)
   if (ERROR_COUNT (&A68G_JOB) == 0 && OPTION_OPT_LEVEL (&A68G_JOB) > NO_OPTIMISE) {
     announce_phase ("plugin-compiler");
     plugin_driver_code ();
-#if defined (BUILD_A68G_COMPILER)
-    emitted = A68G_TRUE;
-    if (ERROR_COUNT (&A68G_JOB) == 0 && !OPTION_RUN_SCRIPT (&A68G_JOB)) {
-      plugin_driver_compile ();
-    }
-    verbosity ();
-#else
-    emitted = A68G_FALSE;
-    diagnostic (A68G_WARNING | A68G_FORCE_DIAGNOSTICS, TOP_NODE (&A68G_JOB), WARNING_OPTIMISATION);
-#endif
+    #if defined (BUILD_A68G_COMPILER)
+      emitted = A68G_TRUE;
+      if (ERROR_COUNT (&A68G_JOB) == 0 && !OPTION_RUN_SCRIPT (&A68G_JOB)) {
+        plugin_driver_compile ();
+      }
+      verbosity ();
+    #else
+      emitted = A68G_FALSE;
+      diagnostic (A68G_WARNING, TOP_NODE (&A68G_JOB), WARNING_OPTIMISATION);
+    #endif
   }
 // Indenter.
   if (ERROR_COUNT (&A68G_JOB) == 0 && OPTION_PRETTY (&A68G_JOB)) {
@@ -483,11 +490,11 @@ void compiler_interpreter (void)
     GetRNGstate ();
     A68G (f_entry) = TOP_NODE (&A68G_JOB);
     A68G (close_tty_on_exit) = A68G_FALSE;
-#if defined (BUILD_A68G_COMPILER)
-    plugin_driver_genie ();
-#else
-    genie ((void *) NULL);
-#endif
+    #if defined (BUILD_A68G_COMPILER)
+      plugin_driver_genie ();
+    #else
+      genie ((void *) NULL);
+    #endif
 // Free heap allocated by genie.
     if (A68G_GC (total) > 10 * MEGABYTE) {
       ASSERT (a68g_bufprt (A68G (edit_line), SNPRINTF_SIZE, 
@@ -542,12 +549,12 @@ void compiler_interpreter (void)
     verbosity ();
   }
 // Cleaning up the intermediate files.
-#if defined (BUILD_A68G_COMPILER)
-  announce_phase ("clean up intermediate files");
-  plugin_driver_clean (emitted);
-#else
-  (void) emitted;
-#endif
+  #if defined (BUILD_A68G_COMPILER)
+    announce_phase ("clean up intermediate files");
+    plugin_driver_clean (emitted);
+  #else
+    (void) emitted;
+  #endif
 }
 
 //! @brief Exit a68g in an orderly manner.
@@ -555,9 +562,9 @@ void compiler_interpreter (void)
 void a68g_exit (int code)
 {
   announce_phase ("exit");
-#if defined (HAVE_GNU_MPFR)
-  mpfr_free_cache ();
-#endif
+  #if defined (HAVE_GNU_MPFR)
+    mpfr_free_cache ();
+  #endif
 // Close unclosed files, remove temp files.
   free_file_entries ();
 // Close the terminal.
@@ -566,12 +573,12 @@ void a68g_exit (int code)
   } else if (OPTION_VERBOSE (&A68G_JOB)) {
     io_close_tty_line ();
   }
-#if defined (HAVE_CURSES)
+  #if defined (HAVE_CURSES)
 // "curses" might still be open if it was not closed from A68, or the program
 // was interrupted, or a runtime error occured. That wreaks havoc on your
 // terminal. 
-  genie_curses_end (NO_NODE);
-#endif
+    genie_curses_end (NO_NODE);
+  #endif
 // Clean up stale things.
   free_syntax_tree (TOP_NODE (&A68G_JOB));
   free_option_list (OPTION_LIST (&A68G_JOB));
@@ -611,18 +618,17 @@ int main (int argc, char *argv[])
   A68G (close_tty_on_exit) = A68G_TRUE;
   FILE_DIAGS_FD (&A68G_JOB) = -1;
 // Get command name and discard path.
-  a68g_bufcpy (A68G (a68g_cmd_name), argv[0], BUFFER_SIZE);
-  for (int k = (int) strlen (A68G (a68g_cmd_name)) - 1; k >= 0; k--) {
-#if defined (BUILD_WIN32)
-    char delim = '\\';
-#else
-    char delim = '/';
-#endif
-    if (A68G (a68g_cmd_name)[k] == delim) {
-      MOVE (&A68G (a68g_cmd_name)[0], &A68G (a68g_cmd_name)[k + 1], (int) strlen (A68G (a68g_cmd_name)) - k + 1);
-      k = -1;
+  #if defined (BUILD_WIN32) || defined (BUILD_WIN64)
+    a68g_bufcpy (A68G (a68g_cmd_name), "a68g", BUFFER_SIZE);
+  #else
+    a68g_bufcpy (A68G (a68g_cmd_name), argv[0], BUFFER_SIZE);
+    for (int k = strlen (A68G (a68g_cmd_name)) - 1; k >= 0; k--) {
+      if (A68G (a68g_cmd_name)[k] == '/') {
+        MOVE (&A68G (a68g_cmd_name)[0], &A68G (a68g_cmd_name)[k + 1], strlen (A68G (a68g_cmd_name)) - k + 1);
+        k = -1;
+      }
     }
-  }
+  #endif
 // Try to read maximum line width on the terminal,
 // used to pretty print diagnostics to same.
   a68g_getty (&A68G (term_heigth), &A68G (term_width));
@@ -647,7 +653,7 @@ int main (int argc, char *argv[])
     init_options ();
     SOURCE_SCAN (&A68G_JOB) = 1;
     default_options (&A68G_JOB);
-    default_mem_sizes (1);
+    default_mem_sizes (1, NULL, NULL);
 // Initialise core.
     A68G_STACK = NO_BYTE;
     A68G_HEAP = NO_BYTE;
@@ -690,11 +696,11 @@ int main (int argc, char *argv[])
 // Start the UI.
     init_before_tokeniser ();
 // Running a script.
-#if defined (BUILD_A68G_COMPILER)
-    if (OPTION_RUN_SCRIPT (&A68G_JOB)) {
-      load_script ();
-    }
-#endif
+    #if defined (BUILD_A68G_COMPILER)
+      if (OPTION_RUN_SCRIPT (&A68G_JOB)) {
+        load_script ();
+      }
+    #endif
 // We translate the program.
     if (FILE_INITIAL_NAME (&A68G_JOB) == NO_TEXT || strlen (FILE_INITIAL_NAME (&A68G_JOB)) == 0) {
       SCAN_ERROR (!(OPTION_LICENSE (&A68G_JOB) || OPTION_VERSION (&A68G_JOB)), NO_LINE, NO_TEXT, ERROR_NO_SOURCE_FILE);
