@@ -30,13 +30,13 @@
 #include "a68g-parser.h"
 
 #define LABEL_FREE(_p_) {\
-  NODE_T *_m_q; ADDR_T pop_sp_lf = A68_SP;\
+  NODE_T *_m_q; ADDR_T pop_sp_lf = A68G_SP;\
   for (_m_q = SEQUENCE (_p_); _m_q != NO_NODE; _m_q = SEQUENCE (_m_q)) {\
     if (IS (_m_q, UNIT) || IS (_m_q, DECLARATION_LIST)) {\
       GENIE_UNIT_TRACE (_m_q);\
     }\
     if (SEQUENCE (_m_q) != NO_NODE) {\
-      A68_SP = pop_sp_lf;\
+      A68G_SP = pop_sp_lf;\
       _m_q = SEQUENCE (_m_q);\
     }\
   }}
@@ -68,12 +68,12 @@ PROP_T genie_assertion (NODE_T * p)
 {
   PROP_T self;
   if (STATUS_TEST (p, ASSERT_MASK)) {
-    A68_BOOL z;
+    A68G_BOOL z;
     GENIE_UNIT (NEXT_SUB (p));
-    POP_OBJECT (p, &z, A68_BOOL);
-    if (VALUE (&z) == A68_FALSE) {
-      diagnostic (A68_RUNTIME_ERROR, p, ERROR_FALSE_ASSERTION);
-      exit_genie (p, A68_RUNTIME_ERROR);
+    POP_OBJECT (p, &z, A68G_BOOL);
+    if (VALUE (&z) == A68G_FALSE) {
+      diagnostic (A68G_RUNTIME_ERROR, p, ERROR_FALSE_ASSERTION);
+      exit_genie (p, A68G_RUNTIME_ERROR);
     }
   }
   UNIT (&self) = genie_assertion;
@@ -86,135 +86,135 @@ PROP_T genie_assertion (NODE_T * p)
 PROP_T genie_unit (NODE_T * p)
 {
   if (IS_COERCION (GINFO (p))) {
-    GLOBAL_PROP (&A68_JOB) = genie_coercion (p);
+    GLOBAL_PROP (&A68G_JOB) = genie_coercion (p);
   } else {
     switch (ATTRIBUTE (p)) {
     case DECLARATION_LIST: {
         genie_declaration (SUB (p));
-        UNIT (&GLOBAL_PROP (&A68_JOB)) = genie_unit;
-        SOURCE (&GLOBAL_PROP (&A68_JOB)) = p;
+        UNIT (&GLOBAL_PROP (&A68G_JOB)) = genie_unit;
+        SOURCE (&GLOBAL_PROP (&A68G_JOB)) = p;
         break;
       }
     case UNIT: {
-        GENIE_UNIT_2 (SUB (p), GLOBAL_PROP (&A68_JOB));
+        GENIE_UNIT_KEEP (SUB (p), GLOBAL_PROP (&A68G_JOB));
         break;
       }
     case TERTIARY:
     case SECONDARY:
     case PRIMARY: {
-        GLOBAL_PROP (&A68_JOB) = genie_unit (SUB (p));
+        GLOBAL_PROP (&A68G_JOB) = genie_unit (SUB (p));
         break;
       }
 // Ex primary.
     case ENCLOSED_CLAUSE: {
-        GLOBAL_PROP (&A68_JOB) = genie_enclosed ((volatile NODE_T *) p);
+        GLOBAL_PROP (&A68G_JOB) = genie_enclosed ((volatile NODE_T *) p);
         break;
       }
     case IDENTIFIER: {
-        GLOBAL_PROP (&A68_JOB) = genie_identifier (p);
+        GLOBAL_PROP (&A68G_JOB) = genie_identifier (p);
         break;
       }
     case CALL: {
-        GLOBAL_PROP (&A68_JOB) = genie_call (p);
+        GLOBAL_PROP (&A68G_JOB) = genie_call (p);
         break;
       }
     case SLICE: {
-        GLOBAL_PROP (&A68_JOB) = genie_slice (p);
+        GLOBAL_PROP (&A68G_JOB) = genie_slice (p);
         break;
       }
     case DENOTATION: {
-        GLOBAL_PROP (&A68_JOB) = genie_denotation (p);
+        GLOBAL_PROP (&A68G_JOB) = genie_denotation (p);
         break;
       }
     case CAST: {
-        GLOBAL_PROP (&A68_JOB) = genie_cast (p);
+        GLOBAL_PROP (&A68G_JOB) = genie_cast (p);
         break;
       }
     case FORMAT_TEXT: {
-        GLOBAL_PROP (&A68_JOB) = genie_format_text (p);
+        GLOBAL_PROP (&A68G_JOB) = genie_format_text (p);
         break;
       }
 // Ex secondary.
     case GENERATOR: {
-        GLOBAL_PROP (&A68_JOB) = genie_generator (p);
+        GLOBAL_PROP (&A68G_JOB) = genie_generator (p);
         break;
       }
     case SELECTION: {
-        GLOBAL_PROP (&A68_JOB) = genie_selection (p);
+        GLOBAL_PROP (&A68G_JOB) = genie_selection (p);
         break;
       }
 // Ex tertiary.
     case FORMULA: {
-        GLOBAL_PROP (&A68_JOB) = genie_formula (p);
+        GLOBAL_PROP (&A68G_JOB) = genie_formula (p);
         break;
       }
     case MONADIC_FORMULA: {
-        GLOBAL_PROP (&A68_JOB) = genie_monadic (p);
+        GLOBAL_PROP (&A68G_JOB) = genie_monadic (p);
         break;
       }
     case NIHIL: {
-        GLOBAL_PROP (&A68_JOB) = genie_nihil (p);
+        GLOBAL_PROP (&A68G_JOB) = genie_nihil (p);
         break;
       }
     case DIAGONAL_FUNCTION: {
-        GLOBAL_PROP (&A68_JOB) = genie_diagonal_function (p);
+        GLOBAL_PROP (&A68G_JOB) = genie_diagonal_function (p);
         break;
       }
     case TRANSPOSE_FUNCTION: {
-        GLOBAL_PROP (&A68_JOB) = genie_transpose_function (p);
+        GLOBAL_PROP (&A68G_JOB) = genie_transpose_function (p);
         break;
       }
     case ROW_FUNCTION: {
-        GLOBAL_PROP (&A68_JOB) = genie_row_function (p);
+        GLOBAL_PROP (&A68G_JOB) = genie_row_function (p);
         break;
       }
     case COLUMN_FUNCTION: {
-        GLOBAL_PROP (&A68_JOB) = genie_column_function (p);
+        GLOBAL_PROP (&A68G_JOB) = genie_column_function (p);
         break;
       }
 // Ex unit.
     case ASSIGNATION: {
-        GLOBAL_PROP (&A68_JOB) = genie_assignation (p);
+        GLOBAL_PROP (&A68G_JOB) = genie_assignation (p);
         break;
       }
     case IDENTITY_RELATION: {
-        GLOBAL_PROP (&A68_JOB) = genie_identity_relation (p);
+        GLOBAL_PROP (&A68G_JOB) = genie_identity_relation (p);
         break;
       }
     case ROUTINE_TEXT: {
-        GLOBAL_PROP (&A68_JOB) = genie_routine_text (p);
+        GLOBAL_PROP (&A68G_JOB) = genie_routine_text (p);
         break;
       }
     case SKIP: {
-        GLOBAL_PROP (&A68_JOB) = genie_skip (p);
+        GLOBAL_PROP (&A68G_JOB) = genie_skip (p);
         break;
       }
     case JUMP: {
-        UNIT (&GLOBAL_PROP (&A68_JOB)) = genie_unit;
-        SOURCE (&GLOBAL_PROP (&A68_JOB)) = p;
+        UNIT (&GLOBAL_PROP (&A68G_JOB)) = genie_unit;
+        SOURCE (&GLOBAL_PROP (&A68G_JOB)) = p;
         genie_jump (p);
         break;
       }
     case AND_FUNCTION: {
-        GLOBAL_PROP (&A68_JOB) = genie_and_function (p);
+        GLOBAL_PROP (&A68G_JOB) = genie_and_function (p);
         break;
       }
     case OR_FUNCTION: {
-        GLOBAL_PROP (&A68_JOB) = genie_or_function (p);
+        GLOBAL_PROP (&A68G_JOB) = genie_or_function (p);
         break;
       }
     case ASSERTION: {
-        GLOBAL_PROP (&A68_JOB) = genie_assertion (p);
+        GLOBAL_PROP (&A68G_JOB) = genie_assertion (p);
         break;
       }
     case CODE_CLAUSE: {
-        diagnostic (A68_RUNTIME_ERROR, p, ERROR_CODE);
-        exit_genie (p, A68_RUNTIME_ERROR);
+        diagnostic (A68G_RUNTIME_ERROR, p, ERROR_CODE);
+        exit_genie (p, A68G_RUNTIME_ERROR);
         break;
       }
     }
   }
-  return GPROP (p) = GLOBAL_PROP (&A68_JOB);
+  return GPROP (p) = GLOBAL_PROP (&A68G_JOB);
 }
 
 //! @brief Execution of serial clause without labels.
@@ -232,7 +232,7 @@ void genie_serial_units_no_label (NODE_T * p, ADDR_T pop_sp, NODE_T ** seq)
       }
     case SEMI_SYMBOL: {
 // Voiden the expression stack.
-        A68_SP = pop_sp;
+        A68G_SP = pop_sp;
         SEQUENCE (*seq) = p;
         (*seq) = p;
         break;
@@ -272,7 +272,7 @@ void genie_serial_units (NODE_T * p, NODE_T ** jump_to, jmp_buf * exit_buf, ADDR
     case SEMI_SYMBOL: {
         if (*jump_to == NO_NODE) {
 // Voiden the expression stack.
-          A68_SP = pop_sp;
+          A68G_SP = pop_sp;
         }
         break;
       }
@@ -294,7 +294,7 @@ void genie_serial_clause (NODE_T * p, jmp_buf * exit_buf)
       NODE_T top_seq; GINFO_T g; NODE_T *seq = &top_seq;
       GINFO (seq) = &g;
       SEQUENCE (seq) = NO_NODE;
-      genie_serial_units_no_label (SUB (p), A68_SP, &seq);
+      genie_serial_units_no_label (SUB (p), A68G_SP, &seq);
       SEQUENCE (p) = SEQUENCE (&top_seq);
       STATUS_SET (p, SEQUENCE_MASK);
       STATUS_SET (p, SERIAL_MASK);
@@ -303,7 +303,7 @@ void genie_serial_clause (NODE_T * p, jmp_buf * exit_buf)
       }
     } else {
 // A linear list without labels.
-      ADDR_T pop_sp = A68_SP;
+      ADDR_T pop_sp = A68G_SP;
       STATUS_SET (p, SERIAL_CLAUSE);
       for (NODE_T *q = SEQUENCE (p); q != NO_NODE; q = SEQUENCE (q)) {
         switch (ATTRIBUTE (q)) {
@@ -313,7 +313,7 @@ void genie_serial_clause (NODE_T * p, jmp_buf * exit_buf)
             break;
           }
         case SEMI_SYMBOL: {
-            A68_SP = pop_sp;
+            A68G_SP = pop_sp;
             break;
           }
         }
@@ -322,19 +322,19 @@ void genie_serial_clause (NODE_T * p, jmp_buf * exit_buf)
   } else {
 // Labels in this clause.
     jmp_buf jump_stat;
-    ADDR_T pop_sp = A68_SP, pop_fp = A68_FP;
-    ADDR_T pop_dns = FRAME_DNS (A68_FP);
-    FRAME_JUMP_STAT (A68_FP) = &jump_stat;
+    ADDR_T pop_sp = A68G_SP, pop_fp = A68G_FP;
+    ADDR_T pop_dns = FRAME_DNS (A68G_FP);
+    FRAME_JUMP_STAT (A68G_FP) = &jump_stat;
     if (!setjmp (jump_stat)) {
       NODE_T *jump_to = NO_NODE;
-      genie_serial_units (SUB (p), &jump_to, exit_buf, A68_SP);
+      genie_serial_units (SUB (p), &jump_to, exit_buf, A68G_SP);
     } else {
 // HIjol! Restore state and look for indicated unit.
       NODE_T *jump_to = JUMP_TO (TABLE (p));
-      A68_SP = pop_sp;
-      A68_FP = pop_fp;
-      FRAME_DNS (A68_FP) = pop_dns;
-      genie_serial_units (SUB (p), &jump_to, exit_buf, A68_SP);
+      A68G_SP = pop_sp;
+      A68G_FP = pop_fp;
+      FRAME_DNS (A68G_FP) = pop_dns;
+      genie_serial_units (SUB (p), &jump_to, exit_buf, A68G_SP);
     }
   }
 }
@@ -349,7 +349,7 @@ void genie_enquiry_clause (NODE_T * p)
     NODE_T *seq = &top_seq;
     GINFO (seq) = &g;
     SEQUENCE (seq) = NO_NODE;
-    genie_serial_units_no_label (SUB (p), A68_SP, &seq);
+    genie_serial_units_no_label (SUB (p), A68G_SP, &seq);
     SEQUENCE (p) = SEQUENCE (&top_seq);
     STATUS_SET (p, SEQUENCE_MASK);
     if (SEQUENCE (p) != NO_NODE && SEQUENCE (SEQUENCE (p)) == NO_NODE) {
@@ -357,7 +357,7 @@ void genie_enquiry_clause (NODE_T * p)
     }
   } else {
 // A linear list without labels (enquiry clause).
-    ADDR_T pop_sp = A68_SP;
+    ADDR_T pop_sp = A68G_SP;
     STATUS_SET (p, SERIAL_MASK);
     for (NODE_T *q = SEQUENCE (p); q != NO_NODE; q = SEQUENCE (q)) {
       switch (ATTRIBUTE (q)) {
@@ -367,7 +367,7 @@ void genie_enquiry_clause (NODE_T * p)
           break;
         }
       case SEMI_SYMBOL: {
-          A68_SP = pop_sp;
+          A68G_SP = pop_sp;
           break;
         }
       }
@@ -382,7 +382,7 @@ void genie_collateral_units (NODE_T * p, int *count)
   for (; p != NO_NODE; FORWARD (p)) {
     if (IS (p, UNIT)) {
       GENIE_UNIT_TRACE (p);
-      STACK_DNS (p, MOID (p), FRAME_DNS (A68_FP));
+      STACK_DNS (p, MOID (p), FRAME_DNS (A68G_FP));
       (*count)++;
       return;
     } else {
@@ -402,28 +402,28 @@ PROP_T genie_collateral (NODE_T * p)
     genie_collateral_units (SUB (p), &count);
   } else {
 // Row display.
-    A68_REF new_display;
+    A68G_REF new_display;
     int count = 0;
-    ADDR_T pop_sp = A68_SP;
+    ADDR_T pop_sp = A68G_SP;
     MOID_T *m = MOID (p);
     genie_collateral_units (SUB (p), &count);
 // [] AMODE vacuum.
     if (count == 0) {
-      A68_SP = pop_sp;
-      INCREMENT_STACK_POINTER (p, A68_REF_SIZE);
-      *(A68_REF *) STACK_ADDRESS (pop_sp) = empty_row (p, m);
+      A68G_SP = pop_sp;
+      INCREMENT_STACK_POINTER (p, A68G_REF_SIZE);
+      *(A68G_REF *) STACK_ADDRESS (pop_sp) = empty_row (p, m);
     } else if (DIM (DEFLEX (m)) == 1) {
 // [] AMODE display.
       new_display = genie_make_row (p, SLICE (DEFLEX (m)), count, pop_sp);
-      A68_SP = pop_sp;
-      INCREMENT_STACK_POINTER (p, A68_REF_SIZE);
-      *(A68_REF *) STACK_ADDRESS (pop_sp) = new_display;
+      A68G_SP = pop_sp;
+      INCREMENT_STACK_POINTER (p, A68G_REF_SIZE);
+      *(A68G_REF *) STACK_ADDRESS (pop_sp) = new_display;
     } else {
 // [,,] AMODE display, we concatenate 1 + (n-1) to n dimensions.
       new_display = genie_make_rowrow (p, m, count, pop_sp);
-      A68_SP = pop_sp;
-      INCREMENT_STACK_POINTER (p, A68_REF_SIZE);
-      *(A68_REF *) STACK_ADDRESS (pop_sp) = new_display;
+      A68G_SP = pop_sp;
+      INCREMENT_STACK_POINTER (p, A68G_REF_SIZE);
+      *(A68G_REF *) STACK_ADDRESS (pop_sp) = new_display;
     }
   }
   UNIT (&self) = genie_collateral;
@@ -436,19 +436,19 @@ PROP_T genie_collateral (NODE_T * p)
 BOOL_T genie_int_case_unit (NODE_T * p, int k, int *count)
 {
   if (p == NO_NODE) {
-    return A68_FALSE;
+    return A68G_FALSE;
   } else {
     if (IS (p, UNIT)) {
       if (k == *count) {
         GENIE_UNIT_TRACE (p);
-        return A68_TRUE;
+        return A68G_TRUE;
       } else {
         (*count)++;
-        return A68_FALSE;
+        return A68G_FALSE;
       }
     } else {
       if (genie_int_case_unit (SUB (p), k, count)) {
-        return A68_TRUE;
+        return A68G_TRUE;
       } else {
         return genie_int_case_unit (NEXT (p), k, count);
       }
@@ -461,7 +461,7 @@ BOOL_T genie_int_case_unit (NODE_T * p, int k, int *count)
 BOOL_T genie_united_case_unit (NODE_T * p, MOID_T * m)
 {
   if (p == NO_NODE) {
-    return A68_FALSE;
+    return A68G_FALSE;
   } else {
     if (IS (p, SPECIFIER)) {
       MOID_T *spec_moid = MOID (NEXT_SUB (p));
@@ -473,7 +473,7 @@ BOOL_T genie_united_case_unit (NODE_T * p, MOID_T * m)
           equal_modes = (BOOL_T) (m == spec_moid);
         }
       } else {
-        equal_modes = A68_FALSE;
+        equal_modes = A68G_FALSE;
       }
       if (equal_modes) {
         NODE_T *q = NEXT_NEXT (SUB (p));
@@ -483,18 +483,18 @@ BOOL_T genie_united_case_unit (NODE_T * p, MOID_T * m)
           if (IS_UNION (spec_moid)) {
             COPY ((FRAME_OBJECT (OFFSET (TAX (q)))), STACK_TOP, SIZE (spec_moid));
           } else {
-            COPY ((FRAME_OBJECT (OFFSET (TAX (q)))), STACK_OFFSET (A68_UNION_SIZE), SIZE (spec_moid));
+            COPY ((FRAME_OBJECT (OFFSET (TAX (q)))), STACK_OFFSET (A68G_UNION_SIZE), SIZE (spec_moid));
           }
         }
         GENIE_UNIT_TRACE (NEXT_NEXT (p));
         CLOSE_FRAME;
-        return A68_TRUE;
+        return A68G_TRUE;
       } else {
-        return A68_FALSE;
+        return A68G_FALSE;
       }
     } else {
       if (genie_united_case_unit (SUB (p), m)) {
-        return A68_TRUE;
+        return A68G_TRUE;
       } else {
         return genie_united_case_unit (NEXT (p), m);
       }
@@ -509,7 +509,7 @@ PROP_T genie_int_case (volatile NODE_T * p)
   volatile int unit_count;
   volatile BOOL_T found_unit;
   jmp_buf exit_buf;
-  A68_INT k;
+  A68G_INT k;
   volatile NODE_T *q = SUB (p);
   volatile MOID_T *yield = MOID (q);
 // CASE or OUSE.
@@ -517,7 +517,7 @@ PROP_T genie_int_case (volatile NODE_T * p)
   INIT_GLOBAL_POINTER ((NODE_T *) SUB (q));
   INIT_STATIC_FRAME ((NODE_T *) SUB (q));
   ENQUIRY_CLAUSE (NEXT_SUB (q));
-  POP_OBJECT (q, &k, A68_INT);
+  POP_OBJECT (q, &k, A68G_INT);
 // IN.
   FORWARD (q);
   OPEN_STATIC_FRAME ((NODE_T *) SUB (q));
@@ -560,7 +560,7 @@ PROP_T genie_int_case (volatile NODE_T * p)
 
 PROP_T genie_united_case (volatile NODE_T * p)
 {
-  volatile BOOL_T found_unit = A68_FALSE;
+  volatile BOOL_T found_unit = A68G_FALSE;
   volatile MOID_T *um;
   volatile ADDR_T pop_sp;
   jmp_buf exit_buf;
@@ -570,10 +570,10 @@ PROP_T genie_united_case (volatile NODE_T * p)
   OPEN_STATIC_FRAME ((NODE_T *) SUB (q));
   INIT_GLOBAL_POINTER ((NODE_T *) SUB (q));
   INIT_STATIC_FRAME ((NODE_T *) SUB (q));
-  pop_sp = A68_SP;
+  pop_sp = A68G_SP;
   ENQUIRY_CLAUSE (NEXT_SUB (q));
-  A68_SP = pop_sp;
-  um = (volatile MOID_T *) VALUE ((A68_UNION *) STACK_TOP);
+  A68G_SP = pop_sp;
+  um = (volatile MOID_T *) VALUE ((A68G_UNION *) STACK_TOP);
 // IN.
   FORWARD (q);
   if (um != NO_MOID) {
@@ -582,7 +582,7 @@ PROP_T genie_united_case (volatile NODE_T * p)
     found_unit = genie_united_case_unit (NEXT_SUB ((NODE_T *) q), (MOID_T *) um);
     CLOSE_FRAME;
   } else {
-    found_unit = A68_FALSE;
+    found_unit = A68G_FALSE;
   }
 // OUT.
   if (!found_unit) {
@@ -619,7 +619,7 @@ PROP_T genie_united_case (volatile NODE_T * p)
 
 PROP_T genie_conditional (volatile NODE_T * p)
 {
-  volatile ADDR_T pop_sp = A68_SP;
+  volatile ADDR_T pop_sp = A68G_SP;
   jmp_buf exit_buf;
   volatile NODE_T *q = SUB (p);
   volatile MOID_T *yield = MOID (q);
@@ -628,9 +628,9 @@ PROP_T genie_conditional (volatile NODE_T * p)
   INIT_GLOBAL_POINTER ((NODE_T *) SUB (q));
   INIT_STATIC_FRAME ((NODE_T *) SUB (q));
   ENQUIRY_CLAUSE (NEXT_SUB (q));
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   FORWARD (q);
-  if (VALUE ((A68_BOOL *) STACK_TOP) == A68_TRUE) {
+  if (VALUE ((A68G_BOOL *) STACK_TOP) == A68G_TRUE) {
 // THEN.
     OPEN_STATIC_FRAME ((NODE_T *) SUB (q));
     INIT_STATIC_FRAME ((NODE_T *) SUB (q));
@@ -682,7 +682,7 @@ PROP_T genie_conditional (volatile NODE_T * p)
 
 PROP_T genie_loop (volatile NODE_T * p)
 {
-  volatile ADDR_T pop_sp = A68_SP;
+  volatile ADDR_T pop_sp = A68G_SP;
   volatile INT_T from, by, to, counter;
   volatile BOOL_T siga, conditional;
   volatile NODE_T *for_part = NO_NODE, *to_part = NO_NODE, *q = NO_NODE;
@@ -695,8 +695,8 @@ PROP_T genie_loop (volatile NODE_T * p)
 // FROM unit.
   if (IS (p, FROM_PART)) {
     GENIE_UNIT (NEXT_SUB (p));
-    A68_SP = pop_sp;
-    from = VALUE ((A68_INT *) STACK_TOP);
+    A68G_SP = pop_sp;
+    from = VALUE ((A68G_INT *) STACK_TOP);
     FORWARD (p);
   } else {
     from = 1;
@@ -704,8 +704,8 @@ PROP_T genie_loop (volatile NODE_T * p)
 // BY unit.
   if (IS (p, BY_PART)) {
     GENIE_UNIT (NEXT_SUB (p));
-    A68_SP = pop_sp;
-    by = VALUE ((A68_INT *) STACK_TOP);
+    A68G_SP = pop_sp;
+    by = VALUE ((A68G_INT *) STACK_TOP);
     FORWARD (p);
   } else {
     by = 1;
@@ -716,12 +716,12 @@ PROP_T genie_loop (volatile NODE_T * p)
       by = -by;
     }
     GENIE_UNIT (NEXT_SUB (p));
-    A68_SP = pop_sp;
-    to = VALUE ((A68_INT *) STACK_TOP);
+    A68G_SP = pop_sp;
+    to = VALUE ((A68G_INT *) STACK_TOP);
     to_part = p;
     FORWARD (p);
   } else {
-    to = (by >= 0 ? A68_MAX_INT : -A68_MAX_INT);
+    to = (by >= 0 ? A68G_MAX_INT : -A68G_MAX_INT);
   }
   q = NEXT_SUB (p);
 // Here the loop part starts.
@@ -732,7 +732,7 @@ PROP_T genie_loop (volatile NODE_T * p)
   counter = from;
 // Does the loop contain conditionals?.
   if (IS (p, WHILE_PART)) {
-    conditional = A68_TRUE;
+    conditional = A68G_TRUE;
   } else if (IS (p, DO_PART) || IS (p, ALT_DO_PART)) {
     NODE_T *until_part = NEXT_SUB (p);
     if (IS (until_part, SERIAL_CLAUSE)) {
@@ -740,22 +740,22 @@ PROP_T genie_loop (volatile NODE_T * p)
     }
     conditional = (BOOL_T) (until_part != NO_NODE && IS (until_part, UNTIL_PART));
   } else {
-    conditional = A68_FALSE;
+    conditional = A68G_FALSE;
   }
   if (conditional) {
 // [FOR ...] [WHILE ...] DO [...] [UNTIL ...] OD.
     siga = (BOOL_T) ((by > 0 && counter <= to) || (by < 0 && counter >= to) || (by == 0));
     while (siga) {
       if (for_part != NO_NODE) {
-        A68_INT *z = (A68_INT *) (FRAME_OBJECT (OFFSET (TAX (for_part))));
+        A68G_INT *z = (A68G_INT *) (FRAME_OBJECT (OFFSET (TAX (for_part))));
         STATUS (z) = INIT_MASK;
         VALUE (z) = counter;
       }
-      A68_SP = pop_sp;
+      A68G_SP = pop_sp;
       if (IS (p, WHILE_PART)) {
         ENQUIRY_CLAUSE (q);
-        A68_SP = pop_sp;
-        siga = (BOOL_T) (VALUE ((A68_BOOL *) STACK_TOP) != A68_FALSE);
+        A68G_SP = pop_sp;
+        siga = (BOOL_T) (VALUE ((A68G_BOOL *) STACK_TOP) != A68G_FALSE);
       }
       if (siga) {
         volatile NODE_T *do_part = p, *until_part;
@@ -777,10 +777,10 @@ PROP_T genie_loop (volatile NODE_T * p)
           NODE_T *v = NEXT_SUB (until_part);
           OPEN_STATIC_FRAME ((NODE_T *) v);
           INIT_STATIC_FRAME ((NODE_T *) v);
-          A68_SP = pop_sp;
+          A68G_SP = pop_sp;
           ENQUIRY_CLAUSE (v);
-          A68_SP = pop_sp;
-          siga = (BOOL_T) (VALUE ((A68_BOOL *) STACK_TOP) == A68_FALSE);
+          A68G_SP = pop_sp;
+          siga = (BOOL_T) (VALUE ((A68G_BOOL *) STACK_TOP) == A68G_FALSE);
           CLOSE_FRAME;
         }
         if (IS (p, WHILE_PART)) {
@@ -805,11 +805,11 @@ PROP_T genie_loop (volatile NODE_T * p)
     siga = (BOOL_T) ((by > 0 && counter <= to) || (by < 0 && counter >= to) || (by == 0));
     while (siga) {
       if (for_part != NO_NODE) {
-        A68_INT *z = (A68_INT *) (FRAME_OBJECT (OFFSET (TAX (for_part))));
+        A68G_INT *z = (A68G_INT *) (FRAME_OBJECT (OFFSET (TAX (for_part))));
         STATUS (z) = INIT_MASK;
         VALUE (z) = counter;
       }
-      A68_SP = pop_sp;
+      A68G_SP = pop_sp;
       SERIAL_CLAUSE (q);
       INCREMENT_COUNTER;
       siga = (BOOL_T) ((by > 0 && counter <= to) || (by < 0 && counter >= to) || (by == 0));
@@ -824,7 +824,7 @@ PROP_T genie_loop (volatile NODE_T * p)
   }
 // OD.
   CLOSE_FRAME;
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   return GPROP (p);
 }
 
