@@ -293,12 +293,12 @@ PROP_T genie_selection_value_quick (NODE_T * p)
   NODE_T *selector = SUB (p);
   MOID_T *result_mode = MOID (selector);
   ADDR_T pop_sp = A68G_SP;
-  int size = SIZE (result_mode);
+  size_t size = SIZE (result_mode);
   INT_T offset = OFFSET (NODE_PACK (SUB (selector)));
   GENIE_UNIT_NO_GC (NEXT (selector));
   A68G_SP = pop_sp;
   if (offset > 0) {
-    MOVE (STACK_TOP, STACK_OFFSET (offset), (unt) size);
+    MOVE (STACK_TOP, STACK_OFFSET (offset), size);
     genie_check_initialisation (p, STACK_TOP, result_mode);
   }
   INCREMENT_STACK_POINTER (selector, size);
@@ -336,9 +336,9 @@ PROP_T genie_selection (NODE_T * p)
     CHECK_REF (p, *r_src, m_str);
     r_src = DEREF (A68G_REF, r_src);
     int dim = DIM (DEFLEX (SUB (m_str)));
-    int d_size = DESCRIPTOR_SIZE (dim);
+    size_t d_size = DESCRIPTOR_SIZE (dim);
     A68G_REF r_dst = heap_generator (select, m_sel, d_size);
-    MOVE (ADDRESS (&r_dst), DEREF (BYTE_T, r_src), (unt) d_size);
+    MOVE (ADDRESS (&r_dst), DEREF (BYTE_T, r_src), d_size);
     MOID ((DEREF (A68G_ARRAY, &r_dst))) = SUB_SUB (m_sel);
     FIELD_OFFSET (DEREF (A68G_ARRAY, &r_dst)) += OFFSET (NODE_PACK (SUB (select)));
     A68G_REF r_sel = heap_generator (select, m_sel, A68G_REF_SIZE);
@@ -349,9 +349,9 @@ PROP_T genie_selection (NODE_T * p)
     A68G_REF *r_src;
     POP_ADDRESS (select, r_src, A68G_REF);
     int dim = DIM (DEFLEX (m_str));
-    int d_size = DESCRIPTOR_SIZE (dim);
+    size_t d_size = DESCRIPTOR_SIZE (dim);
     A68G_REF r_dst = heap_generator (select, m_sel, d_size);
-    MOVE (ADDRESS (&r_dst), DEREF (BYTE_T, r_src), (unt) d_size);
+    MOVE (ADDRESS (&r_dst), DEREF (BYTE_T, r_src), d_size);
     MOID ((DEREF (A68G_ARRAY, &r_dst))) = SUB (m_sel);
     FIELD_OFFSET (DEREF (A68G_ARRAY, &r_dst)) += OFFSET (NODE_PACK (SUB (select)));
     PUSH_REF (select, r_dst);
@@ -365,7 +365,7 @@ PROP_T genie_selection (NODE_T * p)
     UNIT (&self) = genie_selection_name_quick;
   } else if (IS_STRUCT (m_str)) {
     DECREMENT_STACK_POINTER (select, SIZE (m_str));
-    MOVE (STACK_TOP, STACK_OFFSET (OFFSET (NODE_PACK (SUB (select)))), (unt) SIZE (m_sel));
+    MOVE (STACK_TOP, STACK_OFFSET (OFFSET (NODE_PACK (SUB (select)))), SIZE (m_sel));
     genie_check_initialisation (p, STACK_TOP, m_sel);
     INCREMENT_STACK_POINTER (select, SIZE (m_sel));
     UNIT (&self) = genie_selection_value_quick;
@@ -391,7 +391,7 @@ PROP_T genie_field_selection (NODE_T * p)
     BOOL_T coerce = A68G_TRUE;
     while (coerce) {
       if (IS_REF (m) && ISNT (SUB (m), STRUCT_SYMBOL)) {
-        int size = SIZE (SUB (m));
+        size_t size = SIZE (SUB (m));
         A68G_SP = pop_sp;
         CHECK_REF (p, *z, m);
         PUSH (p, ADDRESS (z), size);
@@ -411,7 +411,7 @@ PROP_T genie_field_selection (NODE_T * p)
       OFFSET (z) += OFFSET (NODE_PACK (p));
     } else if (IS_STRUCT (m)) {
       A68G_SP = pop_sp;
-      MOVE (STACK_TOP, STACK_OFFSET (OFFSET (NODE_PACK (p))), (unt) SIZE (m_sel));
+      MOVE (STACK_TOP, STACK_OFFSET (OFFSET (NODE_PACK (p))), SIZE (m_sel));
       INCREMENT_STACK_POINTER (p, SIZE (m_sel));
     }
   }
