@@ -42,9 +42,9 @@ void genie_directory (NODE_T * p)
   A68G_REF name;
   POP_REF (p, &name);
   CHECK_INIT (p, INITIALISED (&name), M_STRING);
-  char *buffer = (char *) a68g_alloc ((size_t) (1 + a68g_string_size (p, name)), __func__, __LINE__);
+  char *buffer = (char *) a68g_alloc (1 + a68g_string_size (p, name), __func__, __LINE__);
   if (buffer == NO_TEXT) {
-    diagnostic (A68G_RUNTIME_ERROR, p, ERROR_OUT_OF_CORE);
+    diagnostic (A68G_RUNTIME_ERROR, p, ERROR_MEMORY_FULL);
     exit_genie (p, A68G_RUNTIME_ERROR);
     PUSH_VALUE (p, A68G_MAX_INT, A68G_INT);
   } else {
@@ -174,8 +174,8 @@ void genie_argv (NODE_T * p)
   POP_OBJECT (p, &a68g_index, A68G_INT);
   if (VALUE (&a68g_index) >= 1 && VALUE (&a68g_index) <= A68G (argc)) {
     char *q = A68G (argv)[VALUE (&a68g_index) - 1];
-    int n = (int) strlen (q);
 // Allow for spaces ending in # to have A68 comment syntax with '#!'.
+    size_t n = strlen (q);
     while (n > 0 && (IS_SPACE (q[n - 1]) || q[n - 1] == '#')) {
       q[--n] = NULL_CHAR;
     }
@@ -228,8 +228,8 @@ void genie_a68g_argv (NODE_T * p)
   }
   if (k >= 1 && k <= A68G (argc)) {
     char *q = A68G (argv)[k - 1];
-    int n = (int) strlen (q);
 // Allow for spaces ending in # to have A68 comment syntax with '#!'.
+    size_t n = strlen (q);
     while (n > 0 && (IS_SPACE (q[n - 1]) || q[n - 1] == '#')) {
       q[--n] = NULL_CHAR;
     }
@@ -250,7 +250,7 @@ void genie_pwd (NODE_T * p)
   while (cont) {
     buffer = (char *) a68g_alloc (size, __func__, __LINE__);
     if (buffer == NO_TEXT) {
-      diagnostic (A68G_RUNTIME_ERROR, p, ERROR_OUT_OF_CORE);
+      diagnostic (A68G_RUNTIME_ERROR, p, ERROR_MEMORY_FULL);
       exit_genie (p, A68G_RUNTIME_ERROR);
     }
     if (getcwd (buffer, size) == buffer) {
@@ -277,9 +277,9 @@ void genie_cd (NODE_T * p)
   A68G_REF dir;
   POP_REF (p, &dir);
   CHECK_INIT (p, INITIALISED (&dir), M_STRING);
-  char *buffer = (char *) a68g_alloc ((size_t) (1 + a68g_string_size (p, dir)), __func__, __LINE__);
+  char *buffer = (char *) a68g_alloc (1 + a68g_string_size (p, dir), __func__, __LINE__);
   if (buffer == NO_TEXT) {
-    diagnostic (A68G_RUNTIME_ERROR, p, ERROR_OUT_OF_CORE);
+    diagnostic (A68G_RUNTIME_ERROR, p, ERROR_MEMORY_FULL);
     exit_genie (p, A68G_RUNTIME_ERROR);
   } else {
     int ret = chdir (a_to_c_string (p, buffer, dir));
@@ -301,9 +301,9 @@ void genie_file_mode (NODE_T * p)
   A68G_REF name;
   POP_REF (p, &name);
   CHECK_INIT (p, INITIALISED (&name), M_STRING);
-  char *buffer = (char *) a68g_alloc ((size_t) (1 + a68g_string_size (p, name)), __func__, __LINE__);
+  char *buffer = (char *) a68g_alloc (1 + a68g_string_size (p, name), __func__, __LINE__);
   if (buffer == NO_TEXT) {
-    diagnostic (A68G_RUNTIME_ERROR, p, ERROR_OUT_OF_CORE);
+    diagnostic (A68G_RUNTIME_ERROR, p, ERROR_MEMORY_FULL);
     exit_genie (p, A68G_RUNTIME_ERROR);
   } else {
     struct stat status;
@@ -324,9 +324,9 @@ void genie_file_is_block_device (NODE_T * p)
   A68G_REF name;
   POP_REF (p, &name);
   CHECK_INIT (p, INITIALISED (&name), M_STRING);
-  char *buffer = (char *) a68g_alloc ((size_t) (1 + a68g_string_size (p, name)), __func__, __LINE__);
+  char *buffer = (char *) a68g_alloc (1 + a68g_string_size (p, name), __func__, __LINE__);
   if (buffer == NO_TEXT) {
-    diagnostic (A68G_RUNTIME_ERROR, p, ERROR_OUT_OF_CORE);
+    diagnostic (A68G_RUNTIME_ERROR, p, ERROR_MEMORY_FULL);
     exit_genie (p, A68G_RUNTIME_ERROR);
   } else {
     struct stat status;
@@ -347,9 +347,9 @@ void genie_file_is_char_device (NODE_T * p)
   A68G_REF name;
   POP_REF (p, &name);
   CHECK_INIT (p, INITIALISED (&name), M_STRING);
-  char *buffer = (char *) a68g_alloc ((size_t) (1 + a68g_string_size (p, name)), __func__, __LINE__);
+  char *buffer = (char *) a68g_alloc (1 + a68g_string_size (p, name), __func__, __LINE__);
   if (buffer == NO_TEXT) {
-    diagnostic (A68G_RUNTIME_ERROR, p, ERROR_OUT_OF_CORE);
+    diagnostic (A68G_RUNTIME_ERROR, p, ERROR_MEMORY_FULL);
     exit_genie (p, A68G_RUNTIME_ERROR);
   } else {
     struct stat status;
@@ -370,9 +370,9 @@ void genie_file_is_directory (NODE_T * p)
   A68G_REF name;
   POP_REF (p, &name);
   CHECK_INIT (p, INITIALISED (&name), M_STRING);
-  char *buffer = (char *) a68g_alloc ((size_t) (1 + a68g_string_size (p, name)), __func__, __LINE__);
+  char *buffer = (char *) a68g_alloc (1 + a68g_string_size (p, name), __func__, __LINE__);
   if (buffer == NO_TEXT) {
-    diagnostic (A68G_RUNTIME_ERROR, p, ERROR_OUT_OF_CORE);
+    diagnostic (A68G_RUNTIME_ERROR, p, ERROR_MEMORY_FULL);
     exit_genie (p, A68G_RUNTIME_ERROR);
   } else {
     struct stat status;
@@ -393,9 +393,9 @@ void genie_file_is_regular (NODE_T * p)
   A68G_REF name;
   POP_REF (p, &name);
   CHECK_INIT (p, INITIALISED (&name), M_STRING);
-  char *buffer = (char *) a68g_alloc ((size_t) (1 + a68g_string_size (p, name)), __func__, __LINE__);
+  char *buffer = (char *) a68g_alloc (1 + a68g_string_size (p, name), __func__, __LINE__);
   if (buffer == NO_TEXT) {
-    diagnostic (A68G_RUNTIME_ERROR, p, ERROR_OUT_OF_CORE);
+    diagnostic (A68G_RUNTIME_ERROR, p, ERROR_MEMORY_FULL);
     exit_genie (p, A68G_RUNTIME_ERROR);
   } else {
     struct stat status;
@@ -418,9 +418,9 @@ void genie_file_is_fifo (NODE_T * p)
   A68G_REF name;
   POP_REF (p, &name);
   CHECK_INIT (p, INITIALISED (&name), M_STRING);
-  char *buffer = (char *) a68g_alloc ((size_t) (1 + a68g_string_size (p, name)), __func__, __LINE__);
+  char *buffer = (char *) a68g_alloc (1 + a68g_string_size (p, name), __func__, __LINE__);
   if (buffer == NO_TEXT) {
-    diagnostic (A68G_RUNTIME_ERROR, p, ERROR_OUT_OF_CORE);
+    diagnostic (A68G_RUNTIME_ERROR, p, ERROR_MEMORY_FULL);
     exit_genie (p, A68G_RUNTIME_ERROR);
   } else {
     struct stat status;
@@ -445,9 +445,9 @@ void genie_file_is_link (NODE_T * p)
   A68G_REF name;
   POP_REF (p, &name);
   CHECK_INIT (p, INITIALISED (&name), M_STRING);
-  char *buffer = (char *) a68g_alloc ((size_t) (1 + a68g_string_size (p, name)), __func__, __LINE__);
+  char *buffer = (char *) a68g_alloc (1 + a68g_string_size (p, name), __func__, __LINE__);
   if (buffer == NO_TEXT) {
-    diagnostic (A68G_RUNTIME_ERROR, p, ERROR_OUT_OF_CORE);
+    diagnostic (A68G_RUNTIME_ERROR, p, ERROR_MEMORY_FULL);
     exit_genie (p, A68G_RUNTIME_ERROR);
   } else {
     struct stat status;
@@ -478,9 +478,9 @@ void convert_string_vector (NODE_T * p, char *vec[], A68G_REF row)
       ADDR_T a68g_index = calculate_internal_index (tup, DIM (arr));
       ADDR_T elem_addr = (a68g_index + SLICE_OFFSET (arr)) * ELEM_SIZE (arr) + FIELD_OFFSET (arr);
       BYTE_T *elem = &base_addr[elem_addr];
-      int size = a68g_string_size (p, *(A68G_REF *) elem);
+      size_t size = a68g_string_size (p, *(A68G_REF *) elem);
       CHECK_INIT (p, INITIALISED ((A68G_REF *) elem), M_STRING);
-      vec[k] = (char *) get_heap_space ((size_t) (1 + size));
+      vec[k] = (char *) get_heap_space (1 + size);
       ASSERT (a_to_c_string (p, vec[k], *(A68G_REF *) elem) != NO_TEXT);
       if (k == VECTOR_SIZE - 1) {
         diagnostic (A68G_RUNTIME_ERROR, p, ERROR_TOO_MANY_ARGUMENTS);
@@ -576,7 +576,7 @@ void genie_getenv (NODE_T * p)
   A68G_REF a_env;
   POP_REF (p, &a_env);
   CHECK_INIT (p, INITIALISED (&a_env), M_STRING);
-  char *z_env = (char *) get_heap_space ((size_t) (1 + a68g_string_size (p, a_env)));
+  char *z_env = (char *) get_heap_space (1 + a68g_string_size (p, a_env));
   char *z = a_to_c_string (p, z_env, a_env);
   char *val = getenv (z);
   if (val == NO_TEXT) {
@@ -591,13 +591,13 @@ void genie_getenv (NODE_T * p)
 
 void genie_fork (NODE_T * p)
 {
-#if defined (BUILD_WIN32)
-  PUSH_VALUE (p, -1, A68G_INT);
-#else
-  errno = 0;
-  int pid = (int) fork ();
-  PUSH_VALUE (p, pid, A68G_INT);
-#endif
+  #if defined (BUILD_WIN32) || defined (BUILD_WIN64)
+    PUSH_VALUE (p, -1, A68G_INT);
+  #else
+    errno = 0;
+    int pid = (int) fork ();
+    PUSH_VALUE (p, pid, A68G_INT);
+  #endif
 }
 
 //! @brief PROC execve = (STRING, [] STRING, [] STRING) INT 
@@ -611,7 +611,7 @@ void genie_exec (NODE_T * p)
   POP_REF (p, &a_args);
   POP_REF (p, &a_prog);
 // Convert strings and hasta el infinito.
-  char *prog = (char *) get_heap_space ((size_t) (1 + a68g_string_size (p, a_prog)));
+  char *prog = (char *) get_heap_space (1 + a68g_string_size (p, a_prog));
   ASSERT (a_to_c_string (p, prog, a_prog) != NO_TEXT);
   char *argv[VECTOR_SIZE], *envp[VECTOR_SIZE];
   convert_string_vector (p, argv, a_args);
@@ -639,35 +639,35 @@ void genie_exec_sub (NODE_T * p)
   POP_REF (p, &a_args);
   POP_REF (p, &a_prog);
 // Now create the pipes and fork.
-#if defined (BUILD_WIN32)
-  int pid = -1;
-  (void) pid;
-  PUSH_VALUE (p, -1, A68G_INT);
-  return;
-#else
-  int pid = (int) fork ();
-  if (pid == -1) {
+  #if defined (BUILD_WIN32) || defined (BUILD_WIN64)
+    int pid = -1;
+    (void) pid;
     PUSH_VALUE (p, -1, A68G_INT);
-  } else if (pid == 0) {
-// Child process.
-    char *prog = (char *) get_heap_space ((size_t) (1 + a68g_string_size (p, a_prog)));
-    ASSERT (a_to_c_string (p, prog, a_prog) != NO_TEXT);
-    char *argv[VECTOR_SIZE], *envp[VECTOR_SIZE];
-    convert_string_vector (p, argv, a_args);
-    convert_string_vector (p, envp, a_env);
-    if (argv[0] == NO_TEXT) {
-      diagnostic (A68G_RUNTIME_ERROR, p, ERROR_EMPTY_ARGUMENT);
-      exit_genie (p, A68G_RUNTIME_ERROR);
+    return;
+  #else
+    int pid = (int) fork ();
+    if (pid == -1) {
+      PUSH_VALUE (p, -1, A68G_INT);
+    } else if (pid == 0) {
+  // Child process.
+      char *prog = (char *) get_heap_space (1 + a68g_string_size (p, a_prog));
+      ASSERT (a_to_c_string (p, prog, a_prog) != NO_TEXT);
+      char *argv[VECTOR_SIZE], *envp[VECTOR_SIZE];
+      convert_string_vector (p, argv, a_args);
+      convert_string_vector (p, envp, a_env);
+      if (argv[0] == NO_TEXT) {
+        diagnostic (A68G_RUNTIME_ERROR, p, ERROR_EMPTY_ARGUMENT);
+        exit_genie (p, A68G_RUNTIME_ERROR);
+      }
+      (void) execve (prog, argv, envp);
+  // execve only returns if it fails - end child process.
+      a68g_exit (EXIT_FAILURE);
+      PUSH_VALUE (p, 0, A68G_INT);
+    } else {
+  // parent process.
+      PUSH_VALUE (p, pid, A68G_INT);
     }
-    (void) execve (prog, argv, envp);
-// execve only returns if it fails - end child process.
-    a68g_exit (EXIT_FAILURE);
-    PUSH_VALUE (p, 0, A68G_INT);
-  } else {
-// parent process.
-    PUSH_VALUE (p, pid, A68G_INT);
-  }
-#endif
+  #endif
 }
 
 //! @brief PROC execve child pipe = (STRING, [] STRING, [] STRING) PIPE
@@ -687,54 +687,54 @@ void genie_exec_sub_pipeline (NODE_T * p)
   POP_REF (p, &a_env);
   POP_REF (p, &a_args);
   POP_REF (p, &a_prog);
-#if !defined (BUILD_UNIX)
-  int pid = -1;
-  (void) pid;
-  genie_mkpipe (p, -1, -1, -1);
-  return;
-#else
-// Create the pipes and fork.
-  int ptoc_fd[2], ctop_fd[2];
-  if ((pipe (ptoc_fd) == -1) || (pipe (ctop_fd) == -1)) {
+  #if !defined (BUILD_UNIX)
+    int pid = -1;
+    (void) pid;
     genie_mkpipe (p, -1, -1, -1);
     return;
-  }
-  int pid = (int) fork ();
-  if (pid == -1) {
-// Fork failure.
-    genie_mkpipe (p, -1, -1, -1);
-    return;
-  }
-  if (pid == 0) {
-// Child process.
-// Convert  strings.
-    char *prog = (char *) get_heap_space ((size_t) (1 + a68g_string_size (p, a_prog)));
-    ASSERT (a_to_c_string (p, prog, a_prog) != NO_TEXT);
-    char *argv[VECTOR_SIZE], *envp[VECTOR_SIZE];
-    convert_string_vector (p, argv, a_args);
-    convert_string_vector (p, envp, a_env);
-// Set up redirection.
-    ASSERT (close (ctop_fd[FD_READ]) == 0);
-    ASSERT (close (ptoc_fd[FD_WRITE]) == 0);
-    ASSERT (close (A68G_STDIN) == 0);
-    ASSERT (close (A68G_STDOUT) == 0);
-    ASSERT (dup2 (ptoc_fd[FD_READ], A68G_STDIN) != -1);
-    ASSERT (dup2 (ctop_fd[FD_WRITE], A68G_STDOUT) != -1);
-    if (argv[0] == NO_TEXT) {
-      diagnostic (A68G_RUNTIME_ERROR, p, ERROR_EMPTY_ARGUMENT);
-      exit_genie (p, A68G_RUNTIME_ERROR);
+  #else
+  // Create the pipes and fork.
+    int ptoc_fd[2], ctop_fd[2];
+    if ((pipe (ptoc_fd) == -1) || (pipe (ctop_fd) == -1)) {
+      genie_mkpipe (p, -1, -1, -1);
+      return;
     }
-    (void) execve (prog, argv, envp);
-// execve only returns if it fails - end child process.
-    a68g_exit (EXIT_FAILURE);
-    genie_mkpipe (p, -1, -1, -1);
-  } else {
-// Parent process.
-    ASSERT (close (ptoc_fd[FD_READ]) == 0);
-    ASSERT (close (ctop_fd[FD_WRITE]) == 0);
-    genie_mkpipe (p, ctop_fd[FD_READ], ptoc_fd[FD_WRITE], pid);
-  }
-#endif
+    int pid = (int) fork ();
+    if (pid == -1) {
+  // Fork failure.
+      genie_mkpipe (p, -1, -1, -1);
+      return;
+    }
+    if (pid == 0) {
+  // Child process.
+  // Convert  strings.
+      char *prog = (char *) get_heap_space (1 + a68g_string_size (p, a_prog));
+      ASSERT (a_to_c_string (p, prog, a_prog) != NO_TEXT);
+      char *argv[VECTOR_SIZE], *envp[VECTOR_SIZE];
+      convert_string_vector (p, argv, a_args);
+      convert_string_vector (p, envp, a_env);
+  // Set up redirection.
+      ASSERT (close (ctop_fd[FD_READ]) == 0);
+      ASSERT (close (ptoc_fd[FD_WRITE]) == 0);
+      ASSERT (close (A68G_STDIN) == 0);
+      ASSERT (close (A68G_STDOUT) == 0);
+      ASSERT (dup2 (ptoc_fd[FD_READ], A68G_STDIN) != -1);
+      ASSERT (dup2 (ctop_fd[FD_WRITE], A68G_STDOUT) != -1);
+      if (argv[0] == NO_TEXT) {
+        diagnostic (A68G_RUNTIME_ERROR, p, ERROR_EMPTY_ARGUMENT);
+        exit_genie (p, A68G_RUNTIME_ERROR);
+      }
+      (void) execve (prog, argv, envp);
+  // execve only returns if it fails - end child process.
+      a68g_exit (EXIT_FAILURE);
+      genie_mkpipe (p, -1, -1, -1);
+    } else {
+  // Parent process.
+      ASSERT (close (ptoc_fd[FD_READ]) == 0);
+      ASSERT (close (ctop_fd[FD_WRITE]) == 0);
+      genie_mkpipe (p, ctop_fd[FD_READ], ptoc_fd[FD_WRITE], pid);
+    }
+  #endif
 }
 
 //! @brief PROC execve output = (STRING, [] STRING, [] STRING, REF_STRING) INT
@@ -754,72 +754,72 @@ void genie_exec_sub_output (NODE_T * p)
   POP_REF (p, &a_env);
   POP_REF (p, &a_args);
   POP_REF (p, &a_prog);
-#if !defined (BUILD_UNIX)
-  int pid = -1;
-  (void) pid;
-  PUSH_VALUE (p, -1, A68G_INT);
-  return;
-#else
-// Create the pipes and fork.
-  int ptoc_fd[2], ctop_fd[2];
-  if ((pipe (ptoc_fd) == -1) || (pipe (ctop_fd) == -1)) {
+  #if !defined (BUILD_UNIX)
+    int pid = -1;
+    (void) pid;
     PUSH_VALUE (p, -1, A68G_INT);
     return;
-  }
-  int pid = (int) fork ();
-  if (pid == -1) {
-// Fork failure.
-    PUSH_VALUE (p, -1, A68G_INT);
-    return;
-  }
-  if (pid == 0) {
-    char *prog = (char *) get_heap_space ((size_t) (1 + a68g_string_size (p, a_prog)));
-    ASSERT (a_to_c_string (p, prog, a_prog) != NO_TEXT);
-    char *argv[VECTOR_SIZE], *envp[VECTOR_SIZE];
-    convert_string_vector (p, argv, a_args);
-    convert_string_vector (p, envp, a_env);
-// Set up redirection.
-    ASSERT (close (ctop_fd[FD_READ]) == 0);
-    ASSERT (close (ptoc_fd[FD_WRITE]) == 0);
-    ASSERT (close (A68G_STDIN) == 0);
-    ASSERT (close (A68G_STDOUT) == 0);
-    ASSERT (dup2 (ptoc_fd[FD_READ], A68G_STDIN) != -1);
-    ASSERT (dup2 (ctop_fd[FD_WRITE], A68G_STDOUT) != -1);
-    if (argv[0] == NO_TEXT) {
-      diagnostic (A68G_RUNTIME_ERROR, p, ERROR_EMPTY_ARGUMENT);
-      exit_genie (p, A68G_RUNTIME_ERROR);
+  #else
+  // Create the pipes and fork.
+    int ptoc_fd[2], ctop_fd[2];
+    if ((pipe (ptoc_fd) == -1) || (pipe (ctop_fd) == -1)) {
+      PUSH_VALUE (p, -1, A68G_INT);
+      return;
     }
-    (void) execve (prog, argv, envp);
-// execve only returns if it fails - end child process.
-    a68g_exit (EXIT_FAILURE);
-    PUSH_VALUE (p, -1, A68G_INT);
-  } else {
-// Parent process.
-    char ch;
-    ASSERT (close (ptoc_fd[FD_READ]) == 0);
-    ASSERT (close (ctop_fd[FD_WRITE]) == 0);
-    reset_transput_buffer (INPUT_BUFFER);
-    int pipe_read, ret, status;
-    do {
-      pipe_read = (int) io_read_conv (ctop_fd[FD_READ], &ch, 1);
-      if (pipe_read > 0) {
-        plusab_transput_buffer (p, INPUT_BUFFER, ch);
+    int pid = (int) fork ();
+    if (pid == -1) {
+  // Fork failure.
+      PUSH_VALUE (p, -1, A68G_INT);
+      return;
+    }
+    if (pid == 0) {
+      char *prog = (char *) get_heap_space (1 + a68g_string_size (p, a_prog));
+      ASSERT (a_to_c_string (p, prog, a_prog) != NO_TEXT);
+      char *argv[VECTOR_SIZE], *envp[VECTOR_SIZE];
+      convert_string_vector (p, argv, a_args);
+      convert_string_vector (p, envp, a_env);
+  // Set up redirection.
+      ASSERT (close (ctop_fd[FD_READ]) == 0);
+      ASSERT (close (ptoc_fd[FD_WRITE]) == 0);
+      ASSERT (close (A68G_STDIN) == 0);
+      ASSERT (close (A68G_STDOUT) == 0);
+      ASSERT (dup2 (ptoc_fd[FD_READ], A68G_STDIN) != -1);
+      ASSERT (dup2 (ctop_fd[FD_WRITE], A68G_STDOUT) != -1);
+      if (argv[0] == NO_TEXT) {
+        diagnostic (A68G_RUNTIME_ERROR, p, ERROR_EMPTY_ARGUMENT);
+        exit_genie (p, A68G_RUNTIME_ERROR);
       }
-    } while (pipe_read > 0);
-    do {
-      ret = (int) waitpid ((a68g_pid_t) pid, &status, 0);
-    } while (ret == -1 && errno == EINTR);
-    if (ret != pid) {
-      status = -1;
+      (void) execve (prog, argv, envp);
+  // execve only returns if it fails - end child process.
+      a68g_exit (EXIT_FAILURE);
+      PUSH_VALUE (p, -1, A68G_INT);
+    } else {
+  // Parent process.
+      char ch;
+      ASSERT (close (ptoc_fd[FD_READ]) == 0);
+      ASSERT (close (ctop_fd[FD_WRITE]) == 0);
+      reset_transput_buffer (INPUT_BUFFER);
+      int pipe_read, ret, status;
+      do {
+        pipe_read = (int) io_read_conv (ctop_fd[FD_READ], &ch, 1);
+        if (pipe_read > 0) {
+          plusab_transput_buffer (p, INPUT_BUFFER, ch);
+        }
+      } while (pipe_read > 0);
+      do {
+        ret = (int) waitpid ((a68g_pid_t) pid, &status, 0);
+      } while (ret == -1 && errno == EINTR);
+      if (ret != pid) {
+        status = -1;
+      }
+      if (!IS_NIL (dest)) {
+        *DEREF (A68G_REF, &dest) = c_to_a_string (p, get_transput_buffer (INPUT_BUFFER), get_transput_buffer_index (INPUT_BUFFER));
+      }
+      ASSERT (close (ptoc_fd[FD_WRITE]) == 0);
+      ASSERT (close (ctop_fd[FD_READ]) == 0);
+      PUSH_VALUE (p, ret, A68G_INT);
     }
-    if (!IS_NIL (dest)) {
-      *DEREF (A68G_REF, &dest) = c_to_a_string (p, get_transput_buffer (INPUT_BUFFER), get_transput_buffer_index (INPUT_BUFFER));
-    }
-    ASSERT (close (ptoc_fd[FD_WRITE]) == 0);
-    ASSERT (close (ctop_fd[FD_READ]) == 0);
-    PUSH_VALUE (p, ret, A68G_INT);
-  }
-#endif
+  #endif
 }
 
 //! @brief PROC create pipe = PIPE
@@ -839,7 +839,7 @@ void genie_waitpid (NODE_T * p)
   errno = 0;
   A68G_INT k;
   POP_OBJECT (p, &k, A68G_INT);
-#if defined (BUILD_UNIX)
-  ASSERT (waitpid ((a68g_pid_t) VALUE (&k), NULL, 0) != -1);
-#endif
+  #if defined (BUILD_UNIX)
+    ASSERT (waitpid ((a68g_pid_t) VALUE (&k), NULL, 0) != -1);
+  #endif
 }
