@@ -45,7 +45,7 @@ void change_masks (NODE_T * p, unt mask, BOOL_T set)
   for (; p != NO_NODE; FORWARD (p)) {
     change_masks (SUB (p), mask, set);
     if (LINE_NUMBER (p) > 0) {
-      if (set == A68_TRUE) {
+      if (set == A68G_TRUE) {
         STATUS_SET (p, mask);
       } else {
         STATUS_CLEAR (p, mask);
@@ -61,11 +61,11 @@ void change_gc_masks (NODE_T * p, BOOL_T set)
   for (; p != NO_NODE; FORWARD (p)) {
     switch (ATTRIBUTE (p)) {
       case CALL: {
-          change_gc_masks (SUB (p), A68_TRUE);
+          change_gc_masks (SUB (p), A68G_TRUE);
           break;
         }
       case SLICE: {
-          change_gc_masks (SUB (p), A68_TRUE);
+          change_gc_masks (SUB (p), A68G_TRUE);
           break;
         }
       default: {
@@ -74,7 +74,7 @@ void change_gc_masks (NODE_T * p, BOOL_T set)
       }
     }
     if (LINE_NUMBER (p) > 0) {
-      if (set == A68_TRUE) {
+      if (set == A68G_TRUE) {
         STATUS_SET (p, BLOCK_GC_MASK);
       } else {
         STATUS_CLEAR (p, BLOCK_GC_MASK);
@@ -90,37 +90,37 @@ void exit_genie (NODE_T * p, int ret)
 #if defined (HAVE_CURSES)
   genie_curses_end (p);
 #endif
-  A68 (close_tty_on_exit) = A68_TRUE;
-  if (!A68 (in_execution)) {
+  A68G (close_tty_on_exit) = A68G_TRUE;
+  if (!A68G (in_execution)) {
     return;
   }
-  if (ret == A68_RUNTIME_ERROR && A68 (in_monitor)) {
+  if (ret == A68G_RUNTIME_ERROR && A68G (in_monitor)) {
     return;
-  } else if (ret == A68_RUNTIME_ERROR && OPTION_DEBUG (&A68_JOB)) {
-    diagnostics_to_terminal (TOP_LINE (&A68_JOB), A68_RUNTIME_ERROR);
+  } else if (ret == A68G_RUNTIME_ERROR && OPTION_DEBUG (&A68G_JOB)) {
+    diagnostics_to_terminal (TOP_LINE (&A68G_JOB), A68G_RUNTIME_ERROR);
     single_step (p, (unt) BREAKPOINT_ERROR_MASK);
-    A68 (in_execution) = A68_FALSE;
-    A68 (ret_line_number) = LINE_NUMBER (p);
-    A68 (ret_code) = ret;
-    longjmp (A68 (genie_exit_label), 1);
+    A68G (in_execution) = A68G_FALSE;
+    A68G (ret_line_number) = LINE_NUMBER (p);
+    A68G (ret_code) = ret;
+    longjmp (A68G (genie_exit_label), 1);
   } else {
-    if ((ret & A68_FORCE_QUIT) != NULL_MASK) {
-      ret &= ~A68_FORCE_QUIT;
+    if ((ret & A68G_FORCE_QUIT) != NULL_MASK) {
+      ret &= ~A68G_FORCE_QUIT;
     }
 #if defined (BUILD_PARALLEL_CLAUSE)
     if (!is_main_thread ()) {
       genie_set_exit_from_threads (ret);
     } else {
-      A68 (in_execution) = A68_FALSE;
-      A68 (ret_line_number) = LINE_NUMBER (p);
-      A68 (ret_code) = ret;
-      longjmp (A68 (genie_exit_label), 1);
+      A68G (in_execution) = A68G_FALSE;
+      A68G (ret_line_number) = LINE_NUMBER (p);
+      A68G (ret_code) = ret;
+      longjmp (A68G (genie_exit_label), 1);
     }
 #else
-    A68 (in_execution) = A68_FALSE;
-    A68 (ret_line_number) = LINE_NUMBER (p);
-    A68 (ret_code) = ret;
-    longjmp (A68 (genie_exit_label), 1);
+    A68G (in_execution) = A68G_FALSE;
+    A68G (ret_line_number) = LINE_NUMBER (p);
+    A68G (ret_code) = ret;
+    longjmp (A68G (genie_exit_label), 1);
 #endif
   }
 }
@@ -143,17 +143,17 @@ void tie_label_to_serial (NODE_T * p)
     if (IS (p, SERIAL_CLAUSE)) {
       BOOL_T valid_follow;
       if (NEXT (p) == NO_NODE) {
-        valid_follow = A68_TRUE;
+        valid_follow = A68G_TRUE;
       } else if (IS (NEXT (p), CLOSE_SYMBOL)) {
-        valid_follow = A68_TRUE;
+        valid_follow = A68G_TRUE;
       } else if (IS (NEXT (p), END_SYMBOL)) {
-        valid_follow = A68_TRUE;
+        valid_follow = A68G_TRUE;
       } else if (IS (NEXT (p), EDOC_SYMBOL)) {
-        valid_follow = A68_TRUE;
+        valid_follow = A68G_TRUE;
       } else if (IS (NEXT (p), OD_SYMBOL)) {
-        valid_follow = A68_TRUE;
+        valid_follow = A68G_TRUE;
       } else {
-        valid_follow = A68_FALSE;
+        valid_follow = A68G_FALSE;
       }
       if (valid_follow) {
         JUMP_TO (TABLE (SUB (p))) = NO_NODE;
@@ -246,7 +246,7 @@ int mode_attribute (MOID_T * p)
 
 void genie_preprocess (NODE_T * p, int *max_lev, void *compile_plugin)
 {
-#if defined (BUILD_A68_COMPILER)
+#if defined (BUILD_A68G_COMPILER)
   static char *last_compile_name = NO_TEXT;
   static PROP_PROC *last_compile_unit = NO_PPROC;
 #endif
@@ -262,8 +262,8 @@ void genie_preprocess (NODE_T * p, int *max_lev, void *compile_plugin)
 // The default.
       UNIT (&GPROP (p)) = genie_unit;
       SOURCE (&GPROP (p)) = p;
-#if defined (BUILD_A68_COMPILER)
-      if (OPTION_OPT_LEVEL (&A68_JOB) > 0 && COMPILE_NAME (GINFO (p)) != NO_TEXT && compile_plugin != NULL) {
+#if defined (BUILD_A68G_COMPILER)
+      if (OPTION_OPT_LEVEL (&A68G_JOB) > 0 && COMPILE_NAME (GINFO (p)) != NO_TEXT && compile_plugin != NULL) {
         if (COMPILE_NAME (GINFO (p)) == last_compile_name) {
 // We copy.
           UNIT (&GPROP (p)) = last_compile_unit;
@@ -283,13 +283,13 @@ void genie_preprocess (NODE_T * p, int *max_lev, void *compile_plugin)
       DIGITS (MOID (p)) = moid_digits (MOID (p));
       SHORT_ID (MOID (p)) = mode_attribute (MOID (p));
       if (GINFO (p) != NO_GINFO) {
-        NEED_DNS (GINFO (p)) = A68_FALSE;
+        NEED_DNS (GINFO (p)) = A68G_FALSE;
         if (IS_REF (MOID (p))) {
-          NEED_DNS (GINFO (p)) = A68_TRUE;
+          NEED_DNS (GINFO (p)) = A68G_TRUE;
         } else if (IS (MOID (p), PROC_SYMBOL)) {
-          NEED_DNS (GINFO (p)) = A68_TRUE;
+          NEED_DNS (GINFO (p)) = A68G_TRUE;
         } else if (IS (MOID (p), FORMAT_SYMBOL)) {
-          NEED_DNS (GINFO (p)) = A68_TRUE;
+          NEED_DNS (GINFO (p)) = A68G_TRUE;
         }
       }
     }
@@ -312,13 +312,13 @@ void genie_preprocess (NODE_T * p, int *max_lev, void *compile_plugin)
       TAG_T *q = TAX (p);
       if (q != NO_TAG && NODE (q) != NO_NODE && TABLE (NODE (q)) != NO_TABLE) {
         LEVEL (GINFO (p)) = LEX_LEVEL (NODE (q));
-        OFFSET (GINFO (p)) = &(A68_STACK[FRAME_INFO_SIZE + OFFSET (q)]);
+        OFFSET (GINFO (p)) = &(A68G_STACK[FRAME_INFO_SIZE + OFFSET (q)]);
       }
     } else if (IS (p, OPERATOR)) {
       TAG_T *q = TAX (p);
       if (q != NO_TAG && NODE (q) != NO_NODE && TABLE (NODE (q)) != NO_TABLE) {
         LEVEL (GINFO (p)) = LEX_LEVEL (NODE (q));
-        OFFSET (GINFO (p)) = &(A68_STACK[FRAME_INFO_SIZE + OFFSET (q)]);
+        OFFSET (GINFO (p)) = &(A68G_STACK[FRAME_INFO_SIZE + OFFSET (q)]);
       }
     }
     if (SUB (p) != NO_NODE) {
@@ -336,8 +336,8 @@ void get_global_level (NODE_T * p)
 {
   for (; p != NO_NODE; FORWARD (p)) {
     if (LINE_NUMBER (p) != 0 && IS (p, UNIT)) {
-      if (LEX_LEVEL (p) < A68 (global_level)) {
-        A68 (global_level) = LEX_LEVEL (p);
+      if (LEX_LEVEL (p) < A68G (global_level)) {
+        A68G (global_level) = LEX_LEVEL (p);
       }
     }
     get_global_level (SUB (p));
@@ -349,106 +349,107 @@ void get_global_level (NODE_T * p)
 void genie (void *compile_plugin)
 {
 // Fill in final info for modes.
-  for (MOID_T *m = TOP_MOID (&A68_JOB); m != NO_MOID; FORWARD (m)) {
+  for (MOID_T *m = TOP_MOID (&A68G_JOB); m != NO_MOID; FORWARD (m)) {
     SIZE (m) = moid_size (m);
     DIGITS (m) = moid_digits (m);
     SHORT_ID (m) = mode_attribute (m);
   }
 // Preprocessing.
-  A68 (max_lex_lvl) = 0;
-//  genie_lex_levels (TOP_NODE (&A68_JOB), 1);.
-  genie_preprocess (TOP_NODE (&A68_JOB), &A68 (max_lex_lvl), compile_plugin);
-  change_masks (TOP_NODE (&A68_JOB), BREAKPOINT_INTERRUPT_MASK, A68_FALSE);
-  change_gc_masks (TOP_NODE (&A68_JOB), A68_FALSE);
-  A68_MON (watchpoint_expression) = NO_TEXT;
-  A68 (frame_stack_limit) = A68 (frame_end) - A68 (storage_overhead);
-  A68 (expr_stack_limit) = A68 (stack_end) - A68 (storage_overhead);
-  if (OPTION_REGRESSION_TEST (&A68_JOB)) {
+  A68G (max_lex_lvl) = 0;
+//  genie_lex_levels (TOP_NODE (&A68G_JOB), 1);.
+  genie_preprocess (TOP_NODE (&A68G_JOB), &A68G (max_lex_lvl), compile_plugin);
+  change_masks (TOP_NODE (&A68G_JOB), BREAKPOINT_INTERRUPT_MASK, A68G_FALSE);
+  change_gc_masks (TOP_NODE (&A68G_JOB), A68G_FALSE);
+  A68G_MON (watchpoint_expression) = NO_TEXT;
+  A68G (frame_stack_limit) = A68G (frame_end) - A68G (storage_overhead);
+  A68G (expr_stack_limit) = A68G (stack_end) - A68G (storage_overhead);
+  if (OPTION_REGRESSION_TEST (&A68G_JOB)) {
     init_rng (1);
   } else {
     genie_init_rng ();
   }
   io_close_tty_line ();
-  if (OPTION_TRACE (&A68_JOB)) {
-    ASSERT (a68g_bufprt (A68 (output_line), SNPRINTF_SIZE, "genie: frame stack %uk, expression stack %uk, heap %uk, handles %uk\n", A68 (frame_stack_size) / KILOBYTE, A68 (expr_stack_size) / KILOBYTE, A68 (heap_size) / KILOBYTE, A68 (handle_pool_size) / KILOBYTE) >= 0);
-    WRITE (A68_STDOUT, A68 (output_line));
+  if (OPTION_TRACE (&A68G_JOB)) {
+    ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "genie: frame stack %uk, expression stack %uk, heap %uk, handles %uk\n", A68G (frame_stack_size) / KILOBYTE, A68G (expr_stack_size) / KILOBYTE, A68G (heap_size) / KILOBYTE, A68G (handle_pool_size) / KILOBYTE) >= 0);
+    WRITE (A68G_STDOUT, A68G (output_line));
   }
   install_signal_handlers ();
-  set_default_event_procedure (&A68 (on_gc_event));
-  A68 (do_confirm_exit) = A68_TRUE;
+  set_default_event_procedure (&A68G (on_gc_event));
+  A68G (do_confirm_exit) = A68G_TRUE;
 #if defined (BUILD_PARALLEL_CLAUSE)
-  ASSERT (pthread_mutex_init (&A68_PAR (unit_sema), NULL) == 0);
+  ASSERT (pthread_mutex_init (&A68G_PAR (unit_sema), NULL) == 0);
 #endif
 // Dive into the program.
-  if (setjmp (A68 (genie_exit_label)) == 0) {
-    NODE_T *p = SUB (TOP_NODE (&A68_JOB));
+  if (setjmp (A68G (genie_exit_label)) == 0) {
+    NODE_T *p = SUB (TOP_NODE (&A68G_JOB));
 // If we are to stop in the monitor, set a breakpoint on the first unit.
-    if (OPTION_DEBUG (&A68_JOB)) {
-      change_masks (TOP_NODE (&A68_JOB), BREAKPOINT_TEMPORARY_MASK, A68_TRUE);
-      WRITE (A68_STDOUT, "Execution begins ...");
+    if (OPTION_DEBUG (&A68G_JOB)) {
+      change_masks (TOP_NODE (&A68G_JOB), BREAKPOINT_TEMPORARY_MASK, A68G_TRUE);
+      WRITE (A68G_STDOUT, "Execution begins ...");
     }
     errno = 0;
-    A68 (ret_code) = 0;
-    A68 (global_level) = INT_MAX;
-    A68_GLOBALS = 0;
+    A68G (ret_code) = 0;
+    A68G (global_level) = A68G_MAX_LEX_LEVEL;
+    A68G_GLOBALS = 0;
     get_global_level (p);
-    A68_FP = A68 (frame_start);
-    A68_SP = A68 (stack_start);
-    FRAME_DYNAMIC_LINK (A68_FP) = 0;
-    FRAME_DNS (A68_FP) = 0;
-    FRAME_STATIC_LINK (A68_FP) = 0;
-    FRAME_NUMBER (A68_FP) = 0;
-    FRAME_TREE (A68_FP) = (NODE_T *) p;
-    FRAME_LEXICAL_LEVEL (A68_FP) = LEX_LEVEL (p);
-    FRAME_PARAMETER_LEVEL (A68_FP) = LEX_LEVEL (p);
-    FRAME_PARAMETERS (A68_FP) = A68_FP;
+    A68G_FP = A68G (frame_start);
+    A68G_SP = A68G (stack_start);
+    FRAME_DYNAMIC_LINK (A68G_FP) = 0;
+    FRAME_DNS (A68G_FP) = 0;
+    FRAME_STATIC_LINK (A68G_FP) = 0;
+    FRAME_NUMBER (A68G_FP) = 0;
+    FRAME_TREE (A68G_FP) = (NODE_T *) p;
+    FRAME_LEXICAL_LEVEL (A68G_FP) = LEX_LEVEL (p);
+    FRAME_PARAMETER_LEVEL (A68G_FP) = LEX_LEVEL (p);
+    FRAME_PARAMETERS (A68G_FP) = A68G_FP;
     initialise_frame (p);
     genie_init_heap (p);
-    genie_init_transput (TOP_NODE (&A68_JOB));
-    A68 (cputime_0) = seconds ();
-    A68_GC (sema) = 0;
+    genie_init_transput (TOP_NODE (&A68G_JOB));
+    A68G (cputime_0) = seconds ();
+    A68G (walltime_0) = wall_seconds ();
+    A68G_GC (sema) = 0;
 // Here we go ...
-    A68 (in_execution) = A68_TRUE;
-    A68 (f_entry) = TOP_NODE (&A68_JOB);
+    A68G (in_execution) = A68G_TRUE;
+    A68G (f_entry) = TOP_NODE (&A68G_JOB);
 #if defined (BUILD_UNIX)
     (void) a68g_alarm (INTERRUPT_INTERVAL);
 #endif
-    if (OPTION_TRACE (&A68_JOB)) {
-      WIS (TOP_NODE (&A68_JOB));
+    if (OPTION_TRACE (&A68G_JOB)) {
+      WIS (TOP_NODE (&A68G_JOB));
     }
-    (void) genie_enclosed (TOP_NODE (&A68_JOB));
+    (void) genie_enclosed (TOP_NODE (&A68G_JOB));
   } else {
 // Here we have jumped out of the interpreter. What happened?.
-    if (OPTION_DEBUG (&A68_JOB)) {
-      WRITE (A68_STDOUT, "Execution discontinued");
+    if (OPTION_DEBUG (&A68G_JOB)) {
+      WRITE (A68G_STDOUT, "Execution discontinued");
     }
-    if (A68 (ret_code) == A68_RERUN) {
-      diagnostics_to_terminal (TOP_LINE (&A68_JOB), A68_RUNTIME_ERROR);
+    if (A68G (ret_code) == A68G_RERUN) {
+      diagnostics_to_terminal (TOP_LINE (&A68G_JOB), A68G_RUNTIME_ERROR);
       genie (compile_plugin);
-    } else if (A68 (ret_code) == A68_RUNTIME_ERROR) {
-      if (OPTION_BACKTRACE (&A68_JOB)) {
+    } else if (A68G (ret_code) == A68G_RUNTIME_ERROR) {
+      if (OPTION_BACKTRACE (&A68G_JOB)) {
         int printed = 0;
-        ASSERT (a68g_bufprt (A68 (output_line), SNPRINTF_SIZE, "\nStack backtrace") >= 0);
-        WRITE (A68_STDOUT, A68 (output_line));
-        stack_dump (A68_STDOUT, A68_FP, 16, &printed);
-        WRITE (A68_STDOUT, NEWLINE_STRING);
+        ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "\nStack backtrace") >= 0);
+        WRITE (A68G_STDOUT, A68G (output_line));
+        stack_dump (A68G_STDOUT, A68G_FP, 16, &printed);
+        WRITE (A68G_STDOUT, NEWLINE_STRING);
       }
-      if (FILE_LISTING_OPENED (&A68_JOB)) {
+      if (FILE_LISTING_OPENED (&A68G_JOB)) {
         int printed = 0;
-        ASSERT (a68g_bufprt (A68 (output_line), SNPRINTF_SIZE, "\nStack backtrace") >= 0);
-        WRITE (FILE_LISTING_FD (&A68_JOB), A68 (output_line));
-        stack_dump (FILE_LISTING_FD (&A68_JOB), A68_FP, 32, &printed);
+        ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "\nStack backtrace") >= 0);
+        WRITE (FILE_LISTING_FD (&A68G_JOB), A68G (output_line));
+        stack_dump (FILE_LISTING_FD (&A68G_JOB), A68G_FP, 32, &printed);
       }
     }
   }
-  A68 (in_execution) = A68_FALSE;
+  A68G (in_execution) = A68G_FALSE;
 }
 
 //! @brief Shows line where 'p' is at and draws a '-' beneath the position.
 
 void where_in_source (FILE_T f, NODE_T * p)
 {
-  write_source_line (f, LINE (INFO (p)), p, A68_NO_DIAGNOSTICS);
+  write_source_line (f, LINE (INFO (p)), p, A68G_NO_DIAGNOSTICS);
 }
 
 // Since Algol 68 can pass procedures as parameters, we use static links rather
@@ -506,11 +507,11 @@ void initialise_frame (NODE_T * p)
 {
   if (INITIALISE_ANON (TABLE (p))) {
     TAG_T *_a_;
-    INITIALISE_ANON (TABLE (p)) = A68_FALSE;
+    INITIALISE_ANON (TABLE (p)) = A68G_FALSE;
     for (_a_ = ANONYMOUS (TABLE (p)); _a_ != NO_TAG; FORWARD (_a_)) {
       if (PRIO (_a_) == ROUTINE_TEXT) {
         int youngest = YOUNGEST_ENVIRON (TAX (NODE (_a_)));
-        A68_PROCEDURE *_z_ = (A68_PROCEDURE *) (FRAME_OBJECT (OFFSET (_a_)));
+        A68G_PROCEDURE *_z_ = (A68G_PROCEDURE *) (FRAME_OBJECT (OFFSET (_a_)));
         STATUS (_z_) = INIT_MASK;
         NODE (&(BODY (_z_))) = NODE (_a_);
         if (youngest > 0) {
@@ -520,10 +521,10 @@ void initialise_frame (NODE_T * p)
         }
         LOCALE (_z_) = NO_HANDLE;
         MOID (_z_) = MOID (_a_);
-        INITIALISE_ANON (TABLE (p)) = A68_TRUE;
+        INITIALISE_ANON (TABLE (p)) = A68G_TRUE;
       } else if (PRIO (_a_) == FORMAT_TEXT) {
         int youngest = YOUNGEST_ENVIRON (TAX (NODE (_a_)));
-        A68_FORMAT *_z_ = (A68_FORMAT *) (FRAME_OBJECT (OFFSET (_a_)));
+        A68G_FORMAT *_z_ = (A68G_FORMAT *) (FRAME_OBJECT (OFFSET (_a_)));
         STATUS (_z_) = INIT_MASK;
         BODY (_z_) = NODE (_a_);
         if (youngest > 0) {
@@ -531,7 +532,7 @@ void initialise_frame (NODE_T * p)
         } else {
           ENVIRON (_z_) = 0;
         }
-        INITIALISE_ANON (TABLE (p)) = A68_TRUE;
+        INITIALISE_ANON (TABLE (p)) = A68G_TRUE;
       }
     }
   }
@@ -546,10 +547,10 @@ void initialise_frame (NODE_T * p)
       NODE_T *u = NEXT_NEXT (_q_);
       if (IS (u, ROUTINE_TEXT)) {
         NODE_T *src = SOURCE (&(GPROP (u)));
-        *(A68_PROCEDURE *) FRAME_OBJECT (OFFSET (TAX (_q_))) = *(A68_PROCEDURE *) (FRAME_OBJECT (OFFSET (TAX (src))));
+        *(A68G_PROCEDURE *) FRAME_OBJECT (OFFSET (TAX (_q_))) = *(A68G_PROCEDURE *) (FRAME_OBJECT (OFFSET (TAX (src))));
       } else if ((IS (u, UNIT) && IS (SUB (u), ROUTINE_TEXT))) {
         NODE_T *src = SOURCE (&(GPROP (SUB (u))));
-        *(A68_PROCEDURE *) FRAME_OBJECT (OFFSET (TAX (_q_))) = *(A68_PROCEDURE *) (FRAME_OBJECT (OFFSET (TAX (src))));
+        *(A68G_PROCEDURE *) FRAME_OBJECT (OFFSET (TAX (_q_))) = *(A68G_PROCEDURE *) (FRAME_OBJECT (OFFSET (TAX (src))));
       }
     }
   }
@@ -562,43 +563,43 @@ void genie_check_initialisation (NODE_T * p, BYTE_T * w, MOID_T * q)
 {
   switch (SHORT_ID (q)) {
   case REF_SYMBOL: {
-      A68_REF *z = (A68_REF *) w;
+      A68G_REF *z = (A68G_REF *) w;
       CHECK_INIT (p, INITIALISED (z), q);
       return;
     }
   case PROC_SYMBOL: {
-      A68_PROCEDURE *z = (A68_PROCEDURE *) w;
+      A68G_PROCEDURE *z = (A68G_PROCEDURE *) w;
       CHECK_INIT (p, INITIALISED (z), q);
       return;
     }
   case MODE_INT: {
-      A68_INT *z = (A68_INT *) w;
+      A68G_INT *z = (A68G_INT *) w;
       CHECK_INIT (p, INITIALISED (z), q);
       return;
     }
   case MODE_REAL: {
-      A68_REAL *z = (A68_REAL *) w;
+      A68G_REAL *z = (A68G_REAL *) w;
       CHECK_INIT (p, INITIALISED (z), q);
       return;
     }
   case MODE_COMPLEX: {
-      A68_REAL *r = (A68_REAL *) w;
-      A68_REAL *i = (A68_REAL *) (w + SIZE_ALIGNED (A68_REAL));
+      A68G_REAL *r = (A68G_REAL *) w;
+      A68G_REAL *i = (A68G_REAL *) (w + SIZE_ALIGNED (A68G_REAL));
       CHECK_INIT (p, INITIALISED (r), q);
       CHECK_INIT (p, INITIALISED (i), q);
       return;
     }
-#if (A68_LEVEL >= 3)
+#if (A68G_LEVEL >= 3)
   case MODE_LONG_INT:
   case MODE_LONG_REAL:
   case MODE_LONG_BITS: {
-      A68_DOUBLE *z = (A68_DOUBLE *) w;
+      A68G_DOUBLE *z = (A68G_DOUBLE *) w;
       CHECK_INIT (p, INITIALISED (z), q);
       return;
     }
   case MODE_LONG_COMPLEX: {
-      A68_LONG_REAL *r = (A68_LONG_REAL *) w;
-      A68_LONG_REAL *i = (A68_LONG_REAL *) (w + SIZE_ALIGNED (A68_LONG_REAL));
+      A68G_LONG_REAL *r = (A68G_LONG_REAL *) w;
+      A68G_LONG_REAL *i = (A68G_LONG_REAL *) (w + SIZE_ALIGNED (A68G_LONG_REAL));
       CHECK_INIT (p, INITIALISED (r), q);
       CHECK_INIT (p, INITIALISED (i), q);
       return;
@@ -637,51 +638,51 @@ void genie_check_initialisation (NODE_T * p, BYTE_T * w, MOID_T * q)
       return;
     }
   case MODE_BOOL: {
-      A68_BOOL *z = (A68_BOOL *) w;
+      A68G_BOOL *z = (A68G_BOOL *) w;
       CHECK_INIT (p, INITIALISED (z), q);
       return;
     }
   case MODE_CHAR: {
-      A68_CHAR *z = (A68_CHAR *) w;
+      A68G_CHAR *z = (A68G_CHAR *) w;
       CHECK_INIT (p, INITIALISED (z), q);
       return;
     }
   case MODE_BITS: {
-      A68_BITS *z = (A68_BITS *) w;
+      A68G_BITS *z = (A68G_BITS *) w;
       CHECK_INIT (p, INITIALISED (z), q);
       return;
     }
   case MODE_BYTES: {
-      A68_BYTES *z = (A68_BYTES *) w;
+      A68G_BYTES *z = (A68G_BYTES *) w;
       CHECK_INIT (p, INITIALISED (z), q);
       return;
     }
   case MODE_LONG_BYTES: {
-      A68_LONG_BYTES *z = (A68_LONG_BYTES *) w;
+      A68G_LONG_BYTES *z = (A68G_LONG_BYTES *) w;
       CHECK_INIT (p, INITIALISED (z), q);
       return;
     }
   case MODE_FILE: {
-      A68_FILE *z = (A68_FILE *) w;
+      A68G_FILE *z = (A68G_FILE *) w;
       CHECK_INIT (p, INITIALISED (z), q);
       return;
     }
   case MODE_FORMAT: {
-      A68_FORMAT *z = (A68_FORMAT *) w;
+      A68G_FORMAT *z = (A68G_FORMAT *) w;
       CHECK_INIT (p, INITIALISED (z), q);
       return;
     }
   case MODE_PIPE: {
-      A68_REF *pipe_read = (A68_REF *) w;
-      A68_REF *pipe_write = (A68_REF *) (w + A68_REF_SIZE);
-      A68_INT *pid = (A68_INT *) (w + 2 * A68_REF_SIZE);
+      A68G_REF *pipe_read = (A68G_REF *) w;
+      A68G_REF *pipe_write = (A68G_REF *) (w + A68G_REF_SIZE);
+      A68G_INT *pid = (A68G_INT *) (w + 2 * A68G_REF_SIZE);
       CHECK_INIT (p, INITIALISED (pipe_read), q);
       CHECK_INIT (p, INITIALISED (pipe_write), q);
       CHECK_INIT (p, INITIALISED (pid), q);
       return;
     }
   case MODE_SOUND: {
-      A68_SOUND *z = (A68_SOUND *) w;
+      A68G_SOUND *z = (A68G_SOUND *) w;
       CHECK_INIT (p, INITIALISED (z), q);
       return;
     }
@@ -690,7 +691,7 @@ void genie_check_initialisation (NODE_T * p, BYTE_T * w, MOID_T * q)
 
 //! @brief Propagator_name.
 
-char *propagator_name (const PROP_PROC * p)
+char *propagator_name (PROP_PROC * p)
 {
   if (p == genie_and_function) {
     return "genie_and_function";
