@@ -37,7 +37,7 @@ void max_unitings_to_simplout (NODE_T * p, int *max)
     if (IS (p, UNITING) && MOID (p) == M_SIMPLOUT) {
       MOID_T *q = MOID (SUB (p));
       if (q != M_SIMPLOUT) {
-        int size = moid_size (q);
+        size_t size = moid_size (q);
         MAXIMISE (*max, size);
       }
     }
@@ -83,7 +83,7 @@ void set_moid_sizes (MOID_T * z)
 
 //! @brief Moid size 2.
 
-int moid_size_2 (MOID_T * p)
+size_t moid_size_2 (MOID_T * p)
 {
   if (p == NO_MOID) {
     return 0;
@@ -103,7 +103,7 @@ int moid_size_2 (MOID_T * p)
 #if (A68G_LEVEL >= 3)
     return SIZE_ALIGNED (A68G_LONG_INT);
 #else
-    return (int) size_mp ();
+    return size_mp ();
 #endif
   } else if (p == M_LONG_REAL) {
 #if (A68G_LEVEL >= 3)
@@ -163,12 +163,11 @@ int moid_size_2 (MOID_T * p)
     MAXIMISE (k, A68G_REF_SIZE);
     MAXIMISE (k, SIZE_ALIGNED (A68G_INT));
     MAXIMISE (k, SIZE_ALIGNED (A68G_REAL));
-    MAXIMISE (k, (int) size_long_mp ());
+    MAXIMISE (k, size_mp ());
+    MAXIMISE (k, size_long_mp ());
 #if (A68G_LEVEL >= 3)
     MAXIMISE (k, SIZE_ALIGNED (A68G_LONG_INT));
     MAXIMISE (k, SIZE_ALIGNED (A68G_LONG_REAL));
-#else
-    MAXIMISE (k, (int) size_mp ());
 #endif
     return SIZE_ALIGNED (A68G_UNION) + k;
   } else if (p == M_SIMPLIN) {
@@ -191,13 +190,13 @@ int moid_size_2 (MOID_T * p)
   } else if (IS_FLEX (p)) {
     return moid_size (SUB (p));
   } else if (IS_STRUCT (p)) {
-    int size = 0;
+    size_t size = 0;
     for (PACK_T *z = PACK (p); z != NO_PACK; FORWARD (z)) {
       size += moid_size (MOID (z));
     }
     return size;
   } else if (IS_UNION (p)) {
-    int size = 0;
+    size_t size = 0;
     for (PACK_T *z = PACK (p); z != NO_PACK; FORWARD (z)) {
       if (moid_size (MOID (z)) > size) {
         size = moid_size (MOID (z));
@@ -205,7 +204,7 @@ int moid_size_2 (MOID_T * p)
     }
     return SIZE_ALIGNED (A68G_UNION) + size;
   } else if (PACK (p) != NO_PACK) {
-    int size = 0;
+    size_t size = 0;
     for (PACK_T *z = PACK (p); z != NO_PACK; FORWARD (z)) {
       size += moid_size (MOID (z));
     }
@@ -258,7 +257,7 @@ int moid_digits_2 (MOID_T * p)
 
 //! @brief Moid size.
 
-int moid_size (MOID_T * p)
+size_t moid_size (MOID_T * p)
 {
   SIZE (p) = A68G_ALIGN (moid_size_2 (p));
   return SIZE (p);
