@@ -78,7 +78,7 @@ MP_T *sqrt_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
 // Argument is in range. Estimate the root as double.
 #if (A68G_LEVEL >= 3)
     DOUBLE_T x_d = mp_to_double (p, x_g, gdigs);
-    (void) double_to_mp (p, z_g, sqrt_double (x_d), gdigs);
+    (void) double_to_mp (p, z_g, sqrt_double (x_d), A68G_DOUBLE_DIG, A68G_FALSE, gdigs);
 #else
     REAL_T x_d = mp_to_real (p, x_g, gdigs);
     (void) real_to_mp (p, z_g, sqrt (x_d), gdigs);
@@ -135,7 +135,7 @@ MP_T *curt_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
 // Argument is in range. Estimate the root as double.
 #if (A68G_LEVEL >= 3)
     DOUBLE_T x_d = mp_to_double (p, x_g, gdigs);
-    (void) double_to_mp (p, z_g, cbrt_double (x_d), gdigs);
+    (void) double_to_mp (p, z_g, cbrt_double (x_d), A68G_DOUBLE_DIG, A68G_FALSE, gdigs);
 #else
     REAL_T x_d = mp_to_real (p, x_g, gdigs);
     (void) real_to_mp (p, z_g, cbrt (x_d), gdigs);
@@ -347,7 +347,7 @@ MP_T *mp_ln_scale (NODE_T * p, MP_T * z, int digs)
 // No luck with the kept value, we generate a longer one.
     (void) set_mp (z_g, (MP_T) 1, 1, gdigs);
     (void) ln_mp (p, z_g, z_g, gdigs);
-    A68G_MP (mp_ln_scale) = (MP_T *) get_heap_space ((unt) SIZE_MP (gdigs));
+    A68G_MP (mp_ln_scale) = (MP_T *) get_heap_space (SIZE_MP (gdigs));
     (void) move_mp (A68G_MP (mp_ln_scale), z_g, gdigs);
     A68G_MP (mp_ln_scale_size) = gdigs;
   }
@@ -370,7 +370,7 @@ MP_T *mp_ln_10 (NODE_T * p, MP_T * z, int digs)
 // No luck with the kept value, we generate a longer one.
     (void) set_mp (z_g, (MP_T) 10, 0, gdigs);
     (void) ln_mp (p, z_g, z_g, gdigs);
-    A68G_MP (mp_ln_10) = (MP_T *) get_heap_space ((unt) SIZE_MP (gdigs));
+    A68G_MP (mp_ln_10) = (MP_T *) get_heap_space (SIZE_MP (gdigs));
     (void) move_mp (A68G_MP (mp_ln_10), z_g, gdigs);
     A68G_MP (mp_ln_10_size) = gdigs;
   }
@@ -431,7 +431,7 @@ MP_T *ln_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
     MP_T *tmp = nil_mp (p, gdigs);
 // Construct an estimate.
 #if (A68G_LEVEL >= 3)
-    (void) double_to_mp (p, z_g, log_double (mp_to_double (p, x_g, gdigs)), gdigs);
+    (void) double_to_mp (p, z_g, log_double (mp_to_double (p, x_g, gdigs)), A68G_DOUBLE_DIG, A68G_FALSE, gdigs);
 #else
     (void) real_to_mp (p, z_g, log (mp_to_real (p, x_g, gdigs)), gdigs);
 #endif
@@ -903,7 +903,7 @@ MP_T *atan_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
     MP_T *sns = nil_mp (p, gdigs), *cns = nil_mp (p, gdigs), *tmp = nil_mp (p, gdigs);
 // Construct an estimate.
 #if (A68G_LEVEL >= 3)
-    (void) double_to_mp (p, z_g, atan_double (mp_to_double (p, x_g, gdigs)), gdigs);
+    (void) double_to_mp (p, z_g, atan_double (mp_to_double (p, x_g, gdigs)), A68G_DOUBLE_DIG, A68G_FALSE, gdigs);
 #else
     (void) real_to_mp (p, z_g, atan (mp_to_real (p, x_g, gdigs)), gdigs);
 #endif
