@@ -123,7 +123,7 @@ int width_to_mp_digits (int n)
 
 //! @brief Unformatted write of z to stdout; debugging routine.
 
-#if !defined (BUILD_WIN32)
+#if defined (BUILD_LINUX)
 
 void raw_write_mp (char *str, MP_T * z, int digs)
 {
@@ -339,7 +339,7 @@ MP_T *int_to_mp (NODE_T * p, MP_T * z, INT_T k, int digs)
     k = -k;
     sign_k = -1;
   }
-  int m = k, n = 0;
+  INT_T m = k, n = 0;
   while ((m /= MP_RADIX) != 0) {
     n++;
   }
@@ -459,7 +459,7 @@ REAL_T mp_to_real (NODE_T * p, MP_T * z, int digs)
   } else {
     REAL_T terms[1 + MP_MAX_DIGITS];
     REAL_T weight = ten_up ((int) (MP_EXPONENT (z) * LOG_MP_RADIX));
-    unt lim = MIN (digs, MP_MAX_DIGITS);
+    int lim = MIN (digs, MP_MAX_DIGITS);
     for (int k = 1; k <= lim; k++) {
       terms[k] = ABS (MP_DIGIT (z, k)) * weight;
       weight /= MP_RADIX;
