@@ -221,10 +221,10 @@ void ignore_superfluous_semicolons (NODE_T * p)
   for (; p != NO_NODE; FORWARD (p)) {
     ignore_superfluous_semicolons (SUB (p));
     if (NEXT (p) != NO_NODE && IS (NEXT (p), SEMI_SYMBOL) && NEXT_NEXT (p) == NO_NODE) {
-      diagnostic (A68G_WARNING | A68G_FORCE_DIAGNOSTICS, NEXT (p), WARNING_SKIPPED_SUPERFLUOUS, ATTRIBUTE (NEXT (p)));
+      diagnostic (A68G_WARNING, NEXT (p), WARNING_SKIPPED_SUPERFLUOUS, ATTRIBUTE (NEXT (p)));
       NEXT (p) = NO_NODE;
     } else if (IS (p, SEMI_SYMBOL) && is_semicolon_less (NEXT (p))) {
-      diagnostic (A68G_WARNING | A68G_FORCE_DIAGNOSTICS, p, WARNING_SKIPPED_SUPERFLUOUS, ATTRIBUTE (p));
+      diagnostic (A68G_WARNING, p, WARNING_SKIPPED_SUPERFLUOUS, ATTRIBUTE (p));
       if (PREVIOUS (p) != NO_NODE) {
         NEXT (PREVIOUS (p)) = NEXT (p);
       }
