@@ -110,13 +110,13 @@ void renumber_moids (MOID_T * p, int n)
 MOID_T *register_extra_mode (MOID_T ** z, MOID_T * u)
 {
   // If we already know this mode, return the existing entry; otherwise link it in.
-  for (MOID_T *head = TOP_MOID (&A68_JOB); head != NO_MOID; FORWARD (head)) {
+  for (MOID_T *head = TOP_MOID (&A68G_JOB); head != NO_MOID; FORWARD (head)) {
     if (prove_moid_equivalence (head, u)) {
       return head;
     }
   }
 // Link to chain and exit.
-  NUMBER (u) = A68 (mode_count)++;
+  NUMBER (u) = A68G (mode_count)++;
   NEXT (u) = (*z);
   return *z = u;
 }
@@ -131,7 +131,7 @@ MOID_T *add_mode (MOID_T ** z, int att, int dim, NODE_T * node, MOID_T * sub, PA
     ABEND (att == FLEX_SYMBOL, ERROR_INTERNAL_CONSISTENCY, __func__);
     ABEND (att == ROW_SYMBOL, ERROR_INTERNAL_CONSISTENCY, __func__);
   }
-  USE (new_mode) = A68_FALSE;
+  USE (new_mode) = A68G_FALSE;
   SIZE (new_mode) = 0;
   ATTRIBUTE (new_mode) = att;
   DIM (new_mode) = dim;
@@ -174,10 +174,10 @@ PACK_T *absorb_union_pack (PACK_T * u)
   BOOL_T siga;
   do {
     z = NO_PACK;
-    siga = A68_FALSE;
+    siga = A68G_FALSE;
     for (PACK_T *t = u; t != NO_PACK; FORWARD (t)) {
       if (IS (MOID (t), UNION_SYMBOL)) {
-        siga = A68_TRUE;
+        siga = A68G_TRUE;
         for (PACK_T *s = PACK (MOID (t)); s != NO_PACK; FORWARD (s)) {
           (void) add_mode_to_pack (&z, MOID (s), NO_TEXT, NODE (s));
         }
@@ -273,7 +273,7 @@ void contract_unions (MOID_T * m)
 MOID_T *search_standard_mode (int sizety, NODE_T * indicant)
 {
 // Check whether a standard mode with length 'sizety' exists.
-  for (MOID_T *p = TOP_MOID (&A68_JOB); p != NO_MOID; FORWARD (p)) {
+  for (MOID_T *p = TOP_MOID (&A68G_JOB); p != NO_MOID; FORWARD (p)) {
     if (IS (p, STANDARD) && DIM (p) == sizety && NSYMBOL (NODE (p)) == NSYMBOL (indicant)) {
       return p;
     }
@@ -404,38 +404,38 @@ MOID_T *get_mode_from_declarer (NODE_T * p)
 // Position of definition tells indicants apart.
           TAG_T *y = find_tag_global (TABLE (p), INDICANT, NSYMBOL (p));
           if (y == NO_TAG) {
-            diagnostic (A68_ERROR, p, ERROR_UNDECLARED_TAG_2, NSYMBOL (p));
+            diagnostic (A68G_ERROR, p, ERROR_UNDECLARED_TAG_2, NSYMBOL (p));
           } else {
-            MOID (p) = add_mode (&TOP_MOID (&A68_JOB), INDICANT, 0, NODE (y), NO_MOID, NO_PACK);
+            MOID (p) = add_mode (&TOP_MOID (&A68G_JOB), INDICANT, 0, NODE (y), NO_MOID, NO_PACK);
           }
         }
         return MOID (p);
       } else if (IS_REF (p)) {
         MOID_T *new_one = get_mode_from_declarer (NEXT (p));
-        MOID (p) = add_mode (&TOP_MOID (&A68_JOB), REF_SYMBOL, 0, p, new_one, NO_PACK);
+        MOID (p) = add_mode (&TOP_MOID (&A68G_JOB), REF_SYMBOL, 0, p, new_one, NO_PACK);
         return MOID (p);
       } else if (IS_FLEX (p)) {
         MOID_T *new_one = get_mode_from_declarer (NEXT (p));
-        MOID (p) = add_mode (&TOP_MOID (&A68_JOB), FLEX_SYMBOL, 0, p, new_one, NO_PACK);
+        MOID (p) = add_mode (&TOP_MOID (&A68G_JOB), FLEX_SYMBOL, 0, p, new_one, NO_PACK);
         SLICE (MOID (p)) = SLICE (new_one);
         return MOID (p);
       } else if (IS (p, FORMAL_BOUNDS)) {
         MOID_T *new_one = get_mode_from_declarer (NEXT (p));
-        MOID (p) = add_row (&TOP_MOID (&A68_JOB), 1 + count_formal_bounds (SUB (p)), new_one, p, A68_FALSE);
+        MOID (p) = add_row (&TOP_MOID (&A68G_JOB), 1 + count_formal_bounds (SUB (p)), new_one, p, A68G_FALSE);
         return MOID (p);
       } else if (IS (p, BOUNDS)) {
         MOID_T *new_one = get_mode_from_declarer (NEXT (p));
-        MOID (p) = add_row (&TOP_MOID (&A68_JOB), count_bounds (SUB (p)), new_one, p, A68_FALSE);
+        MOID (p) = add_row (&TOP_MOID (&A68G_JOB), count_bounds (SUB (p)), new_one, p, A68G_FALSE);
         return MOID (p);
       } else if (IS (p, STRUCT_SYMBOL)) {
         PACK_T *u = NO_PACK;
         get_mode_from_struct_field (NEXT (p), &u);
-        MOID (p) = add_mode (&TOP_MOID (&A68_JOB), STRUCT_SYMBOL, count_pack_members (u), p, NO_MOID, u);
+        MOID (p) = add_mode (&TOP_MOID (&A68G_JOB), STRUCT_SYMBOL, count_pack_members (u), p, NO_MOID, u);
         return MOID (p);
       } else if (IS (p, UNION_SYMBOL)) {
         PACK_T *u = NO_PACK;
         get_mode_from_union_pack (NEXT (p), &u);
-        MOID (p) = add_mode (&TOP_MOID (&A68_JOB), UNION_SYMBOL, count_pack_members (u), p, NO_MOID, u);
+        MOID (p) = add_mode (&TOP_MOID (&A68G_JOB), UNION_SYMBOL, count_pack_members (u), p, NO_MOID, u);
         return MOID (p);
       } else if (IS (p, PROC_SYMBOL)) {
         NODE_T *save = p;
@@ -445,7 +445,7 @@ MOID_T *get_mode_from_declarer (NODE_T * p)
           FORWARD (p);
         }
         MOID_T *new_one = get_mode_from_declarer (NEXT (p));
-        MOID (p) = add_mode (&TOP_MOID (&A68_JOB), PROC_SYMBOL, count_pack_members (u), save, new_one, u);
+        MOID (p) = add_mode (&TOP_MOID (&A68G_JOB), PROC_SYMBOL, count_pack_members (u), save, new_one, u);
         MOID (save) = MOID (p);
         return MOID (p);
       } else {
@@ -466,7 +466,7 @@ MOID_T *get_mode_from_routine_text (NODE_T * p)
     FORWARD (p);
   }
   MOID_T *n = get_mode_from_declarer (p);
-  return add_mode (&TOP_MOID (&A68_JOB), PROC_SYMBOL, count_pack_members (u), q, n, u);
+  return add_mode (&TOP_MOID (&A68G_JOB), PROC_SYMBOL, count_pack_members (u), q, n, u);
 }
 
 //! @brief Collect modes from operator-plan.
@@ -480,7 +480,7 @@ MOID_T *get_mode_from_operator (NODE_T * p)
     FORWARD (p);
   }
   MOID_T *new_one = get_mode_from_declarer (NEXT (p));
-  MOID (p) = add_mode (&TOP_MOID (&A68_JOB), PROC_SYMBOL, count_pack_members (u), save, new_one, u);
+  MOID (p) = add_mode (&TOP_MOID (&A68G_JOB), PROC_SYMBOL, count_pack_members (u), save, new_one, u);
   return MOID (p);
 }
 
@@ -518,7 +518,7 @@ void get_mode_from_denotation (NODE_T * p, int sizety)
         MOID (p) = (sizety > 0 ? M_LONG_LONG_REAL : M_REAL);
       }
     } else if (IS (p, BITS_DENOTATION)) {
-#if (A68_LEVEL <= 2)
+#if (A68G_LEVEL <= 2)
       if (sizety == 0) {
         MOID (p) = M_BITS;
       } else if (sizety == 1) {
@@ -556,7 +556,7 @@ void get_modes_from_tree (NODE_T * p, int attribute)
     } else if (IS (q, DECLARER)) {
       if (attribute == VARIABLE_DECLARATION) {
         MOID_T *new_one = get_mode_from_declarer (q);
-        MOID (q) = add_mode (&TOP_MOID (&A68_JOB), REF_SYMBOL, 0, NO_NODE, new_one, NO_PACK);
+        MOID (q) = add_mode (&TOP_MOID (&A68G_JOB), REF_SYMBOL, 0, NO_NODE, new_one, NO_PACK);
       } else {
         MOID (q) = get_mode_from_declarer (q);
       }
@@ -568,7 +568,7 @@ void get_modes_from_tree (NODE_T * p, int attribute)
       if (attribute == GENERATOR) {
         MOID_T *new_one = get_mode_from_declarer (NEXT (q));
         MOID (NEXT (q)) = new_one;
-        MOID (q) = add_mode (&TOP_MOID (&A68_JOB), REF_SYMBOL, 0, NO_NODE, new_one, NO_PACK);
+        MOID (q) = add_mode (&TOP_MOID (&A68G_JOB), REF_SYMBOL, 0, NO_NODE, new_one, NO_PACK);
       }
     } else {
       if (attribute == DENOTATION) {
@@ -597,7 +597,7 @@ void get_mode_from_proc_variables (NODE_T * p)
       get_mode_from_proc_variables (NEXT (p));
     } else if (IS (p, DEFINING_IDENTIFIER)) {
       MOID_T *new_one = MOID (NEXT_NEXT (p));
-      MOID (p) = add_mode (&TOP_MOID (&A68_JOB), REF_SYMBOL, 0, p, new_one, NO_PACK);
+      MOID (p) = add_mode (&TOP_MOID (&A68G_JOB), REF_SYMBOL, 0, p, new_one, NO_PACK);
     }
   }
 }
@@ -621,13 +621,13 @@ void get_mode_from_proc_var_declarations_tree (NODE_T * p)
 BOOL_T is_well_formed (MOID_T * def, MOID_T * z, BOOL_T yin, BOOL_T yang, BOOL_T video)
 {
   if (z == NO_MOID) {
-    return A68_FALSE;
+    return A68G_FALSE;
   } else if (yin && yang) {
-    return z == M_VOID ? video : A68_TRUE;
+    return z == M_VOID ? video : A68G_TRUE;
   } else if (z == M_VOID) {
     return video;
   } else if (IS (z, STANDARD)) {
-    return A68_TRUE;
+    return A68G_TRUE;
   } else if (IS (z, INDICANT)) {
     if (def == NO_MOID) {
 // Check an applied indicant for relation to VOID.
@@ -637,42 +637,42 @@ BOOL_T is_well_formed (MOID_T * def, MOID_T * z, BOOL_T yin, BOOL_T yang, BOOL_T
       if (z == M_VOID) {
         return video;
       } else {
-        return A68_TRUE;
+        return A68G_TRUE;
       }
     } else {
       if (z == def || USE (z)) {
         return yin && yang;
       } else {
-        USE (z) = A68_TRUE;
+        USE (z) = A68G_TRUE;
         BOOL_T wwf = is_well_formed (def, EQUIVALENT (z), yin, yang, video);
-        USE (z) = A68_FALSE;
+        USE (z) = A68G_FALSE;
         return wwf;
       }
     }
   } else if (IS_REF (z)) {
-    return is_well_formed (def, SUB (z), A68_TRUE, yang, A68_FALSE);
+    return is_well_formed (def, SUB (z), A68G_TRUE, yang, A68G_FALSE);
   } else if (IS (z, PROC_SYMBOL)) {
-    return PACK (z) != NO_PACK ? A68_TRUE : is_well_formed (def, SUB (z), A68_TRUE, yang, A68_TRUE);
+    return PACK (z) != NO_PACK ? A68G_TRUE : is_well_formed (def, SUB (z), A68G_TRUE, yang, A68G_TRUE);
   } else if (IS_ROW (z)) {
-    return is_well_formed (def, SUB (z), yin, yang, A68_FALSE);
+    return is_well_formed (def, SUB (z), yin, yang, A68G_FALSE);
   } else if (IS_FLEX (z)) {
-    return is_well_formed (def, SUB (z), yin, yang, A68_FALSE);
+    return is_well_formed (def, SUB (z), yin, yang, A68G_FALSE);
   } else if (IS (z, STRUCT_SYMBOL)) {
     for (PACK_T *s = PACK (z); s != NO_PACK; FORWARD (s)) {
-      if (!is_well_formed (def, MOID (s), yin, A68_TRUE, A68_FALSE)) {
-        return A68_FALSE;
+      if (!is_well_formed (def, MOID (s), yin, A68G_TRUE, A68G_FALSE)) {
+        return A68G_FALSE;
       }
     }
-    return A68_TRUE;
+    return A68G_TRUE;
   } else if (IS (z, UNION_SYMBOL)) {
     for (PACK_T *s = PACK (z); s != NO_PACK; FORWARD (s)) {
-      if (!is_well_formed (def, MOID (s), yin, yang, A68_TRUE)) {
-        return A68_FALSE;
+      if (!is_well_formed (def, MOID (s), yin, yang, A68G_TRUE)) {
+        return A68G_FALSE;
       }
     }
-    return A68_TRUE;
+    return A68G_TRUE;
   } else {
-    return A68_FALSE;
+    return A68G_FALSE;
   }
 }
 
@@ -744,7 +744,7 @@ void make_flex_multiple_row_pack (PACK_T * src, PACK_T ** dst, MOID_T ** p, int
 {
   if (src != NO_PACK) {
     make_flex_multiple_row_pack (NEXT (src), dst, p, dim);
-    MOID_T *z = add_row (p, dim, MOID (src), NO_NODE, A68_FALSE);
+    MOID_T *z = add_row (p, dim, MOID (src), NO_NODE, A68G_FALSE);
     z = add_mode (p, FLEX_SYMBOL, 0, NO_NODE, z, NO_PACK);
     (void) add_mode_to_pack (dst, z, TEXT (src), NODE (src));
   }
@@ -778,7 +778,7 @@ void make_multiple_row_pack (PACK_T * src, PACK_T ** dst, MOID_T ** p, int dim)
 {
   if (src != NO_PACK) {
     make_multiple_row_pack (NEXT (src), dst, p, dim);
-    (void) add_mode_to_pack (dst, add_row (p, dim, MOID (src), NO_NODE, A68_FALSE), TEXT (src), NODE (src));
+    (void) add_mode_to_pack (dst, add_row (p, dim, MOID (src), NO_NODE, A68G_FALSE), TEXT (src), NODE (src));
   }
 }
 
@@ -805,8 +805,8 @@ MOID_T *make_multiple_struct (MOID_T * m, MOID_T ** p, int dim)
 BOOL_T is_mode_has_row (MOID_T * m)
 {
   if (IS (m, STRUCT_SYMBOL) || IS (m, UNION_SYMBOL)) {
-    BOOL_T k = A68_FALSE;
-    for (PACK_T *p = PACK (m); p != NO_PACK && k == A68_FALSE; FORWARD (p)) {
+    BOOL_T k = A68G_FALSE;
+    for (PACK_T *p = PACK (m); p != NO_PACK && k == A68G_FALSE; FORWARD (p)) {
       HAS_ROWS (MOID (p)) = is_mode_has_row (MOID (p));
       k |= (HAS_ROWS (MOID (p)));
     }
@@ -879,9 +879,9 @@ void compute_derived_modes (MODULE_T * mod)
 // Fill out stuff for rows, f.i. inverse relations.
     for (z = TOP_MOID (mod); z != NO_MOID; FORWARD (z)) {
       if (IS_ROW (z) && DIM (z) > 0 && SUB (z) != NO_MOID && !DERIVATE (z)) {
-        (void) add_row (&TOP_MOID (mod), DIM (z) + 1, SUB (z), NODE (z), A68_TRUE);
+        (void) add_row (&TOP_MOID (mod), DIM (z) + 1, SUB (z), NODE (z), A68G_TRUE);
       } else if (IS_REF (z) && IS (SUB (z), ROW_SYMBOL) && !DERIVATE (SUB (z))) {
-        MOID_T *x = add_row (&TOP_MOID (mod), DIM (SUB (z)) + 1, SUB_SUB (z), NODE (SUB (z)), A68_TRUE);
+        MOID_T *x = add_row (&TOP_MOID (mod), DIM (SUB (z)) + 1, SUB_SUB (z), NODE (SUB (z)), A68G_TRUE);
         MOID_T *y = add_mode (&TOP_MOID (mod), REF_SYMBOL, 0, NODE (z), x, NO_PACK);
         NAME (y) = z;
       }
@@ -906,9 +906,9 @@ void compute_derived_modes (MODULE_T * mod)
     for (z = TOP_MOID (mod); z != NO_MOID; FORWARD (z)) {
       resolve_eq_members (z);
     }
-    resolve_eq_tags (INDICANTS (A68_STANDENV));
-    resolve_eq_tags (IDENTIFIERS (A68_STANDENV));
-    resolve_eq_tags (OPERATORS (A68_STANDENV));
+    resolve_eq_tags (INDICANTS (A68G_STANDENV));
+    resolve_eq_tags (IDENTIFIERS (A68G_STANDENV));
+    resolve_eq_tags (OPERATORS (A68G_STANDENV));
     resolve_equivalent (&M_STRING);
     resolve_equivalent (&M_COMPLEX);
     resolve_equivalent (&M_COMPL);
@@ -930,7 +930,7 @@ void compute_derived_modes (MODULE_T * mod)
       }
     }
 // See what new known modes we have generated by resolving..
-    for (z = TOP_MOID (mod); z != STANDENV_MOID (&A68_JOB); FORWARD (z)) {
+    for (z = TOP_MOID (mod); z != STANDENV_MOID (&A68G_JOB); FORWARD (z)) {
       MOID_T *v;
       for (v = NEXT (z); v != NO_MOID; FORWARD (v)) {
         if (prove_moid_equivalence (z, v)) {
@@ -953,7 +953,7 @@ void compute_derived_modes (MODULE_T * mod)
 // Check flexible modes.
   for (z = TOP_MOID (mod); z != NO_MOID; FORWARD (z)) {
     if (IS_FLEX (z) && !IS (SUB (z), ROW_SYMBOL)) {
-      diagnostic (A68_ERROR, NODE (z), ERROR_NOT_WELL_FORMED, z);
+      diagnostic (A68G_ERROR, NODE (z), ERROR_NOT_WELL_FORMED, z);
     }
   }
 // Check on fields in structured modes f.i. STRUCT (REAL x, INT n, REAL x) is wrong.
@@ -961,14 +961,14 @@ void compute_derived_modes (MODULE_T * mod)
     if (IS (z, STRUCT_SYMBOL) && EQUIVALENT (z) == NO_MOID) {
       PACK_T *s = PACK (z);
       for (; s != NO_PACK; FORWARD (s)) {
-        BOOL_T x = A68_TRUE;
+        BOOL_T x = A68G_TRUE;
         for (PACK_T *t = NEXT (s); t != NO_PACK && x; FORWARD (t)) {
           if (TEXT (s) == TEXT (t)) {
-            diagnostic (A68_ERROR, NODE (z), ERROR_MULTIPLE_FIELD);
+            diagnostic (A68G_ERROR, NODE (z), ERROR_MULTIPLE_FIELD);
             while (NEXT (s) != NO_PACK && TEXT (NEXT (s)) == TEXT (t)) {
               FORWARD (s);
             }
-            x = A68_FALSE;
+            x = A68G_FALSE;
           }
         }
       }
@@ -980,7 +980,7 @@ void compute_derived_modes (MODULE_T * mod)
       PACK_T *s = PACK (z);
 // Discard unions with one member.
       if (count_pack_members (s) == 1) {
-        diagnostic (A68_ERROR, NODE (z), ERROR_COMPONENT_NUMBER, z);
+        diagnostic (A68G_ERROR, NODE (z), ERROR_COMPONENT_NUMBER, z);
       }
 // Discard incestuous unions with firmly related modes.
       for (; s != NO_PACK; FORWARD (s)) {
@@ -988,7 +988,7 @@ void compute_derived_modes (MODULE_T * mod)
         for (t = NEXT (s); t != NO_PACK; FORWARD (t)) {
           if (MOID (t) != MOID (s)) {
             if (is_firm (MOID (s), MOID (t))) {
-              diagnostic (A68_ERROR, NODE (z), ERROR_COMPONENT_RELATED, z);
+              diagnostic (A68G_ERROR, NODE (z), ERROR_COMPONENT_RELATED, z);
             }
           }
         }
@@ -997,21 +997,21 @@ void compute_derived_modes (MODULE_T * mod)
       for (s = PACK (z); s != NO_PACK; FORWARD (s)) {
         MOID_T *n = depref_completely (MOID (s));
         if (IS (n, UNION_SYMBOL) && is_subset (n, z, NO_DEFLEXING)) {
-          diagnostic (A68_ERROR, NODE (z), ERROR_SUBSET_RELATED, z, n);
+          diagnostic (A68G_ERROR, NODE (z), ERROR_SUBSET_RELATED, z, n);
         }
       }
     }
   }
 // Wrap up and exit.
-  free_postulate_list (A68 (top_postulate), NO_POSTULATE);
-  A68 (top_postulate) = NO_POSTULATE;
+  free_postulate_list (A68G (top_postulate), NO_POSTULATE);
+  A68G (top_postulate) = NO_POSTULATE;
 }
 
 //! @brief Make list of all modes in the program.
 
 void make_moid_list (MODULE_T * mod)
 {
-  BOOL_T cont = A68_TRUE;
+  BOOL_T cont = A68G_TRUE;
 // Collect modes from the syntax tree.
   reset_moid_tree (TOP_NODE (mod));
   get_modes_from_tree (TOP_NODE (mod), STOP);
@@ -1028,13 +1028,13 @@ void make_moid_list (MODULE_T * mod)
   }
 // Checks on wrong declarations.
   for (MOID_T *z = TOP_MOID (mod); z != NO_MOID; FORWARD (z)) {
-    USE (z) = A68_FALSE;
+    USE (z) = A68G_FALSE;
   }
   for (MOID_T *z = TOP_MOID (mod); z != NO_MOID; FORWARD (z)) {
     if (IS (z, INDICANT) && EQUIVALENT (z) != NO_MOID) {
-      if (!is_well_formed (z, EQUIVALENT (z), A68_FALSE, A68_FALSE, A68_TRUE)) {
-        diagnostic (A68_ERROR, NODE (z), ERROR_NOT_WELL_FORMED, z);
-        cont = A68_FALSE;
+      if (!is_well_formed (z, EQUIVALENT (z), A68G_FALSE, A68G_FALSE, A68G_TRUE)) {
+        diagnostic (A68G_ERROR, NODE (z), ERROR_NOT_WELL_FORMED, z);
+        cont = A68G_FALSE;
       }
     }
   }
@@ -1042,8 +1042,8 @@ void make_moid_list (MODULE_T * mod)
     if (IS (z, INDICANT) && EQUIVALENT (z) != NO_MOID) {
       ;
     } else if (NODE (z) != NO_NODE) {
-      if (!is_well_formed (NO_MOID, z, A68_FALSE, A68_FALSE, A68_TRUE)) {
-        diagnostic (A68_ERROR, NODE (z), ERROR_NOT_WELL_FORMED, z);
+      if (!is_well_formed (NO_MOID, z, A68G_FALSE, A68G_FALSE, A68G_TRUE)) {
+        diagnostic (A68G_ERROR, NODE (z), ERROR_NOT_WELL_FORMED, z);
       }
     }
   }
