@@ -808,7 +808,7 @@ void widen_denotation (NODE_T * p)
   }
 #define WARN_WIDENING\
   if (OPTION_PORTCHECK (&A68G_JOB) && !(STATUS_TEST (SUB (q), OPTIMAL_MASK))) {\
-    diagnostic (A68G_WARNING | A68G_FORCE_DIAGNOSTICS, q, WARNING_WIDENING_NOT_PORTABLE);\
+    diagnostic (A68G_NOTICE, q, WARNING_WIDENING_NOT_PORTABLE);\
   }
   for (NODE_T *q = p; q != NO_NODE; FORWARD (q)) {
     widen_denotation (SUB (q));
