@@ -69,7 +69,7 @@ void restore_state (LINE_T ** ref_l, char **ref_s, char *ch)
 
 LINE_T *new_source_line (void)
 {
-  LINE_T *z = (LINE_T *) get_fixed_heap_space ((size_t) SIZE_ALIGNED (LINE_T));
+  LINE_T *z = (LINE_T *) get_fixed_heap_space (SIZE_ALIGNED (LINE_T));
   MARKER (z)[0] = NULL_CHAR;
   STRING (z) = NO_TEXT;
   FILENAME (z) = NO_TEXT;
@@ -138,11 +138,11 @@ void concatenate_lines (LINE_T * top)
   }
   for (; q != NO_LINE; BACKWARD (q)) {
     char *z = STRING (q);
-    int len = (int) strlen (z);
+    size_t len = strlen (z);
     if (len >= 2 && z[len - 2] == BACKSLASH_CHAR && z[len - 1] == NEWLINE_CHAR && NEXT (q) != NO_LINE && STRING (NEXT (q)) != NO_TEXT) {
       z[len - 2] = NULL_CHAR;
-      len += (int) strlen (STRING (NEXT (q)));
-      z = (char *) get_fixed_heap_space ((size_t) (len + 1));
+      len += strlen (STRING (NEXT (q)));
+      z = (char *) get_fixed_heap_space (len + 1);
       a68g_bufcpy (z, STRING (q), len + 1);
       a68g_bufcat (z, STRING (NEXT (q)), len + 1);
       STRING (NEXT (q))[0] = NULL_CHAR;
@@ -155,7 +155,7 @@ void concatenate_lines (LINE_T * top)
 
 BOOL_T is_bold (char *u, char *v)
 {
-  unt len = (unt) strlen (v);
+  size_t len = strlen (v);
   if (OPTION_STROPPING (&A68G_JOB) == QUOTE_STROPPING) {
     if (u[0] == '\'') {
       return (BOOL_T) (strncmp (++u, v, len) == 0 && u[len] == '\'');
@@ -436,7 +436,7 @@ void include_files (LINE_T * top)
 // Search for PR include "filename" PR.
       if (item != NO_TEXT && (streq (item, "INCLUDE") == 0 || streq (item, "READ") == 0)) {
         FILE_T fd;
-        int n, line_num, fsize, k, bytes_read, fnwid;
+        int n, line_num, k, bytes_read;
         char *fbuf, delim;
         BUFFER fnb;
         char *fn;
@@ -486,8 +486,8 @@ void include_files (LINE_T * top)
         } else {
           SCAN_ERROR_INFO (A68G_TRUE, NO_LINE, NO_TEXT, ERROR_SOURCE_FILE_INCLUDE_OPEN, fnb);
         }
-        fnwid = (int) strlen (fnb) + 1;
-        fn = (char *) get_fixed_heap_space ((size_t) fnwid);
+        size_t fnwid = strlen (fnb) + 1;
+        fn = (char *) get_fixed_heap_space (fnwid);
         a68g_bufcpy (fn, fnb, fnwid);
 // Ignore the file when included more than once.
         for (t = top; t != NO_LINE; t = NEXT (t)) {
@@ -500,10 +500,10 @@ void include_files (LINE_T * top)
         fd = open (fn, O_RDONLY | O_BINARY);
         SCAN_ERROR_INFO (fd == -1, start_l, start_c, ERROR_SOURCE_FILE_INCLUDE_OPEN, fnb);
         errno = 0;
-        fsize = (int) lseek (fd, 0, SEEK_END);
+        a68g_off_t fsize = (a68g_off_t) lseek (fd, 0, SEEK_END);
         ASSERT (fsize >= 0);
         SCAN_ERROR (errno != 0, start_l, start_c, ERROR_FILE_READ);
-        fbuf = (char *) get_temp_heap_space ((unt) (8 + fsize));
+        fbuf = (char *) get_temp_heap_space ((size_t) (8 + fsize));
         errno = 0;
         ASSERT (lseek (fd, 0, SEEK_SET) >= 0);
         SCAN_ERROR (errno != 0, start_l, start_c, ERROR_FILE_READ);
@@ -513,7 +513,7 @@ void include_files (LINE_T * top)
 // Buffer still usable?.
         if (fsize > A68G_PARSER (max_scan_buf_length)) {
           A68G_PARSER (max_scan_buf_length) = fsize;
-          A68G_PARSER (scan_buf) = (char *) get_temp_heap_space ((unt) (8 + A68G_PARSER (max_scan_buf_length)));
+          A68G_PARSER (scan_buf) = (char *) get_temp_heap_space (8 + A68G_PARSER (max_scan_buf_length));
         }
 // Link all lines into the list.
         line_num = 1;
@@ -555,11 +555,11 @@ void include_files (LINE_T * top)
 
 //! @brief Size of source file.
 
-int get_source_size (void)
+a68g_off_t get_source_size (void)
 {
   FILE_T f = FILE_SOURCE_FD (&A68G_JOB);
-// This is why WIN32 must open as "read binary".
-  return (int) lseek (f, 0, SEEK_END);
+// This is why WIN32/64 must open as "read binary".
+  return (a68g_off_t) lseek (f, 0, SEEK_END);
 }
 
 //! @brief Append environment source lines.
@@ -578,20 +578,19 @@ void append_environ (char *str[], LINE_T ** ref_l, int *line_num, char *name)
 BOOL_T read_script_file (void)
 {
   LINE_T *ref_l = NO_LINE;
-  int k, n, num;
-  unt len;
+  int num;
   BOOL_T file_end = A68G_FALSE;
   BUFFER filename, linenum;
-  char ch, *fn, *line;
-  char *buffer = (char *) get_temp_heap_space ((unt) (8 + A68G_PARSER (source_file_size)));
+  char *buffer = (char *) get_temp_heap_space (8 + A68G_PARSER (source_file_size));
   FILE_T source = FILE_SOURCE_FD (&A68G_JOB);
   ABEND (source == -1, ERROR_ACTION, __func__);
   buffer[0] = NULL_CHAR;
-  n = 0;
-  len = (unt) (8 + A68G_PARSER (source_file_size));
+  UNSIGNED_T k, n = 0;
+  size_t len = 8 + A68G_PARSER (source_file_size);
   buffer = (char *) get_temp_heap_space (len);
   ASSERT (lseek (source, 0, SEEK_SET) >= 0);
   while (!file_end) {
+    char ch;
 // Read the original file name.
     filename[0] = NULL_CHAR;
     k = 0;
@@ -604,7 +603,7 @@ BOOL_T read_script_file (void)
       ASSERT (io_read (source, &ch, 1) == 1);
     }
     filename[k] = NULL_CHAR;
-    fn = TEXT (add_token (&A68G (top_token), filename));
+    char *fn = TEXT (add_token (&A68G (top_token), filename));
 // Read the original file number.
     linenum[0] = NULL_CHAR;
     k = 0;
@@ -618,11 +617,11 @@ BOOL_T read_script_file (void)
     ABEND (errno == ERANGE, ERROR_INTERNAL_CONSISTENCY, __func__);
 // COPY original line into buffer.
     ASSERT (io_read (source, &ch, 1) == 1);
-    line = &buffer[n];
+    char *line = &buffer[n];
     while (ch != NEWLINE_CHAR) {
       buffer[n++] = ch;
       ASSERT (io_read (source, &ch, 1) == 1);
-      ABEND ((unt) n >= len, ERROR_ACTION, __func__);
+      ABEND (n >= len, ERROR_ACTION, __func__);
     }
     buffer[n++] = NEWLINE_CHAR;
     buffer[n] = NULL_CHAR;
@@ -668,12 +667,12 @@ BOOL_T read_source_file (void)
 // Read the file into a single buffer, so we save on system calls.
   line_num = 1;
   errno = 0;
-  text = (char *) get_temp_heap_space ((unt) (8 + A68G_PARSER (source_file_size)));
-  ABEND (errno != 0 || text == NO_TEXT, ERROR_ALLOCATION, __func__);
+  text = (char *) get_temp_heap_space (8 + A68G_PARSER (source_file_size));
+  ABEND (errno != 0 || text == NO_TEXT, ERROR_MEMORY_FULL, __func__);
   ASSERT (lseek (f, 0, SEEK_SET) >= 0);
   ABEND (errno != 0, ERROR_ACTION, __func__);
   errno = 0;
-  bytes_read = (int) io_read (f, text, (size_t) A68G_PARSER (source_file_size));
+  bytes_read = (int) io_read (f, text, A68G_PARSER (source_file_size));
   ABEND (errno != 0 || bytes_read != A68G_PARSER (source_file_size), ERROR_ACTION, __func__);
 // Little test on stropping.
   char *pr1 = "'PR'QUOTESTROPPING'PR'";
@@ -720,7 +719,7 @@ BOOL_T read_source_file (void)
       k++;
     }
     append_source_line (A68G_PARSER (scan_buf), &ref_l, &line_num, FILE_SOURCE_NAME (&A68G_JOB));
-    SCAN_ERROR (l != (ssize_t) strlen (A68G_PARSER (scan_buf)), NO_LINE, NO_TEXT, ERROR_FILE_SOURCE_CTRL);
+    SCAN_ERROR (l != strlen (A68G_PARSER (scan_buf)), NO_LINE, NO_TEXT, ERROR_FILE_SOURCE_CTRL);
   }
 // Postlude.
   append_environ (postlude, &ref_l, &line_num, "postlude");
@@ -780,12 +779,13 @@ void get_good_char (char *ref_c, LINE_T ** ref_l, char **ref_s)
 
 char *pragment (int type, LINE_T ** ref_l, char **ref_c)
 {
+  size_t chars_in_buf;
 #define INIT_BUFFER {chars_in_buf = 0; A68G_PARSER (scan_buf)[chars_in_buf] = NULL_CHAR;}
 #define ADD_ONE_CHAR(ch) {A68G_PARSER (scan_buf)[chars_in_buf ++] = ch; A68G_PARSER (scan_buf)[chars_in_buf] = NULL_CHAR;}
+//
   char c = **ref_c, *term_s = NO_TEXT, *start_c = *ref_c;
   char *z = NO_TEXT;
   LINE_T *start_l = *ref_l;
-  int term_s_length, chars_in_buf;
   BOOL_T stop, pragmat = A68G_FALSE;
 // Set terminator.
   if (OPTION_STROPPING (&A68G_JOB) == UPPER_STROPPING) {
@@ -817,7 +817,7 @@ char *pragment (int type, LINE_T ** ref_l, char **ref_c)
       pragmat = A68G_TRUE;
     }
   }
-  term_s_length = (int) strlen (term_s);
+  size_t term_s_length = strlen (term_s);
 // Scan for terminator.
   INIT_BUFFER;
   stop = A68G_FALSE;
@@ -1428,7 +1428,7 @@ void tokenise_source (NODE_T ** root, int level, BOOL_T in_format, LINE_T ** l,
           make_lower_case (A68G_PARSER (scan_buf));
         }
         if (att != ROW_CHAR_DENOTATION && att != LITERAL) {
-          int len = (int) strlen (A68G_PARSER (scan_buf));
+          size_t len = strlen (A68G_PARSER (scan_buf));
           while (len >= 1 && A68G_PARSER (scan_buf)[len - 1] == '_') {
             trailing = "_";
             A68G_PARSER (scan_buf)[len - 1] = NULL_CHAR;
@@ -1455,7 +1455,7 @@ void tokenise_source (NODE_T ** root, int level, BOOL_T in_format, LINE_T ** l,
 // Handle pragments.
           if (att == STYLE_II_COMMENT_SYMBOL || att == STYLE_I_COMMENT_SYMBOL || att == BOLD_COMMENT_SYMBOL) {
             char *nlpr = pragment (ATTRIBUTE (kw), l, s);
-            if (lpr == NO_TEXT || (int) strlen (lpr) == 0) {
+            if (lpr == NO_TEXT || strlen (lpr) == 0) {
               lpr = nlpr;
             } else {
               char *stale = lpr;
@@ -1467,7 +1467,7 @@ void tokenise_source (NODE_T ** root, int level, BOOL_T in_format, LINE_T ** l,
             make_node = A68G_FALSE;
           } else if (att == STYLE_I_PRAGMAT_SYMBOL || att == BOLD_PRAGMAT_SYMBOL) {
             char *nlpr = pragment (ATTRIBUTE (kw), l, s);
-            if (lpr == NO_TEXT || (int) strlen (lpr) == 0) {
+            if (lpr == NO_TEXT || strlen (lpr) == 0) {
               lpr = nlpr;
             } else {
               char *stale = lpr;
@@ -1534,7 +1534,7 @@ void tokenise_source (NODE_T ** root, int level, BOOL_T in_format, LINE_T ** l,
         }
         *root = q;
         if (trailing != NO_TEXT) {
-          diagnostic (A68G_WARNING | A68G_FORCE_DIAGNOSTICS, q, WARNING_TRAILING, trailing, att);
+          diagnostic (A68G_WARNING, q, WARNING_TRAILING, trailing, att);
         }
       }
 // Redirection in tokenising formats. The scanner is a recursive-descent type as
@@ -1583,13 +1583,13 @@ BOOL_T lexical_analyser (void)
     return A68G_FALSE;
   }
   if (OPTION_RUN_SCRIPT (&A68G_JOB)) {
-    A68G_PARSER (scan_buf) = (char *) get_temp_heap_space ((unt) (8 + A68G_PARSER (max_scan_buf_length)));
+    A68G_PARSER (scan_buf) = (char *) get_temp_heap_space (8 + A68G_PARSER (max_scan_buf_length));
     if (!read_script_file ()) {
       return A68G_FALSE;
     }
   } else {
     A68G_PARSER (max_scan_buf_length) += KILOBYTE;       // for the environ, more than enough
-    A68G_PARSER (scan_buf) = (char *) get_temp_heap_space ((unt) A68G_PARSER (max_scan_buf_length));
+    A68G_PARSER (scan_buf) = (char *) get_temp_heap_space (A68G_PARSER (max_scan_buf_length));
 // Errors in file?.
     if (!read_source_file ()) {
       return A68G_FALSE;
