@@ -113,7 +113,7 @@ int first_tag_global (TABLE_T * table, char *name)
 
 #define PORTCHECK_TAX(p, q) {\
   if (q == A68G_FALSE) {\
-    diagnostic (A68G_WARNING | A68G_FORCE_DIAGNOSTICS, p, WARNING_TAG_NOT_PORTABLE);\
+    diagnostic (A68G_NOTICE, p, WARNING_TAG_NOT_PORTABLE);\
   }}
 
 //! @brief Check portability of sub tree.
@@ -133,7 +133,7 @@ void portcheck (NODE_T * p)
         PORTCHECK_TAX (p, PORTABLE (TAX (p)));
         PORTABLE (TAX (p)) = A68G_TRUE;
       } else if (IS (p, ASSERTION)) {
-        diagnostic (A68G_WARNING | A68G_FORCE_DIAGNOSTICS, p, WARNING_TAG_NOT_PORTABLE);
+        diagnostic (A68G_NOTICE, p, WARNING_TAG_NOT_PORTABLE);
       }
     }
   }
@@ -544,9 +544,9 @@ void already_declared_hidden (NODE_T * n, int a)
   TAG_T *s = find_tag_global (PREVIOUS (TABLE (n)), a, NSYMBOL (n));
   if (s != NO_TAG) {
     if (TAG_TABLE (s) == A68G_STANDENV) {
-      diagnostic (A68G_WARNING, n, WARNING_HIDES_PRELUDE, MOID (s), NSYMBOL (n));
+      diagnostic (A68G_NOTICE, n, WARNING_HIDES_PRELUDE, MOID (s), NSYMBOL (n));
     } else {
-      diagnostic (A68G_WARNING, n, WARNING_HIDES, NSYMBOL (n));
+      diagnostic (A68G_NOTICE, n, WARNING_HIDES, NSYMBOL (n));
     }
   }
 }
@@ -1304,7 +1304,7 @@ void unused (TAG_T * s)
 {
   for (; s != NO_TAG; FORWARD (s)) {
     if (LINE_NUMBER (NODE (s)) > 0 && !USE (s)) {
-      diagnostic (A68G_WARNING, NODE (s), WARNING_TAG_UNUSED, NODE (s));
+      diagnostic (A68G_NOTICE, NODE (s), WARNING_TAG_UNUSED, NODE (s));
     }
   }
 }
