@@ -121,24 +121,24 @@ void init_before_tokeniser (void)
 // Heap management set-up.
   errno = 0;
   init_heap ();
-  A68 (top_keyword) = NO_KEYWORD;
-  A68 (top_token) = NO_TOKEN;
-  TOP_NODE (&A68_JOB) = NO_NODE;
-  TOP_MOID (&A68_JOB) = NO_MOID;
-  TOP_LINE (&A68_JOB) = NO_LINE;
-  STANDENV_MOID (&A68_JOB) = NO_MOID;
+  A68G (top_keyword) = NO_KEYWORD;
+  A68G (top_token) = NO_TOKEN;
+  TOP_NODE (&A68G_JOB) = NO_NODE;
+  TOP_MOID (&A68G_JOB) = NO_MOID;
+  TOP_LINE (&A68G_JOB) = NO_LINE;
+  STANDENV_MOID (&A68G_JOB) = NO_MOID;
   set_up_tables ();
 // Various initialisations.
-  ERROR_COUNT (&A68_JOB) = WARNING_COUNT (&A68_JOB) = 0;
-  ABEND (errno != 0, ERROR_ALLOCATION, __func__);
+  ERROR_COUNT (&A68G_JOB) = WARNING_COUNT (&A68G_JOB) = 0;
+  ABEND (errno != 0, ERROR_MEMORY_FULL, __func__);
   errno = 0;
 }
 
 void init_parser (void)
 {
-  A68_PARSER (stop_scanner) = A68_FALSE;
-  A68_PARSER (read_error) = A68_FALSE;
-  A68_PARSER (no_preprocessing) = A68_FALSE;
+  A68G_PARSER (stop_scanner) = A68G_FALSE;
+  A68G_PARSER (read_error) = A68G_FALSE;
+  A68G_PARSER (no_preprocessing) = A68G_FALSE;
 }
 
 //! @brief Is_ref_refety_flex.
@@ -146,11 +146,11 @@ void init_parser (void)
 BOOL_T is_ref_refety_flex (MOID_T * m)
 {
   if (IS_REF_FLEX (m)) {
-    return A68_TRUE;
+    return A68G_TRUE;
   } else if (IS_REF (m)) {
     return is_ref_refety_flex (SUB (m));
   } else {
-    return A68_FALSE;
+    return A68G_FALSE;
   }
 }
 
@@ -222,10 +222,10 @@ BOOL_T is_semicolon_less (NODE_T * p)
   case OCCA_SYMBOL:
   case OD_SYMBOL:
   case UNTIL_SYMBOL: {
-      return A68_TRUE;
+      return A68G_TRUE;
     }
   default: {
-      return A68_FALSE;
+      return A68G_FALSE;
     }
   }
 }
@@ -235,7 +235,7 @@ BOOL_T is_semicolon_less (NODE_T * p)
 BOOL_T is_formal_bounds (NODE_T * p)
 {
   if (p == NO_NODE) {
-    return A68_TRUE;
+    return A68G_TRUE;
   } else {
     switch (ATTRIBUTE (p)) {
     case OPEN_SYMBOL:
@@ -251,7 +251,7 @@ BOOL_T is_formal_bounds (NODE_T * p)
         return (BOOL_T) (is_formal_bounds (SUB (p)) && is_formal_bounds (NEXT (p)));
       }
     default: {
-        return A68_FALSE;
+        return A68G_FALSE;
       }
     }
   }
@@ -280,10 +280,10 @@ BOOL_T is_unit_terminator (NODE_T * p)
   case ESAC_SYMBOL:
   case EDOC_SYMBOL:
   case OCCA_SYMBOL: {
-      return A68_TRUE;
+      return A68G_TRUE;
     }
   }
-  return A68_FALSE;
+  return A68G_FALSE;
 }
 
 //! @brief Whether token is a unit-terminator in a loop clause.
@@ -298,10 +298,10 @@ BOOL_T is_loop_keyword (NODE_T * p)
   case DOWNTO_SYMBOL:
   case WHILE_SYMBOL:
   case DO_SYMBOL: {
-      return A68_TRUE;
+      return A68G_TRUE;
     }
   }
-  return A68_FALSE;
+  return A68G_FALSE;
 }
 
 //! @brief Get good attribute.
@@ -318,7 +318,11 @@ int get_good_attribute (NODE_T * p)
     }
   case DECLARER: {
     if (IS (SUB (p), INDICANT)) {
-      return ATTRIBUTE (SUB_SUB (p));
+      if (SUB_SUB (p) != NO_NODE) {
+        return ATTRIBUTE (SUB_SUB (p));
+      } else {
+        return INDICANT;
+      }
     } else {
       return DECLARER;
     }
@@ -342,13 +346,13 @@ char *phrase_to_text (NODE_T * p, NODE_T ** w)
 {
 #define MAX_TERMINALS 10
   int count = 0;
-  BOOL_T put_space = A68_FALSE;
+  BOOL_T put_space = A68G_FALSE;
   static BUFFER buffer;
   buffer[0] = NULL_CHAR;
   while (p != NO_NODE && count < MAX_TERMINALS) {
     if (LINE_NUMBER (p) > 0) {
       int gatt = get_good_attribute (p);
-      char *z = non_terminal_string (A68 (input_line), gatt);
+      char *z = non_terminal_string (A68G (input_line), gatt);
 // Where to put the error message? 
 // The actual content of a  diagnostic is not as important 
 // as accurately indicating *were* the problem is! 
@@ -365,7 +369,7 @@ char *phrase_to_text (NODE_T * p, NODE_T ** w)
         case CLOSE_SYMBOL:
         case BUS_SYMBOL: {
           // Next symbol may have leading space.
-          put_space = A68_TRUE;
+          put_space = A68G_TRUE;
           break;
         }
         case OPEN_SYMBOL:
@@ -374,7 +378,7 @@ char *phrase_to_text (NODE_T * p, NODE_T ** w)
             a68g_bufcat (buffer, " ", BUFFER_SIZE);
           }
           // Next symbol has no leading space.
-          put_space = A68_FALSE;
+          put_space = A68G_FALSE;
           break;              
         }
         default: {
@@ -382,7 +386,7 @@ char *phrase_to_text (NODE_T * p, NODE_T ** w)
             a68g_bufcat (buffer, " ", BUFFER_SIZE);
           }
           // Next symbol may have leading space.
-          put_space = A68_TRUE;
+          put_space = A68G_TRUE;
           break;
         }
       }
@@ -391,33 +395,33 @@ char *phrase_to_text (NODE_T * p, NODE_T ** w)
         switch (gatt) {
           case DENOTATION:
           case IDENTIFIER: {
-            ASSERT (a68g_bufprt (A68 (edit_line), SNPRINTF_SIZE, "%s '%s'", z, NSYMBOL (p)) >= 0);
+            ASSERT (a68g_bufprt (A68G (edit_line), SNPRINTF_SIZE, "%s '%s'", z, NSYMBOL (p)) >= 0);
             break;
           }
           case OPERATOR: {
-            ASSERT (a68g_bufprt (A68 (edit_line), SNPRINTF_SIZE, "%s", NSYMBOL (p)) >= 0);
+            ASSERT (a68g_bufprt (A68G (edit_line), SNPRINTF_SIZE, "%s", NSYMBOL (p)) >= 0);
             break;
           }
           case DECLARER:
           case COLON_SYMBOL: {
-            ASSERT (a68g_bufprt (A68 (edit_line), SNPRINTF_SIZE, "%s", z) >= 0);
+            ASSERT (a68g_bufprt (A68G (edit_line), SNPRINTF_SIZE, "%s", z) >= 0);
             break;
           }
           default: {
             if (SUB (p) == NO_NODE && NSYMBOL (p) != NO_TEXT) {
-              ASSERT (a68g_bufprt (A68 (edit_line), SNPRINTF_SIZE, "%s", NSYMBOL (p)) >= 0);
+              ASSERT (a68g_bufprt (A68G (edit_line), SNPRINTF_SIZE, "%s", NSYMBOL (p)) >= 0);
             } else {
-              ASSERT (a68g_bufprt (A68 (edit_line), SNPRINTF_SIZE, "%s", z) >= 0);
+              ASSERT (a68g_bufprt (A68G (edit_line), SNPRINTF_SIZE, "%s", z) >= 0);
             }
             break;
           }
         }
       } else if (NSYMBOL (p) != NO_TEXT) {
-        ASSERT (a68g_bufprt (A68 (edit_line), SNPRINTF_SIZE, "%s", NSYMBOL (p)) >= 0);
+        ASSERT (a68g_bufprt (A68G (edit_line), SNPRINTF_SIZE, "%s", NSYMBOL (p)) >= 0);
       } else {
-        ASSERT (a68g_bufprt (A68 (edit_line), SNPRINTF_SIZE, "...") >= 0);
+        ASSERT (a68g_bufprt (A68G (edit_line), SNPRINTF_SIZE, "...") >= 0);
       }
-      a68g_bufcat (buffer, A68 (edit_line), BUFFER_SIZE);
+      a68g_bufcat (buffer, A68G (edit_line), BUFFER_SIZE);
       count++;
     }
     FORWARD (p);
@@ -535,193 +539,201 @@ BOOL_T dont_mark_here (NODE_T * p)
   case ENQUIRY_CLAUSE:
   case INITIALISER_SERIES:
   case DECLARATION_LIST: {
-      return A68_TRUE;
+      return A68G_TRUE;
     }
   }
-  return A68_FALSE;
+  return A68G_FALSE;
 }
 
 void a68g_parser (void)
 {
 // Tokeniser.
-  FILE_SOURCE_OPENED (&A68_JOB) = A68_TRUE;
+  FILE_SOURCE_OPENED (&A68G_JOB) = A68G_TRUE;
   announce_phase ("initialiser");
-  A68_PARSER (error_tag) = (TAG_T *) new_tag ();
+  A68G_PARSER (error_tag) = (TAG_T *) new_tag ();
   init_parser ();
-  if (ERROR_COUNT (&A68_JOB) == 0) {
-    int frame_stack_size_2 = A68 (frame_stack_size);
-    int expr_stack_size_2 = A68 (expr_stack_size);
-    int heap_size_2 = A68 (heap_size);
-    int handle_pool_size_2 = A68 (handle_pool_size);
+  if (ERROR_COUNT (&A68G_JOB) == 0) {
+    size_t frame_stack_size_2 = A68G (frame_stack_size);
+    size_t expr_stack_size_2 = A68G (expr_stack_size);
+    size_t heap_size_2 = A68G (heap_size);
+    size_t handle_pool_size_2 = A68G (handle_pool_size);
     BOOL_T ok;
     announce_phase ("tokeniser");
     ok = lexical_analyser ();
     if (!ok || errno != 0) {
-      diagnostics_to_terminal (TOP_LINE (&A68_JOB), A68_ALL_DIAGNOSTICS);
+      diagnostics_to_terminal (TOP_LINE (&A68G_JOB), A68G_ALL_DIAGNOSTICS);
       return;
     }
 // Maybe the program asks for more memory through a PRAGMAT. We restart.
-    if (frame_stack_size_2 != A68 (frame_stack_size) || expr_stack_size_2 != A68 (expr_stack_size) || heap_size_2 != A68 (heap_size) || handle_pool_size_2 != A68 (handle_pool_size)) {
+    if (frame_stack_size_2 != A68G (frame_stack_size) || expr_stack_size_2 != A68G (expr_stack_size) || heap_size_2 != A68G (heap_size) || handle_pool_size_2 != A68G (handle_pool_size)) {
       announce_phase ("tokeniser");
-      free_syntax_tree (TOP_NODE (&A68_JOB));
+      free_syntax_tree (TOP_NODE (&A68G_JOB));
       discard_heap ();
       init_before_tokeniser ();
-      SOURCE_SCAN (&A68_JOB)++;
+      SOURCE_SCAN (&A68G_JOB)++;
       ok = lexical_analyser ();
       verbosity ();
     }
     if (!ok || errno != 0) {
-      diagnostics_to_terminal (TOP_LINE (&A68_JOB), A68_ALL_DIAGNOSTICS);
+      diagnostics_to_terminal (TOP_LINE (&A68G_JOB), A68G_ALL_DIAGNOSTICS);
       return;
     }
-    ASSERT (close (FILE_SOURCE_FD (&A68_JOB)) == 0);
-    FILE_SOURCE_OPENED (&A68_JOB) = A68_FALSE;
-    prune_echoes (OPTION_LIST (&A68_JOB));
-    TREE_LISTING_SAFE (&A68_JOB) = A68_TRUE;
+    ASSERT (close (FILE_SOURCE_FD (&A68G_JOB)) == 0);
+    FILE_SOURCE_OPENED (&A68G_JOB) = A68G_FALSE;
+    prune_echoes (OPTION_LIST (&A68G_JOB));
+    TREE_LISTING_SAFE (&A68G_JOB) = A68G_TRUE;
     int renum = 0;
-    renumber_nodes (TOP_NODE (&A68_JOB), &renum);
+    renumber_nodes (TOP_NODE (&A68G_JOB), &renum);
   }
 // Now the default precision of LONG LONG modes is fixed.
   if (long_mp_digits () == 0) {
     set_long_mp_digits (LONG_LONG_MP_DIGITS);
   }
 // Final initialisations.
-  if (ERROR_COUNT (&A68_JOB) == 0) {
-    if (OPTION_REGRESSION_TEST (&A68_JOB)) {
-      a68g_bufcpy (A68 (a68g_cmd_name), "a68g", BUFFER_SIZE);
+  if (ERROR_COUNT (&A68G_JOB) == 0) {
+    if (OPTION_REGRESSION_TEST (&A68G_JOB)) {
+      a68g_bufcpy (A68G (a68g_cmd_name), "a68g", BUFFER_SIZE);
       io_close_tty_line ();
-      WRITE (A68_STDERR, "[");
-      WRITE (A68_STDERR, FILE_INITIAL_NAME (&A68_JOB));
-      WRITE (A68_STDERR, "]\n");
+      WRITE (A68G_STDERR, "[");
+      WRITE (A68G_STDERR, FILE_INITIAL_NAME (&A68G_JOB));
+      WRITE (A68G_STDERR, "]\n");
     }
-    A68_STANDENV = NO_TABLE;
+    A68G_STANDENV = NO_TABLE;
     init_postulates ();
-    A68 (mode_count) = 0;
-    make_special_mode (&M_HIP, A68 (mode_count)++);
-    make_special_mode (&M_UNDEFINED, A68 (mode_count)++);
-    make_special_mode (&M_ERROR, A68 (mode_count)++);
-    make_special_mode (&M_VACUUM, A68 (mode_count)++);
-    make_special_mode (&M_C_STRING, A68 (mode_count)++);
-    make_special_mode (&M_COLLITEM, A68 (mode_count)++);
-    make_special_mode (&M_SOUND_DATA, A68 (mode_count)++);
+    A68G (mode_count) = 0;
+    make_special_mode (&M_HIP, A68G (mode_count)++);
+    make_special_mode (&M_UNDEFINED, A68G (mode_count)++);
+    make_special_mode (&M_ERROR, A68G (mode_count)++);
+    make_special_mode (&M_VACUUM, A68G (mode_count)++);
+    make_special_mode (&M_C_STRING, A68G (mode_count)++);
+    make_special_mode (&M_COLLITEM, A68G (mode_count)++);
+    make_special_mode (&M_SOUND_DATA, A68G (mode_count)++);
   }
 // Refinement preprocessor.
-  if (ERROR_COUNT (&A68_JOB) == 0) {
+  if (ERROR_COUNT (&A68G_JOB) == 0) {
     announce_phase ("preprocessor");
     get_refinements ();
-    if (ERROR_COUNT (&A68_JOB) == 0) {
+    if (ERROR_COUNT (&A68G_JOB) == 0) {
       put_refinements ();
     }
     int renum = 0;
-    renumber_nodes (TOP_NODE (&A68_JOB), &renum);
+    renumber_nodes (TOP_NODE (&A68G_JOB), &renum);
     verbosity ();
   }
 // Top-down parser.
-  if (ERROR_COUNT (&A68_JOB) == 0) {
+  if (ERROR_COUNT (&A68G_JOB) == 0) {
     announce_phase ("parser phase 1");
-    check_parenthesis (TOP_NODE (&A68_JOB));
-    if (ERROR_COUNT (&A68_JOB) == 0) {
-      if (OPTION_BRACKETS (&A68_JOB)) {
-        substitute_brackets (TOP_NODE (&A68_JOB));
+    check_parenthesis (TOP_NODE (&A68G_JOB));
+    if (ERROR_COUNT (&A68G_JOB) == 0) {
+      if (OPTION_BRACKETS (&A68G_JOB)) {
+        substitute_brackets (TOP_NODE (&A68G_JOB));
       }
-      A68 (symbol_table_count) = 0;
-      A68_STANDENV = new_symbol_table (NO_TABLE);
-      LEVEL (A68_STANDENV) = 0;
-      top_down_parser (TOP_NODE (&A68_JOB));
+      A68G (symbol_table_count) = 0;
+      A68G_STANDENV = new_symbol_table (NO_TABLE);
+      LEVEL (A68G_STANDENV) = 0;
+      top_down_parser (TOP_NODE (&A68G_JOB));
     }
     int renum = 0;
-    renumber_nodes (TOP_NODE (&A68_JOB), &renum);
+    renumber_nodes (TOP_NODE (&A68G_JOB), &renum);
     verbosity ();
   }
 // Standard environment builder.
-  if (ERROR_COUNT (&A68_JOB) == 0) {
+  if (ERROR_COUNT (&A68G_JOB) == 0) {
     announce_phase ("standard environ builder");
-    TABLE (TOP_NODE (&A68_JOB)) = new_symbol_table (A68_STANDENV);
+    TABLE (TOP_NODE (&A68G_JOB)) = new_symbol_table (A68G_STANDENV);
     make_standard_environ ();
-    STANDENV_MOID (&A68_JOB) = TOP_MOID (&A68_JOB);
+    STANDENV_MOID (&A68G_JOB) = TOP_MOID (&A68G_JOB);
     verbosity ();
   }
 // Bottom-up parser.
-  if (ERROR_COUNT (&A68_JOB) == 0) {
+  if (ERROR_COUNT (&A68G_JOB) == 0) {
     announce_phase ("parser phase 2");
-    preliminary_symbol_table_setup (TOP_NODE (&A68_JOB));
-    bottom_up_parser (TOP_NODE (&A68_JOB));
+    preliminary_symbol_table_setup (TOP_NODE (&A68G_JOB));
+    bottom_up_parser (TOP_NODE (&A68G_JOB));
     int renum = 0;
-    renumber_nodes (TOP_NODE (&A68_JOB), &renum);
+    renumber_nodes (TOP_NODE (&A68G_JOB), &renum);
     verbosity ();
   }
-  if (ERROR_COUNT (&A68_JOB) == 0) {
+  if (ERROR_COUNT (&A68G_JOB) == 0) {
     announce_phase ("parser phase 3");
-    bottom_up_error_check (TOP_NODE (&A68_JOB));
-    victal_checker (TOP_NODE (&A68_JOB));
-    if (ERROR_COUNT (&A68_JOB) == 0) {
-      finalise_symbol_table_setup (TOP_NODE (&A68_JOB), 2);
-      NEST (TABLE (TOP_NODE (&A68_JOB))) = A68 (symbol_table_count) = 3;
-      reset_symbol_table_nest_count (TOP_NODE (&A68_JOB));
-      fill_symbol_table_outer (TOP_NODE (&A68_JOB), TABLE (TOP_NODE (&A68_JOB)));
-      set_nest (TOP_NODE (&A68_JOB), NO_NODE);
-      set_proc_level (TOP_NODE (&A68_JOB), 1);
+    bottom_up_error_check (TOP_NODE (&A68G_JOB));
+    victal_checker (TOP_NODE (&A68G_JOB));
+    if (ERROR_COUNT (&A68G_JOB) == 0) {
+      finalise_symbol_table_setup (TOP_NODE (&A68G_JOB), 2);
+      NEST (TABLE (TOP_NODE (&A68G_JOB))) = A68G (symbol_table_count) = 3;
+      reset_symbol_table_nest_count (TOP_NODE (&A68G_JOB));
+      fill_symbol_table_outer (TOP_NODE (&A68G_JOB), TABLE (TOP_NODE (&A68G_JOB)));
+      set_nest (TOP_NODE (&A68G_JOB), NO_NODE);
+      set_proc_level (TOP_NODE (&A68G_JOB), 1);
     }
     int renum = 0;
-    renumber_nodes (TOP_NODE (&A68_JOB), &renum);
+    renumber_nodes (TOP_NODE (&A68G_JOB), &renum);
     verbosity ();
   }
 // Mode table builder.
-  if (ERROR_COUNT (&A68_JOB) == 0) {
+  if (ERROR_COUNT (&A68G_JOB) == 0) {
     announce_phase ("mode table builder");
-    make_moid_list (&A68_JOB);
+    make_moid_list (&A68G_JOB);
     verbosity ();
   }
-  CROSS_REFERENCE_SAFE (&A68_JOB) = A68_TRUE;
+  CROSS_REFERENCE_SAFE (&A68G_JOB) = A68G_TRUE;
 // Symbol table builder.
-  if (ERROR_COUNT (&A68_JOB) == 0) {
+  if (ERROR_COUNT (&A68G_JOB) == 0) {
     announce_phase ("symbol table builder");
-    collect_taxes (TOP_NODE (&A68_JOB));
+    collect_taxes (TOP_NODE (&A68G_JOB));
     verbosity ();
   }
 // Post parser.
-  if (ERROR_COUNT (&A68_JOB) == 0) {
+  if (ERROR_COUNT (&A68G_JOB) == 0) {
     announce_phase ("parser phase 4");
-    rearrange_goto_less_jumps (TOP_NODE (&A68_JOB));
+    rearrange_goto_less_jumps (TOP_NODE (&A68G_JOB));
     verbosity ();
   }
 // Mode checker.
-  if (ERROR_COUNT (&A68_JOB) == 0) {
+  if (ERROR_COUNT (&A68G_JOB) == 0) {
     announce_phase ("mode checker");
-    mode_checker (TOP_NODE (&A68_JOB));
+    mode_checker (TOP_NODE (&A68G_JOB));
     verbosity ();
   }
 // Coercion inserter.
-  if (ERROR_COUNT (&A68_JOB) == 0) {
+  if (ERROR_COUNT (&A68G_JOB) == 0) {
     announce_phase ("coercion enforcer");
-    coercion_inserter (TOP_NODE (&A68_JOB));
-    widen_denotation (TOP_NODE (&A68_JOB));
-    get_max_simplout_size (TOP_NODE (&A68_JOB));
-    set_moid_sizes (TOP_MOID (&A68_JOB));
-    assign_offsets_table (A68_STANDENV);
-    assign_offsets (TOP_NODE (&A68_JOB));
-    assign_offsets_packs (TOP_MOID (&A68_JOB));
+    coercion_inserter (TOP_NODE (&A68G_JOB));
+    widen_denotation (TOP_NODE (&A68G_JOB));
+    get_max_simplout_size (TOP_NODE (&A68G_JOB));
+    set_moid_sizes (TOP_MOID (&A68G_JOB));
+    verbosity ();
+  }
+// Finalize tree.
+  if (ERROR_COUNT (&A68G_JOB) == 0) {
+    announce_phase ("finalize tree");
+    if (OPTION_CONSERVATIVE_GC (&A68G_JOB) == A68G_FALSE) {
+      annotate_gc (TOP_NODE (&A68G_JOB));
+    }
+    assign_offsets_table (A68G_STANDENV);
+    assign_offsets (TOP_NODE (&A68G_JOB));
+    assign_offsets_packs (TOP_MOID (&A68G_JOB));
     int renum = 0;
-    renumber_nodes (TOP_NODE (&A68_JOB), &renum);
+    renumber_nodes (TOP_NODE (&A68G_JOB), &renum);
     verbosity ();
   }
 // Application checker.
-  if (ERROR_COUNT (&A68_JOB) == 0) {
+  if (ERROR_COUNT (&A68G_JOB) == 0) {
     announce_phase ("application checker");
-    mark_moids (TOP_NODE (&A68_JOB));
-    mark_auxilliary (TOP_NODE (&A68_JOB));
-    jumps_from_procs (TOP_NODE (&A68_JOB));
-    warn_for_unused_tags (TOP_NODE (&A68_JOB));
+    mark_moids (TOP_NODE (&A68G_JOB));
+    mark_auxilliary (TOP_NODE (&A68G_JOB));
+    jumps_from_procs (TOP_NODE (&A68G_JOB));
+    warn_for_unused_tags (TOP_NODE (&A68G_JOB));
     verbosity ();
   }
 // Scope checker.
-  if (ERROR_COUNT (&A68_JOB) == 0) {
+  if (ERROR_COUNT (&A68G_JOB) == 0) {
     announce_phase ("static scope checker");
-    tie_label_to_serial (TOP_NODE (&A68_JOB));
-    tie_label_to_unit (TOP_NODE (&A68_JOB));
-    bind_routine_tags_to_tree (TOP_NODE (&A68_JOB));
-    bind_format_tags_to_tree (TOP_NODE (&A68_JOB));
-    scope_checker (TOP_NODE (&A68_JOB));
+    tie_label_to_serial (TOP_NODE (&A68G_JOB));
+    tie_label_to_unit (TOP_NODE (&A68G_JOB));
+    bind_routine_tags_to_tree (TOP_NODE (&A68G_JOB));
+    bind_format_tags_to_tree (TOP_NODE (&A68G_JOB));
+    scope_checker (TOP_NODE (&A68G_JOB));
     verbosity ();
   }
 }
@@ -741,7 +753,7 @@ void renumber_nodes (NODE_T * p, int *n)
 void register_nodes (NODE_T * p)
 {
   for (; p != NO_NODE; FORWARD (p)) {
-    A68 (node_register)[NUMBER (p)] = p;
+    A68G (node_register)[NUMBER (p)] = p;
     register_nodes (SUB (p));
   }
 }
@@ -750,8 +762,8 @@ void register_nodes (NODE_T * p)
 
 NODE_INFO_T *new_node_info (void)
 {
-  NODE_INFO_T *z = (NODE_INFO_T *) get_fixed_heap_space ((size_t) SIZE_ALIGNED (NODE_INFO_T));
-  A68 (new_node_infos)++;
+  NODE_INFO_T *z = (NODE_INFO_T *) get_fixed_heap_space (SIZE_ALIGNED (NODE_INFO_T));
+  A68G (new_node_infos)++;
   PROCEDURE_LEVEL (z) = 0;
   CHAR_IN_LINE (z) = NO_TEXT;
   SYMBOL (z) = NO_TEXT;
@@ -765,15 +777,15 @@ NODE_INFO_T *new_node_info (void)
 
 GINFO_T *new_genie_info (void)
 {
-  GINFO_T *z = (GINFO_T *) get_fixed_heap_space ((size_t) SIZE_ALIGNED (GINFO_T));
-  A68 (new_genie_infos)++;
+  GINFO_T *z = (GINFO_T *) get_fixed_heap_space (SIZE_ALIGNED (GINFO_T));
+  A68G (new_genie_infos)++;
   UNIT (&PROP (z)) = NO_PPROC;
   SOURCE (&PROP (z)) = NO_NODE;
   PARTIAL_PROC (z) = NO_MOID;
   PARTIAL_LOCALE (z) = NO_MOID;
-  IS_COERCION (z) = A68_FALSE;
-  IS_NEW_LEXICAL_LEVEL (z) = A68_FALSE;
-  NEED_DNS (z) = A68_FALSE;
+  IS_COERCION (z) = A68G_FALSE;
+  IS_NEW_LEXICAL_LEVEL (z) = A68G_FALSE;
+  NEED_DNS (z) = A68G_FALSE;
   PARENT (z) = NO_NODE;
   OFFSET (z) = NO_BYTE;
   CONSTANT (z) = NO_CONSTANT;
@@ -789,8 +801,8 @@ GINFO_T *new_genie_info (void)
 
 NODE_T *new_node (void)
 {
-  NODE_T *z = (NODE_T *) get_fixed_heap_space ((size_t) SIZE_ALIGNED (NODE_T));
-  A68 (new_nodes)++;
+  NODE_T *z = (NODE_T *) get_fixed_heap_space (SIZE_ALIGNED (NODE_T));
+  A68G (new_nodes)++;
   STATUS (z) = NULL_MASK;
   CODEX (z) = NULL_MASK;
   TABLE (z) = NO_TABLE;
@@ -805,6 +817,7 @@ NODE_T *new_node (void)
   NEST (z) = NO_NODE;
   NON_LOCAL (z) = NO_TABLE;
   TAX (z) = NO_TAG;
+  TAX_GC (z) = NO_TAG;
   SEQUENCE (z) = NO_NODE;
   PACK (z) = NO_PACK;
   return z;
@@ -814,15 +827,15 @@ NODE_T *new_node (void)
 
 TABLE_T *new_symbol_table (TABLE_T * p)
 {
-  TABLE_T *z = (TABLE_T *) get_fixed_heap_space ((size_t) SIZE_ALIGNED (TABLE_T));
-  NUM (z) = A68 (symbol_table_count);
-  LEVEL (z) = A68 (symbol_table_count)++;
-  NEST (z) = A68 (symbol_table_count);
+  TABLE_T *z = (TABLE_T *) get_fixed_heap_space (SIZE_ALIGNED (TABLE_T));
+  NUM (z) = A68G (symbol_table_count);
+  LEVEL (z) = A68G (symbol_table_count)++;
+  NEST (z) = A68G (symbol_table_count);
   ATTRIBUTE (z) = 0;
   AP_INCREMENT (z) = 0;
-  INITIALISE_FRAME (z) = A68_TRUE;
-  PROC_OPS (z) = A68_TRUE;
-  INITIALISE_ANON (z) = A68_TRUE;
+  INITIALISE_FRAME (z) = A68G_TRUE;
+  PROC_OPS (z) = A68G_TRUE;
+  INITIALISE_ANON (z) = A68G_TRUE;
   PREVIOUS (z) = p;
   OUTER (z) = NO_TABLE;
   IDENTIFIERS (z) = NO_TAG;
@@ -840,19 +853,19 @@ TABLE_T *new_symbol_table (TABLE_T * p)
 
 MOID_T *new_moid (void)
 {
-  MOID_T *z = (MOID_T *) get_fixed_heap_space ((size_t) SIZE_ALIGNED (MOID_T));
-  A68 (new_modes)++;
+  MOID_T *z = (MOID_T *) get_fixed_heap_space (SIZE_ALIGNED (MOID_T));
+  A68G (new_modes)++;
   ATTRIBUTE (z) = 0;
   NUMBER (z) = 0;
   DIM (z) = 0;
-  USE (z) = A68_FALSE;
-  HAS_ROWS (z) = A68_FALSE;
+  USE (z) = A68G_FALSE;
+  HAS_ROWS (z) = A68G_FALSE;
   SIZE (z) = 0;
   DIGITS (z) = 0;
   SIZE_COMPL (z) = 0;
   DIGITS_COMPL (z) = 0;
-  PORTABLE (z) = A68_TRUE;
-  DERIVATE (z) = A68_FALSE;
+  PORTABLE (z) = A68G_TRUE;
+  DERIVATE (z) = A68G_FALSE;
   NODE (z) = NO_NODE;
   PACK (z) = NO_PACK;
   SUB (z) = NO_MOID;
@@ -870,7 +883,7 @@ MOID_T *new_moid (void)
 
 PACK_T *new_pack (void)
 {
-  PACK_T *z = (PACK_T *) get_fixed_heap_space ((size_t) SIZE_ALIGNED (PACK_T));
+  PACK_T *z = (PACK_T *) get_fixed_heap_space (SIZE_ALIGNED (PACK_T));
   MOID (z) = NO_MOID;
   TEXT (z) = NO_TEXT;
   NODE (z) = NO_NODE;
@@ -885,7 +898,7 @@ PACK_T *new_pack (void)
 
 TAG_T *new_tag (void)
 {
-  TAG_T *z = (TAG_T *) get_fixed_heap_space ((size_t) SIZE_ALIGNED (TAG_T));
+  TAG_T *z = (TAG_T *) get_fixed_heap_space (SIZE_ALIGNED (TAG_T));
   STATUS (z) = NULL_MASK;
   CODEX (z) = NULL_MASK;
   TAG_TABLE (z) = NO_TABLE;
@@ -893,22 +906,22 @@ TAG_T *new_tag (void)
   NODE (z) = NO_NODE;
   UNIT (z) = NO_NODE;
   VALUE (z) = NO_TEXT;
-  A68_STANDENV_PROC (z) = 0;
+  A68G_STANDENV_PROC (z) = 0;
   PROCEDURE (z) = NO_GPROC;
   SCOPE (z) = PRIMAL_SCOPE;
-  SCOPE_ASSIGNED (z) = A68_FALSE;
+  SCOPE_ASSIGNED (z) = A68G_FALSE;
   PRIO (z) = 0;
-  USE (z) = A68_FALSE;
-  IN_PROC (z) = A68_FALSE;
-  HEAP (z) = A68_FALSE;
+  USE (z) = A68G_FALSE;
+  IN_PROC (z) = A68G_FALSE;
+  HEAP (z) = A68G_FALSE;
   SIZE (z) = 0;
   OFFSET (z) = 0;
   YOUNGEST_ENVIRON (z) = PRIMAL_SCOPE;
-  LOC_ASSIGNED (z) = A68_FALSE;
+  LOC_ASSIGNED (z) = A68G_FALSE;
   NEXT (z) = NO_TAG;
   BODY (z) = NO_TAG;
-  PORTABLE (z) = A68_TRUE;
-  NUMBER (z) = ++A68_PARSER (tag_number);
+  PORTABLE (z) = A68G_TRUE;
+  NUMBER (z) = ++A68G_PARSER (tag_number);
   return z;
 }
 
@@ -929,23 +942,6 @@ void make_special_mode (MOID_T ** n, int m)
   ROWED (*n) = NO_MOID;
 }
 
-//! @brief Whether x matches c; case insensitive.
-
-BOOL_T match_string (char *x, char *c, char alt)
-{
-  BOOL_T match = A68_TRUE;
-  while ((IS_UPPER (c[0]) || IS_DIGIT (c[0]) || c[0] == '-') && match) {
-    match = (BOOL_T) (match & (TO_LOWER (x[0]) == TO_LOWER ((c++)[0])));
-    if (!(x[0] == NULL_CHAR || x[0] == alt)) {
-      x++;
-    }
-  }
-  while (x[0] != NULL_CHAR && x[0] != alt && c[0] != NULL_CHAR && match) {
-    match = (BOOL_T) (match & (TO_LOWER ((x++)[0]) == TO_LOWER ((c++)[0])));
-  }
-  return (BOOL_T) (match ? (x[0] == NULL_CHAR || x[0] == alt) : A68_FALSE);
-}
-
 //! @brief Whether attributes match in subsequent nodes.
 
 BOOL_T whether (NODE_T * p, ...)
@@ -958,21 +954,21 @@ BOOL_T whether (NODE_T * p, ...)
     if (p != NO_NODE && a == WILDCARD) {
       FORWARD (p);
     } else if (p != NO_NODE && (a == KEYWORD)) {
-      if (find_keyword_from_attribute (A68 (top_keyword), ATTRIBUTE (p)) != NO_KEYWORD) {
+      if (find_keyword_from_attribute (A68G (top_keyword), ATTRIBUTE (p)) != NO_KEYWORD) {
         FORWARD (p);
       } else {
         va_end (vl);
-        return A68_FALSE;
+        return A68G_FALSE;
       }
     } else if (p != NO_NODE && (a >= 0 ? a == ATTRIBUTE (p) : (-a) != ATTRIBUTE (p))) {
       FORWARD (p);
     } else {
       va_end (vl);
-      return A68_FALSE;
+      return A68G_FALSE;
     }
   }
   va_end (vl);
-  return A68_TRUE;
+  return A68G_TRUE;
 }
 
 //! @brief Whether one of a series of attributes matches a node.
@@ -982,7 +978,7 @@ BOOL_T is_one_of (NODE_T * p, ...)
   if (p != NO_NODE) {
     va_list vl;
     va_start (vl, p);
-    BOOL_T match = A68_FALSE;
+    BOOL_T match = A68G_FALSE;
     int a;
     while ((a = va_arg (vl, int)) != STOP)
     {
@@ -991,7 +987,7 @@ BOOL_T is_one_of (NODE_T * p, ...)
     va_end (vl);
     return match;
   } else {
-    return A68_FALSE;
+    return A68G_FALSE;
   }
 }
 
@@ -1072,10 +1068,10 @@ BOOL_T is_new_lexical_level (NODE_T * p)
   case CONFORMITY_IN_PART:
   case CONFORMITY_OUSE_PART:
   case WHILE_PART: {
-      return A68_TRUE;
+      return A68G_TRUE;
     }
   default: {
-      return A68_FALSE;
+      return A68G_FALSE;
     }
   }
 }
