@@ -521,7 +521,7 @@ char *gen_call (NODE_T * p, FILE_T out, int compose_fun)
       write_fun_prelude (p, out, fun);
     }
 // Compute arguments.
-    int size = 0;
+    size_t size = 0;
     A68G_OPT (root_idf) = NO_DEC;
     inline_arguments (args, out, L_DECLARE, &size);
     (void) add_declaration (&A68G_OPT (root_idf), "ADDR_T", 0, pop);
@@ -588,7 +588,7 @@ char *gen_voiding_call (NODE_T * p, FILE_T out, int compose_fun)
       write_fun_prelude (p, out, fun);
     }
 // Compute arguments.
-    int size = 0;
+    size_t size = 0;
     A68G_OPT (root_idf) = NO_DEC;
     inline_arguments (args, out, L_DECLARE, &size);
     (void) add_declaration (&A68G_OPT (root_idf), "ADDR_T", 0, pop);
