@@ -104,7 +104,7 @@ void plugin_driver_emit (FILE_T out)
   A68G_OPT (cse_pointer) = 0;
   A68G_OPT (unic_pointer) = 0;
   A68G_OPT (root_idf) = NO_DEC;
-  A68G (global_level) = INT_MAX;
+  A68G (global_level) = A68G_MAX_LEX_LEVEL;
   A68G_GLOBALS = 0;
   get_global_level (SUB (TOP_NODE (&A68G_JOB)));
   A68G (max_lex_lvl) = 0;
@@ -249,7 +249,7 @@ DEC_T *add_identifier (DEC_T ** p, int level, char *idf)
       return *p;
     }
   }
-  *p = (DEC_T *) get_temp_heap_space ((size_t) SIZE_ALIGNED (DEC_T));
+  *p = (DEC_T *) get_temp_heap_space (SIZE_ALIGNED (DEC_T));
   TEXT (*p) = z;
   LEVEL (*p) = level;
   SUB (*p) = LESS (*p) = MORE (*p) = NO_DEC;
@@ -272,7 +272,7 @@ DEC_T *add_declaration (DEC_T ** p, char *mode, int level, char *idf)
       return *p;
     }
   }
-  *p = (DEC_T *) get_temp_heap_space ((size_t) SIZE_ALIGNED (DEC_T));
+  *p = (DEC_T *) get_temp_heap_space (SIZE_ALIGNED (DEC_T));
   TEXT (*p) = z;
   LEVEL (*p) = -1;
   SUB (*p) = LESS (*p) = MORE (*p) = NO_DEC;
@@ -931,7 +931,6 @@ char *compile_call (NODE_T * p, FILE_T out)
   } else {
     static char fn[NAME_SIZE];
     char fun[NAME_SIZE], pop[NAME_SIZE];
-    int size;
 // Declare.
     (void) make_name (fun, FUN, "", NUMBER (proc));
     (void) make_name (pop, PUP, "", NUMBER (p));
@@ -939,7 +938,7 @@ char *compile_call (NODE_T * p, FILE_T out)
     (void) make_name (fn, moid_with_name ("", SUB_MOID (proc), "_call"), "", NUMBER (p));
     write_fun_prelude (p, out, fn);
 // Compute arguments.
-    size = 0;
+    size_t size = 0;
     A68G_OPT (root_idf) = NO_DEC;
     inline_arguments (args, out, L_DECLARE, &size);
     (void) add_declaration (&A68G_OPT (root_idf), "ADDR_T", 0, pop);
