@@ -31,7 +31,7 @@
 #if defined (HAVE_CURL)
 
 #if defined (HAVE_CURL_CURL_H)
-#  include <curl/curl.h>
+  #include <curl/curl.h>
 #endif
 
 typedef struct DATA_T DATA_T;
@@ -52,12 +52,12 @@ static size_t a68g_curl_concat (void *data, size_t len, size_t n, void *buf)
   } else if (n == 0 || len == 0) {
     return 0;
   }
-  ABEND (len >= (2 * GIGABYTE) / n, ERROR_OUT_OF_CORE, NO_TEXT);
+  ABEND (len >= (2 * GIGABYTE) / n, ERROR_MEMORY_FULL, NO_TEXT);
   size_t new_len = n * len;
-  ABEND (new_len + 1 > 2 * GIGABYTE - ((DATA_T *) buf)->len, ERROR_OUT_OF_CORE, NO_TEXT);
+  ABEND (new_len + 1 > 2 * GIGABYTE - ((DATA_T *) buf)->len, ERROR_MEMORY_FULL, NO_TEXT);
   char *stale = ((DATA_T *) buf)->ref;
   ((DATA_T *) buf)->ref = malloc (((DATA_T *) buf)->len + new_len + 1);
-  ABEND (((DATA_T *) buf)->ref == NO_TEXT, ERROR_OUT_OF_CORE, NO_TEXT);
+  ABEND (((DATA_T *) buf)->ref == NO_TEXT, ERROR_MEMORY_FULL, NO_TEXT);
   if (stale != NO_TEXT) {
     MOVE (((DATA_T *) buf)->ref, stale, ((DATA_T *) buf)->len + 1);
     free (stale);
@@ -70,11 +70,11 @@ static size_t a68g_curl_concat (void *data, size_t len, size_t n, void *buf)
 
 void genie_curl_content (NODE_T * p, char *protocol)
 {
-  A68_REF path_string, domain_string, content_string;
-  A68_INT port;
+  A68G_REF path_string, domain_string, content_string;
+  A68G_INT port;
   errno = 0;
 // Pop arguments.
-  POP_OBJECT (p, &port, A68_INT);
+  POP_OBJECT (p, &port, A68G_INT);
   CHECK_INIT (p, INITIALISED (&port), M_INT); // Unused for now.
   POP_REF (p, &path_string);
   CHECK_INIT (p, INITIALISED (&path_string), M_STRING);
@@ -82,7 +82,7 @@ void genie_curl_content (NODE_T * p, char *protocol)
   CHECK_INIT (p, INITIALISED (&domain_string), M_STRING);
   POP_REF (p, &content_string);
   CHECK_REF (p, content_string, M_REF_STRING);
-  *DEREF (A68_REF, &content_string) = empty_string (p);
+  *DEREF (A68G_REF, &content_string) = empty_string (p);
 // Set buffers.
   reset_transput_buffer (DOMAIN_BUFFER);
   add_a_string_transput_buffer (p, DOMAIN_BUFFER, (BYTE_T *) & domain_string);
@@ -108,14 +108,14 @@ void genie_curl_content (NODE_T * p, char *protocol)
   if (rc != CURLE_OK) {
     errno = rc;
   } else {
-    *DEREF (A68_REF, &content_string) = c_to_a_string (p, data.ref, data.len);
+    *DEREF (A68G_REF, &content_string) = c_to_a_string (p, data.ref, data.len);
   }
   if (data.ref != NO_TEXT) {
     free (data.ref);
   }
   curl_easy_cleanup (handle);
   curl_global_cleanup ();
-  PUSH_VALUE (p, errno, A68_INT);
+  PUSH_VALUE (p, errno, A68G_INT);
 }
 
 //! @brief PROC (REF STRING, STRING, STRING, INT) INT http content 
