@@ -84,6 +84,17 @@
 
 #define DEF_NODE(p) (NEXT_NEXT (NODE (TAX (p))))
 
+//! @brief Check overflow at size multiplication.
+
+BOOL_T size_mul_overflow (size_t u, size_t v)
+{
+  if (u == 0 || v == 0) {
+    return (A68G_FALSE);
+  } else {
+    return v > (MAX_MEM_SIZE / u);
+  }
+}
+
 //! @brief PROC VOID gc heap
 
 void genie_gc_heap (NODE_T * p)
@@ -97,6 +108,7 @@ void genie_preemptive_gc_heap (NODE_T * p)
 {
   if (A68G_GC (preemptive)) {
     gc_heap (p, A68G_FP);
+    A68G_GC (preemptive) = A68G_FALSE;
   }
 }
 
@@ -138,9 +150,13 @@ void genie_garbage_seconds (NODE_T * p)
 
 //! @brief Size available for an object in the heap.
 
-unt heap_available (void)
+size_t heap_available (void)
 {
-  return A68G (heap_size) - A68G_HP;
+  if (A68G (temp_heap_pointer) > A68G_HP) {
+    return A68G (temp_heap_pointer) - A68G_HP;
+  } else {
+    return 0;
+  }
 }
 
 //! @brief Initialise heap management.
@@ -149,11 +165,11 @@ void genie_init_heap (NODE_T * p)
 {
   (void) p;
   if (A68G_HEAP == NO_BYTE) {
-    diagnostic (A68G_RUNTIME_ERROR, TOP_NODE (&A68G_JOB), ERROR_OUT_OF_CORE);
+    diagnostic (A68G_RUNTIME_ERROR, TOP_NODE (&A68G_JOB), ERROR_MEMORY_FULL);
     exit_genie (TOP_NODE (&A68G_JOB), A68G_RUNTIME_ERROR);
   }
   if (A68G_HANDLES == NO_BYTE) {
-    diagnostic (A68G_RUNTIME_ERROR, TOP_NODE (&A68G_JOB), ERROR_OUT_OF_CORE);
+    diagnostic (A68G_RUNTIME_ERROR, TOP_NODE (&A68G_JOB), ERROR_MEMORY_FULL);
     exit_genie (TOP_NODE (&A68G_JOB), A68G_RUNTIME_ERROR);
   }
   A68G_GC (seconds) = 0;
@@ -161,14 +177,15 @@ void genie_init_heap (NODE_T * p)
   A68G_GC (sweeps) = 0;
   A68G_GC (refused) = 0;
   A68G_GC (preemptive) = A68G_FALSE;
-  ABEND (A68G (fixed_heap_pointer) >= (A68G (heap_size) - MIN_MEM_SIZE), ERROR_OUT_OF_CORE, __func__);
+  // Make sure we have some space for an A68 heap.
+  ABEND ((A68G (fixed_heap_pointer) + 2 * A68G (storage_overhead)) >= A68G (temp_heap_pointer), ERROR_MEMORY_FULL, __func__);
   A68G_HP = A68G (fixed_heap_pointer);
   A68G (heap_is_fluid) = A68G_FALSE;
 // Assign handle space.
   A68G_HANDLE *z = (A68G_HANDLE *) A68G_HANDLES;
   A68G_GC (available_handles) = z;
   A68G_GC (busy_handles) = NO_HANDLE;
-  int N = (unt) A68G (handle_pool_size) / SIZE_ALIGNED (A68G_HANDLE);
+  size_t N = A68G (handle_pool_size) / SIZE_ALIGNED (A68G_HANDLE);
   A68G_GC (free_handles) = N;
   A68G_GC (max_handles) = N;
   for (int k = 0; k < N; k++) {
@@ -199,6 +216,8 @@ BOOL_T moid_needs_colouring (MOID_T * m)
     return A68G_FALSE;
   } else if (m == M_SIMPLIN || m == M_SIMPLOUT) {
     return A68G_TRUE;
+  } else if (m == M_SOUND) {
+    return A68G_TRUE;
   } else {
     return A68G_FALSE;
   }
@@ -379,7 +398,7 @@ void defragment_heap (void)
   for (; z != NO_HANDLE; BACKWARD (z)) {
     BYTE_T *dst = HEAP_ADDRESS (A68G_HP);
     if (dst != POINTER (z)) {
-      MOVE (dst, POINTER (z), (unt) SIZE (z));
+      MOVE (dst, POINTER (z), SIZE (z));
     }
     STATUS_CLEAR (z, (COLOUR_MASK | COOKIE_MASK));
     POINTER (z) = dst;
@@ -405,7 +424,11 @@ void gc_heap (NODE_T * p, ADDR_T fp)
     A68G_GC (refused)++;
     return;
   }
-  if (OPTION_CONSERVATIVE_GC (&A68G_JOB) && (A68G_GC (sema) > 0)) {
+  if (OPTION_CONSERVATIVE_GC (&A68G_JOB) == A68G_GC_HALT) {
+    A68G_GC (refused)++;
+    return;
+  }
+  if (OPTION_CONSERVATIVE_GC (&A68G_JOB) == A68G_GC_SAFE && (A68G_GC (sema) > 0)) {
     A68G_GC (refused)++;
     return;
   }
@@ -466,7 +489,7 @@ A68G_HANDLE *give_handle (NODE_T * p, MOID_T * a68m)
     return x;
   } else {
 // Do not auto-GC!.
-    diagnostic (A68G_RUNTIME_ERROR, p, ERROR_OUT_OF_CORE);
+    diagnostic (A68G_RUNTIME_ERROR, p, ERROR_MEMORY_FULL);
     exit_genie (p, A68G_RUNTIME_ERROR);
   }
   return NO_HANDLE;
@@ -474,7 +497,7 @@ A68G_HANDLE *give_handle (NODE_T * p, MOID_T * a68m)
 
 //! @brief Give a block of heap for an object of indicated mode.
 
-A68G_REF heap_generator (NODE_T * p, MOID_T * mode, int size)
+A68G_REF heap_generator (NODE_T * p, MOID_T * mode, size_t size)
 {
   ABEND (size < 0, ERROR_INVALID_SIZE, __func__);
   size = A68G_ALIGN (size);
@@ -488,17 +511,24 @@ A68G_REF heap_generator (NODE_T * p, MOID_T * mode, int size)
     FILL (POINTER (x), 0, size);
     REF_SCOPE (&z) = PRIMAL_SCOPE;
     REF_HANDLE (&z) = x;
-    ABEND (((long) ADDRESS (&z)) % A68G_ALIGNMENT != 0, ERROR_ALIGNMENT, __func__);
+    ABEND (((size_t) ADDRESS (&z)) % A68G_ALIGNMENT != 0, ERROR_ALIGNMENT, __func__);
     A68G_HP += size;
-    REAL_T _f_ = (REAL_T) A68G_HP / (REAL_T) A68G (heap_size);
-    REAL_T _g_ = (REAL_T) (A68G_GC (max_handles) - A68G_GC (free_handles)) / (REAL_T) A68G_GC (max_handles);
-    if (_f_ > DEFAULT_PREEMPTIVE || _g_ > DEFAULT_PREEMPTIVE) {
+    // Raise a flag for a preemptive sweep at a convenient moment.
+    if (heap_available () < (A68G (storage_overhead) + size) || A68G_GC (free_handles) < 100) {
+      // Emergency break.
       A68G_GC (preemptive) = A68G_TRUE;
+    } else {
+      // General case.
+      REAL_T _f_ = (REAL_T) A68G_HP / (REAL_T) heap_available ();
+      REAL_T _g_ = (REAL_T) (A68G_GC (max_handles) - A68G_GC (free_handles)) / (REAL_T) A68G_GC (max_handles);
+      if (_f_ > PREEMPTIVE_FRACTION || _g_ > PREEMPTIVE_FRACTION) {
+         A68G_GC (preemptive) = A68G_TRUE;
+      }
     }
     return z;
   } else {
 // Do not auto-GC!.
-    diagnostic (A68G_RUNTIME_ERROR, p, ERROR_OUT_OF_CORE);
+    diagnostic (A68G_RUNTIME_ERROR, p, ERROR_MEMORY_FULL);
     exit_genie (p, A68G_RUNTIME_ERROR);
     return nil_ref;
   }
@@ -506,30 +536,30 @@ A68G_REF heap_generator (NODE_T * p, MOID_T * mode, int size)
 
 //! @brief Give a block of heap for an object of indicated mode.
 
-A68G_REF heap_generator_2 (NODE_T * p, MOID_T * mode, int len, int size)
+A68G_REF heap_generator_2 (NODE_T * p, MOID_T * mode, size_t len, size_t size)
 {
   if (len == 0 || size == 0) {
     return heap_generator (p, mode, 0);
-  } else if (ABS (size) < (2 * GIGABYTE) / ABS (len)) {
-    return heap_generator (p, mode, len * size);
-  } else {
-    diagnostic (A68G_RUNTIME_ERROR, p, ERROR_OUT_OF_CORE);
+  } else if (size_mul_overflow (len, size)) {
+    diagnostic (A68G_RUNTIME_ERROR, p, ERROR_OBJECT_TOO_LARGE, mode);
     exit_genie (p, A68G_RUNTIME_ERROR);
+  } else {
+    return heap_generator (p, mode, len * size);
   }
   return nil_ref;
 }
 
 //! @brief Give a block of heap for an object of indicated mode.
 
-A68G_REF heap_generator_3 (NODE_T * p, MOID_T * mode, int len1, int len2, int size)
+A68G_REF heap_generator_3 (NODE_T * p, MOID_T * mode, size_t len1, size_t len2, size_t size)
 {
   if (len1 == 0 || len2 == 0) {
     return heap_generator (p, mode, 0);
-  } else if (ABS (len2) < (2 * GIGABYTE) / ABS (len1)) {
-    return heap_generator_2 (p, mode, len1 * len2, size);
-  } else {
-    diagnostic (A68G_RUNTIME_ERROR, p, ERROR_OUT_OF_CORE);
+  } else if (size_mul_overflow (len1, len2)) {
+    diagnostic (A68G_RUNTIME_ERROR, p, ERROR_OBJECT_TOO_LARGE, mode);
     exit_genie (p, A68G_RUNTIME_ERROR);
+  } else {
+    return heap_generator_2 (p, mode, len1 * len2, size);
   }
   return nil_ref;
 }
