@@ -1346,7 +1346,7 @@ void show_item (FILE_T f, NODE_T * p, BYTE_T * item, MOID_T * mode)
     } else {
       A68G_ARRAY *arr; A68G_TUPLE *tup;
       GET_DESCRIPTOR (arr, tup, (A68G_REF *) item);
-      int elems = get_row_size (tup, DIM (arr));
+      size_t elems = get_row_size (tup, DIM (arr));
       ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, ", %d element(s)", elems) >= 0);
       WRITE (f, A68G (output_line));
       if (get_row_size (tup, DIM (arr)) != 0) {
@@ -1943,8 +1943,9 @@ BOOL_T single_stepper (NODE_T * p, char *cmd)
       if (sym[0] == QUOTE_CHAR) {
         sym++;
       }
-      if (sym[strlen (sym) - 1] == QUOTE_CHAR) {
-        sym[strlen (sym) - 1] = NULL_CHAR;
+      size_t len = strlen (sym);
+      if (len > 0 && sym[len - 1] == QUOTE_CHAR) {
+        sym[len - 1] = NULL_CHAR;
       }
       a68g_bufcpy (A68G_MON (prompt), sym, BUFFER_SIZE);
     }
@@ -2170,8 +2171,8 @@ void single_step (NODE_T * p, unt mask)
   } else if ((mask & BREAKPOINT_TRACE_MASK) != 0) {
     PROP_T *prop = &GPROP (p);
     WIS ((p));
-    if (propagator_name ((const PROP_PROC *) UNIT (prop)) != NO_TEXT) {
-      WRITELN (A68G_STDOUT, propagator_name ((const PROP_PROC *) UNIT (prop)));
+    if (propagator_name ((PROP_PROC *) UNIT (prop)) != NO_TEXT) {
+      WRITELN (A68G_STDOUT, propagator_name ((PROP_PROC *) UNIT (prop)));
     }
     return;
   } else {
