@@ -47,12 +47,12 @@ void restore_stacks (pthread_t);
 #define SAVE_STACK(stk, st, si) {\
   A68G_STACK_DESCRIPTOR *s = (stk);\
   BYTE_T *start = (st);\
-  int size = (si);\
+  size_t size = (si);\
   if (size > 0) {\
     if (!((s != NULL) && (BYTES (s) > 0) && (size <= BYTES (s)))) {\
       a68g_free (SWAP (s));\
-      SWAP (s) = (BYTE_T *) get_heap_space ((size_t) size);\
-      ABEND (SWAP (s) == NULL, ERROR_OUT_OF_CORE, __func__);\
+      SWAP (s) = (BYTE_T *) get_heap_space (size);\
+      ABEND (SWAP (s) == NULL, ERROR_MEMORY_FULL, __func__);\
     }\
     START (s) = start;\
     BYTES (s) = size;\
