@@ -468,11 +468,12 @@ char *pq_edit (char *str)
   } else {
     static BUFFER edt;
     char *q = edt;
-    int newlines = 0, len = (int) strlen (str);
+    int newlines = 0;
+    size_t len = strlen (str);
     BOOL_T suppress_blank = A68G_FALSE;
     while (len > 0 && str[len - 1] == NEWLINE_CHAR) {
       str[len - 1] = NULL_CHAR;
-      len = (int) strlen (str);
+      len = strlen (str);
     }
     while (str[0] != NULL_CHAR) {
       if (str[0] == CR_CHAR) {
@@ -527,7 +528,7 @@ void genie_pq_errormessage (NODE_T * p)
     BUFFER str;
     if (PQerrorMessage (CONNECTION (file)) != NULL) {
       a68g_bufcpy (str, pq_edit (PQerrorMessage (CONNECTION (file))), BUFFER_SIZE);
-      int upb = (int) strlen (str);
+      size_t upb = strlen (str);
       if (upb > 0 && str[upb - 1] == NEWLINE_CHAR) {
         str[upb - 1] = NULL_CHAR;
       }
@@ -563,7 +564,7 @@ void genie_pq_resulterrormessage (NODE_T * p)
     BUFFER str;
     if (PQresultErrorMessage (RESULT (file)) != NULL) {
       a68g_bufcpy (str, pq_edit (PQresultErrorMessage (RESULT (file))), BUFFER_SIZE);
-      int upb = (int) strlen (str);
+      size_t upb = strlen (str);
       if (upb > 0 && str[upb - 1] == NEWLINE_CHAR) {
         str[upb - 1] = NULL_CHAR;
       }
