@@ -32,11 +32,11 @@
 #define MAX_BYTES 4
 
 #if (__BYTE_ORDER == __LITTLE_ENDIAN)
-  #define A68_LITTLE_ENDIAN A68_TRUE
-  #define A68_BIG_ENDIAN A68_FALSE
+  #define A68G_LITTLE_ENDIAN A68G_TRUE
+  #define A68G_BIG_ENDIAN A68G_FALSE
 #elif (__BYTE_ORDER == __BIG_ENDIAN)
-  #define A68_LITTLE_ENDIAN A68_FALSE
-  #define A68_BIG_ENDIAN A68_TRUE
+  #define A68G_LITTLE_ENDIAN A68G_FALSE
+  #define A68G_BIG_ENDIAN A68G_TRUE
 #else
   #error "undefined endianness"
 #endif
@@ -99,8 +99,8 @@ static unt pow256[] = { 1, 256, 65536, 16777216 };
 void test_bits_per_sample (NODE_T * p, unt bps)
 {
   if (bps <= 0 || bps > 24) {
-    diagnostic (A68_RUNTIME_ERROR, p, ERROR_SOUND_INTERNAL, M_SOUND, "unsupported number of bits per sample");
-    exit_genie (p, A68_RUNTIME_ERROR);
+    diagnostic (A68G_RUNTIME_ERROR, p, ERROR_SOUND_INTERNAL, M_SOUND, "unsupported number of bits per sample");
+    exit_genie (p, A68G_RUNTIME_ERROR);
   }
 }
 
@@ -109,8 +109,8 @@ void test_bits_per_sample (NODE_T * p, unt bps)
 unt code_string (NODE_T * p, char *s, int n)
 {
   if (n > MAX_BYTES) {
-    diagnostic (A68_RUNTIME_ERROR, p, ERROR_SOUND_INTERNAL, M_SOUND, "too long word length");
-    exit_genie (p, A68_RUNTIME_ERROR);
+    diagnostic (A68G_RUNTIME_ERROR, p, ERROR_SOUND_INTERNAL, M_SOUND, "too long word length");
+    exit_genie (p, A68G_RUNTIME_ERROR);
   }
   unt v = 0; int m = n - 1;
   for (int k = 0; k < n; k++, m--) {
@@ -300,8 +300,8 @@ unt read_riff_item (NODE_T * p, FILE_T fd, int n, BOOL_T little)
   unt v, z;
   int k, m, r;
   if (n > MAX_BYTES) {
-    diagnostic (A68_RUNTIME_ERROR, p, ERROR_SOUND_INTERNAL, M_SOUND, "too long word length");
-    exit_genie (p, A68_RUNTIME_ERROR);
+    diagnostic (A68G_RUNTIME_ERROR, p, ERROR_SOUND_INTERNAL, M_SOUND, "too long word length");
+    exit_genie (p, A68G_RUNTIME_ERROR);
   }
   if (little) {
     for (k = 0, m = 0, v = 0; k < n; k++, m++) {
@@ -309,8 +309,8 @@ unt read_riff_item (NODE_T * p, FILE_T fd, int n, BOOL_T little)
       errno = 0;
       r = (int) io_read (fd, &z, (size_t) 1);
       if (r != 1 || errno != 0) {
-        diagnostic (A68_RUNTIME_ERROR, p, ERROR_SOUND_INTERNAL, M_SOUND, "error while reading file");
-        exit_genie (p, A68_RUNTIME_ERROR);
+        diagnostic (A68G_RUNTIME_ERROR, p, ERROR_SOUND_INTERNAL, M_SOUND, "error while reading file");
+        exit_genie (p, A68G_RUNTIME_ERROR);
       }
       v += z * pow256[m];
     }
@@ -320,8 +320,8 @@ unt read_riff_item (NODE_T * p, FILE_T fd, int n, BOOL_T little)
       errno = 0;
       r = (int) io_read (fd, &z, (size_t) 1);
       if (r != 1 || errno != 0) {
-        diagnostic (A68_RUNTIME_ERROR, p, ERROR_SOUND_INTERNAL, M_SOUND, "error while reading file");
-        exit_genie (p, A68_RUNTIME_ERROR);
+        diagnostic (A68G_RUNTIME_ERROR, p, ERROR_SOUND_INTERNAL, M_SOUND, "error while reading file");
+        exit_genie (p, A68G_RUNTIME_ERROR);
       }
       v += z * pow256[m];
     }
@@ -331,78 +331,78 @@ unt read_riff_item (NODE_T * p, FILE_T fd, int n, BOOL_T little)
 
 //! @brief Read sound from file.
 
-void read_sound (NODE_T * p, A68_REF ref_file, A68_SOUND * w)
+void read_sound (NODE_T * p, A68G_REF ref_file, A68G_SOUND * w)
 {
-  A68_FILE *f = FILE_DEREF (&ref_file);
+  A68G_FILE *f = FILE_DEREF (&ref_file);
   int r;
   unt fmt_cat;
   unt blockalign, byterate, chunksize, subchunk2size, z;
-  BOOL_T data_read = A68_FALSE;
-  if (read_riff_item (p, FD (f), 4, A68_BIG_ENDIAN) != code_string (p, "RIFF", 4)) {
-    diagnostic (A68_RUNTIME_ERROR, p, ERROR_SOUND_INTERNAL, M_SOUND, "file format is not RIFF");
-    exit_genie (p, A68_RUNTIME_ERROR);
+  BOOL_T data_read = A68G_FALSE;
+  if (read_riff_item (p, FD (f), 4, A68G_BIG_ENDIAN) != code_string (p, "RIFF", 4)) {
+    diagnostic (A68G_RUNTIME_ERROR, p, ERROR_SOUND_INTERNAL, M_SOUND, "file format is not RIFF");
+    exit_genie (p, A68G_RUNTIME_ERROR);
   }
-  chunksize = read_riff_item (p, FD (f), 4, A68_LITTLE_ENDIAN);
-  if ((z = read_riff_item (p, FD (f), 4, A68_BIG_ENDIAN)) != code_string (p, "WAVE", 4)) {
-    diagnostic (A68_RUNTIME_ERROR, p, ERROR_SOUND_INTERNAL_STRING, M_SOUND, "file format is not \"WAVE\" but", code_unt (p, z));
-    exit_genie (p, A68_RUNTIME_ERROR);
+  chunksize = read_riff_item (p, FD (f), 4, A68G_LITTLE_ENDIAN);
+  if ((z = read_riff_item (p, FD (f), 4, A68G_BIG_ENDIAN)) != code_string (p, "WAVE", 4)) {
+    diagnostic (A68G_RUNTIME_ERROR, p, ERROR_SOUND_INTERNAL_STRING, M_SOUND, "file format is not \"WAVE\" but", code_unt (p, z));
+    exit_genie (p, A68G_RUNTIME_ERROR);
   }
 // Now read chunks.
-  while (data_read == A68_FALSE) {
-    z = read_riff_item (p, FD (f), 4, A68_BIG_ENDIAN);
+  while (data_read == A68G_FALSE) {
+    z = read_riff_item (p, FD (f), 4, A68G_BIG_ENDIAN);
     if (z == code_string (p, "fmt ", 4)) {
 // Read fmt chunk.
-      z = read_riff_item (p, FD (f), 4, A68_LITTLE_ENDIAN);
+      z = read_riff_item (p, FD (f), 4, A68G_LITTLE_ENDIAN);
       int skip = (int) z - 0x10;    // Bytes to skip in extended wave format
-      fmt_cat = read_riff_item (p, FD (f), 2, A68_LITTLE_ENDIAN);
+      fmt_cat = read_riff_item (p, FD (f), 2, A68G_LITTLE_ENDIAN);
       if (fmt_cat != WAVE_FORMAT_PCM) {
-        diagnostic (A68_RUNTIME_ERROR, p, ERROR_SOUND_INTERNAL_STRING, M_SOUND, "category is not WAVE_FORMAT_PCM but", format_category (fmt_cat));
-        exit_genie (p, A68_RUNTIME_ERROR);
+        diagnostic (A68G_RUNTIME_ERROR, p, ERROR_SOUND_INTERNAL_STRING, M_SOUND, "category is not WAVE_FORMAT_PCM but", format_category (fmt_cat));
+        exit_genie (p, A68G_RUNTIME_ERROR);
       }
-      NUM_CHANNELS (w) = read_riff_item (p, FD (f), 2, A68_LITTLE_ENDIAN);
-      SAMPLE_RATE (w) = read_riff_item (p, FD (f), 4, A68_LITTLE_ENDIAN);
-      byterate = read_riff_item (p, FD (f), 4, A68_LITTLE_ENDIAN);
-      blockalign = read_riff_item (p, FD (f), 2, A68_LITTLE_ENDIAN);
-      BITS_PER_SAMPLE (w) = read_riff_item (p, FD (f), 2, A68_LITTLE_ENDIAN);
+      NUM_CHANNELS (w) = read_riff_item (p, FD (f), 2, A68G_LITTLE_ENDIAN);
+      SAMPLE_RATE (w) = read_riff_item (p, FD (f), 4, A68G_LITTLE_ENDIAN);
+      byterate = read_riff_item (p, FD (f), 4, A68G_LITTLE_ENDIAN);
+      blockalign = read_riff_item (p, FD (f), 2, A68G_LITTLE_ENDIAN);
+      BITS_PER_SAMPLE (w) = read_riff_item (p, FD (f), 2, A68G_LITTLE_ENDIAN);
       test_bits_per_sample (p, BITS_PER_SAMPLE (w));
       for (int k = 0; k < skip; k++) {
-        z = read_riff_item (p, FD (f), 1, A68_LITTLE_ENDIAN);
+        z = read_riff_item (p, FD (f), 1, A68G_LITTLE_ENDIAN);
       }
     } else if (z == code_string (p, "LIST", 4)) {
 // Skip a LIST chunk.
-      z = read_riff_item (p, FD (f), 4, A68_LITTLE_ENDIAN);
+      z = read_riff_item (p, FD (f), 4, A68G_LITTLE_ENDIAN);
       int skip = (int) z;
       for (int k = 0; k < skip; k++) {
-        z = read_riff_item (p, FD (f), 1, A68_LITTLE_ENDIAN);
+        z = read_riff_item (p, FD (f), 1, A68G_LITTLE_ENDIAN);
       }
     } else if (z == code_string (p, "cue ", 4)) {
 // Skip a cue chunk.
-      z = read_riff_item (p, FD (f), 4, A68_LITTLE_ENDIAN);
+      z = read_riff_item (p, FD (f), 4, A68G_LITTLE_ENDIAN);
       int skip = (int) z;
       for (int k = 0; k < skip; k++) {
-        z = read_riff_item (p, FD (f), 1, A68_LITTLE_ENDIAN);
+        z = read_riff_item (p, FD (f), 1, A68G_LITTLE_ENDIAN);
       }
     } else if (z == code_string (p, "fact", 4)) {
 // Skip a fact chunk.
-      z = read_riff_item (p, FD (f), 4, A68_LITTLE_ENDIAN);
+      z = read_riff_item (p, FD (f), 4, A68G_LITTLE_ENDIAN);
       int skip = (int) z;
       for (int k = 0; k < skip; k++) {
-        z = read_riff_item (p, FD (f), 1, A68_LITTLE_ENDIAN);
+        z = read_riff_item (p, FD (f), 1, A68G_LITTLE_ENDIAN);
       }
     } else if (z == code_string (p, "data", 4)) {
 // Read data chunk.
-      subchunk2size = read_riff_item (p, FD (f), 4, A68_LITTLE_ENDIAN);
-      NUM_SAMPLES (w) = subchunk2size / NUM_CHANNELS (w) / (unt) A68_SOUND_BYTES (w);
-      DATA (w) = heap_generator (p, M_SOUND_DATA, (int) subchunk2size);
+      subchunk2size = read_riff_item (p, FD (f), 4, A68G_LITTLE_ENDIAN);
+      NUM_SAMPLES (w) = subchunk2size / NUM_CHANNELS (w) / (unt) A68G_SOUND_BYTES (w);
+      DATA (w) = heap_generator (p, M_SOUND_DATA, (size_t) subchunk2size);
       r = (int) io_read (FD (f), ADDRESS (&(DATA (w))), subchunk2size);
       if (r != (int) subchunk2size) {
-        diagnostic (A68_RUNTIME_ERROR, p, ERROR_SOUND_INTERNAL, M_SOUND, "cannot read all of the data");
-        exit_genie (p, A68_RUNTIME_ERROR);
+        diagnostic (A68G_RUNTIME_ERROR, p, ERROR_SOUND_INTERNAL, M_SOUND, "cannot read all of the data");
+        exit_genie (p, A68G_RUNTIME_ERROR);
       }
-      data_read = A68_TRUE;
+      data_read = A68G_TRUE;
     } else {
-      diagnostic (A68_RUNTIME_ERROR, p, ERROR_SOUND_INTERNAL_STRING, M_SOUND, "chunk is", code_unt (p, z));
-      exit_genie (p, A68_RUNTIME_ERROR);
+      diagnostic (A68G_RUNTIME_ERROR, p, ERROR_SOUND_INTERNAL_STRING, M_SOUND, "chunk is", code_unt (p, z));
+      exit_genie (p, A68G_RUNTIME_ERROR);
     }
   }
   (void) z;
@@ -419,8 +419,8 @@ void write_riff_item (NODE_T * p, FILE_T fd, unt z, int n, BOOL_T little)
 {
   unt char y[MAX_BYTES];
   if (n > MAX_BYTES) {
-    diagnostic (A68_RUNTIME_ERROR, p, ERROR_SOUND_INTERNAL, M_SOUND, "too long word length");
-    exit_genie (p, A68_RUNTIME_ERROR);
+    diagnostic (A68G_RUNTIME_ERROR, p, ERROR_SOUND_INTERNAL, M_SOUND, "too long word length");
+    exit_genie (p, A68G_RUNTIME_ERROR);
   }
   for (int k = 0; k < n; k++) {
     y[k] = (unt char) (z & 0xff);
@@ -434,8 +434,8 @@ void write_riff_item (NODE_T * p, FILE_T fd, unt z, int n, BOOL_T little)
     for (int k = n - 1; k >= 0; k--) {
       int r = (int) io_write (fd, &(y[k]), 1);
       if (r != 1) {
-        diagnostic (A68_RUNTIME_ERROR, p, ERROR_SOUND_INTERNAL, M_SOUND, "error while writing file");
-        exit_genie (p, A68_RUNTIME_ERROR);
+        diagnostic (A68G_RUNTIME_ERROR, p, ERROR_SOUND_INTERNAL, M_SOUND, "error while writing file");
+        exit_genie (p, A68G_RUNTIME_ERROR);
       }
     }
   }
@@ -443,35 +443,35 @@ void write_riff_item (NODE_T * p, FILE_T fd, unt z, int n, BOOL_T little)
 
 //! @brief Write sound to file.
 
-void write_sound (NODE_T * p, A68_REF ref_file, A68_SOUND * w)
+void write_sound (NODE_T * p, A68G_REF ref_file, A68G_SOUND * w)
 {
-  A68_FILE *f = FILE_DEREF (&ref_file);
+  A68G_FILE *f = FILE_DEREF (&ref_file);
   int r;
-  unt blockalign = NUM_CHANNELS (w) * (unt) (A68_SOUND_BYTES (w));
+  unt blockalign = NUM_CHANNELS (w) * (unt) (A68G_SOUND_BYTES (w));
   unt byterate = SAMPLE_RATE (w) * blockalign;
   unt subchunk2size = NUM_SAMPLES (w) * blockalign;
   unt chunksize = 4 + (8 + 16) + (8 + subchunk2size);
-  write_riff_item (p, FD (f), code_string (p, "RIFF", 4), 4, A68_BIG_ENDIAN);
-  write_riff_item (p, FD (f), chunksize, 4, A68_LITTLE_ENDIAN);
-  write_riff_item (p, FD (f), code_string (p, "WAVE", 4), 4, A68_BIG_ENDIAN);
-  write_riff_item (p, FD (f), code_string (p, "fmt ", 4), 4, A68_BIG_ENDIAN);
-  write_riff_item (p, FD (f), 16, 4, A68_LITTLE_ENDIAN);
-  write_riff_item (p, FD (f), 1, 2, A68_LITTLE_ENDIAN);
-  write_riff_item (p, FD (f), NUM_CHANNELS (w), 2, A68_LITTLE_ENDIAN);
-  write_riff_item (p, FD (f), SAMPLE_RATE (w), 4, A68_LITTLE_ENDIAN);
-  write_riff_item (p, FD (f), byterate, 4, A68_LITTLE_ENDIAN);
-  write_riff_item (p, FD (f), blockalign, 2, A68_LITTLE_ENDIAN);
-  write_riff_item (p, FD (f), BITS_PER_SAMPLE (w), 2, A68_LITTLE_ENDIAN);
-  write_riff_item (p, FD (f), code_string (p, "data", 4), 4, A68_BIG_ENDIAN);
-  write_riff_item (p, FD (f), subchunk2size, 4, A68_LITTLE_ENDIAN);
+  write_riff_item (p, FD (f), code_string (p, "RIFF", 4), 4, A68G_BIG_ENDIAN);
+  write_riff_item (p, FD (f), chunksize, 4, A68G_LITTLE_ENDIAN);
+  write_riff_item (p, FD (f), code_string (p, "WAVE", 4), 4, A68G_BIG_ENDIAN);
+  write_riff_item (p, FD (f), code_string (p, "fmt ", 4), 4, A68G_BIG_ENDIAN);
+  write_riff_item (p, FD (f), 16, 4, A68G_LITTLE_ENDIAN);
+  write_riff_item (p, FD (f), 1, 2, A68G_LITTLE_ENDIAN);
+  write_riff_item (p, FD (f), NUM_CHANNELS (w), 2, A68G_LITTLE_ENDIAN);
+  write_riff_item (p, FD (f), SAMPLE_RATE (w), 4, A68G_LITTLE_ENDIAN);
+  write_riff_item (p, FD (f), byterate, 4, A68G_LITTLE_ENDIAN);
+  write_riff_item (p, FD (f), blockalign, 2, A68G_LITTLE_ENDIAN);
+  write_riff_item (p, FD (f), BITS_PER_SAMPLE (w), 2, A68G_LITTLE_ENDIAN);
+  write_riff_item (p, FD (f), code_string (p, "data", 4), 4, A68G_BIG_ENDIAN);
+  write_riff_item (p, FD (f), subchunk2size, 4, A68G_LITTLE_ENDIAN);
   if (IS_NIL (DATA (w))) {
-    diagnostic (A68_RUNTIME_ERROR, p, ERROR_SOUND_INTERNAL, M_SOUND, "sound has no data");
-    exit_genie (p, A68_RUNTIME_ERROR);
+    diagnostic (A68G_RUNTIME_ERROR, p, ERROR_SOUND_INTERNAL, M_SOUND, "sound has no data");
+    exit_genie (p, A68G_RUNTIME_ERROR);
   }
   r = (int) io_write (FD (f), ADDRESS (&(DATA (w))), subchunk2size);
   if (r != (int) subchunk2size) {
-    diagnostic (A68_RUNTIME_ERROR, p, ERROR_SOUND_INTERNAL, M_SOUND, "error while writing file");
-    exit_genie (p, A68_RUNTIME_ERROR);
+    diagnostic (A68G_RUNTIME_ERROR, p, ERROR_SOUND_INTERNAL, M_SOUND, "error while writing file");
+    exit_genie (p, A68G_RUNTIME_ERROR);
   }
 }
 
@@ -479,47 +479,47 @@ void write_sound (NODE_T * p, A68_REF ref_file, A68_SOUND * w)
 
 void genie_new_sound (NODE_T * p)
 {
-  A68_INT num_channels, sample_rate, bits_per_sample, num_samples;
-  A68_SOUND w;
-  POP_OBJECT (p, &num_samples, A68_INT);
-  POP_OBJECT (p, &num_channels, A68_INT);
-  POP_OBJECT (p, &sample_rate, A68_INT);
-  POP_OBJECT (p, &bits_per_sample, A68_INT);
+  A68G_INT num_channels, sample_rate, bits_per_sample, num_samples;
+  A68G_SOUND w;
+  POP_OBJECT (p, &num_samples, A68G_INT);
+  POP_OBJECT (p, &num_channels, A68G_INT);
+  POP_OBJECT (p, &sample_rate, A68G_INT);
+  POP_OBJECT (p, &bits_per_sample, A68G_INT);
   NUM_SAMPLES (&w) = (unt) (VALUE (&num_samples));
   NUM_CHANNELS (&w) = (unt) (VALUE (&num_channels));
   SAMPLE_RATE (&w) = (unt) (VALUE (&sample_rate));
   BITS_PER_SAMPLE (&w) = (unt) (VALUE (&bits_per_sample));
   test_bits_per_sample (p, BITS_PER_SAMPLE (&w));
-  DATA_SIZE (&w) = (unt) A68_SOUND_DATA_SIZE (&w);
-  DATA (&w) = heap_generator (p, M_SOUND_DATA, (int) DATA_SIZE (&w) * sizeof (unt));
+  DATA_SIZE (&w) = (unt) A68G_SOUND_DATA_SIZE (&w);
+  DATA (&w) = heap_generator (p, M_SOUND_DATA, (size_t) DATA_SIZE (&w));
   STATUS (&w) = INIT_MASK;
-  PUSH_OBJECT (p, w, A68_SOUND);
+  PUSH_OBJECT (p, w, A68G_SOUND);
 }
 
 //! @brief PROC get sound = (SOUND w, INT channel, sample) INT
 
 void genie_get_sound (NODE_T * p)
 {
-  A68_INT channel, sample;
-  A68_SOUND w;
+  A68G_INT channel, sample;
+  A68G_SOUND w;
   int addr, k, n, z, m;
   BYTE_T *d;
-  POP_OBJECT (p, &sample, A68_INT);
-  POP_OBJECT (p, &channel, A68_INT);
-  POP_OBJECT (p, &w, A68_SOUND);
+  POP_OBJECT (p, &sample, A68G_INT);
+  POP_OBJECT (p, &channel, A68G_INT);
+  POP_OBJECT (p, &w, A68G_SOUND);
   if (!(VALUE (&channel) >= 1 && VALUE (&channel) <= (int) NUM_CHANNELS (&w))) {
-    diagnostic (A68_RUNTIME_ERROR, p, ERROR_SOUND_INTERNAL, M_SOUND, "channel index out of range");
-    exit_genie (p, A68_RUNTIME_ERROR);
+    diagnostic (A68G_RUNTIME_ERROR, p, ERROR_SOUND_INTERNAL, M_SOUND, "channel index out of range");
+    exit_genie (p, A68G_RUNTIME_ERROR);
   }
   if (!(VALUE (&sample) >= 1 && VALUE (&sample) <= (int) NUM_SAMPLES (&w))) {
-    diagnostic (A68_RUNTIME_ERROR, p, ERROR_SOUND_INTERNAL, M_SOUND, "sample index out of range");
-    exit_genie (p, A68_RUNTIME_ERROR);
+    diagnostic (A68G_RUNTIME_ERROR, p, ERROR_SOUND_INTERNAL, M_SOUND, "sample index out of range");
+    exit_genie (p, A68G_RUNTIME_ERROR);
   }
   if (IS_NIL (DATA (&w))) {
-    diagnostic (A68_RUNTIME_ERROR, p, ERROR_SOUND_INTERNAL, M_SOUND, "sound has no data");
-    exit_genie (p, A68_RUNTIME_ERROR);
+    diagnostic (A68G_RUNTIME_ERROR, p, ERROR_SOUND_INTERNAL, M_SOUND, "sound has no data");
+    exit_genie (p, A68G_RUNTIME_ERROR);
   }
-  n = A68_SOUND_BYTES (&w);
+  n = A68G_SOUND_BYTES (&w);
   addr = ((VALUE (&sample) - 1) * (int) (NUM_CHANNELS (&w)) + (VALUE (&channel) - 1)) * n;
   ABEND (addr < 0 || addr >= (int) DATA_SIZE (&w), ERROR_INTERNAL_CONSISTENCY, __func__);
   d = &(ADDRESS (&(DATA (&w)))[addr]);
@@ -528,34 +528,34 @@ void genie_get_sound (NODE_T * p)
     z += ((int) (d[k]) * (int) (pow256[k]));
     m = k;
   }
-  PUSH_VALUE (p, (d[m] & 0x80 ? (n == 4 ? z : z - (int) pow256[m + 1]) : z), A68_INT);
+  PUSH_VALUE (p, (d[m] & 0x80 ? (n == 4 ? z : z - (int) pow256[m + 1]) : z), A68G_INT);
 }
 
 //! @brief PROC set sound = (SOUND w, INT channel, sample, value) VOID
 
 void genie_set_sound (NODE_T * p)
 {
-  A68_INT channel, sample, value;
+  A68G_INT channel, sample, value;
   int addr, k, n, z;
   BYTE_T *d;
-  A68_SOUND w;
-  POP_OBJECT (p, &value, A68_INT);
-  POP_OBJECT (p, &sample, A68_INT);
-  POP_OBJECT (p, &channel, A68_INT);
-  POP_OBJECT (p, &w, A68_SOUND);
+  A68G_SOUND w;
+  POP_OBJECT (p, &value, A68G_INT);
+  POP_OBJECT (p, &sample, A68G_INT);
+  POP_OBJECT (p, &channel, A68G_INT);
+  POP_OBJECT (p, &w, A68G_SOUND);
   if (!(VALUE (&channel) >= 1 && VALUE (&channel) <= (int) NUM_CHANNELS (&w))) {
-    diagnostic (A68_RUNTIME_ERROR, p, ERROR_SOUND_INTERNAL, M_SOUND, "channel index out of range");
-    exit_genie (p, A68_RUNTIME_ERROR);
+    diagnostic (A68G_RUNTIME_ERROR, p, ERROR_SOUND_INTERNAL, M_SOUND, "channel index out of range");
+    exit_genie (p, A68G_RUNTIME_ERROR);
   }
   if (!(VALUE (&sample) >= 1 && VALUE (&sample) <= (int) NUM_SAMPLES (&w))) {
-    diagnostic (A68_RUNTIME_ERROR, p, ERROR_SOUND_INTERNAL, M_SOUND, "sample index out of range");
-    exit_genie (p, A68_RUNTIME_ERROR);
+    diagnostic (A68G_RUNTIME_ERROR, p, ERROR_SOUND_INTERNAL, M_SOUND, "sample index out of range");
+    exit_genie (p, A68G_RUNTIME_ERROR);
   }
   if (IS_NIL (DATA (&w))) {
-    diagnostic (A68_RUNTIME_ERROR, p, ERROR_SOUND_INTERNAL, M_SOUND, "sound has no data");
-    exit_genie (p, A68_RUNTIME_ERROR);
+    diagnostic (A68G_RUNTIME_ERROR, p, ERROR_SOUND_INTERNAL, M_SOUND, "sound has no data");
+    exit_genie (p, A68G_RUNTIME_ERROR);
   }
-  n = A68_SOUND_BYTES (&w);
+  n = A68G_SOUND_BYTES (&w);
   addr = ((VALUE (&sample) - 1) * (int) (NUM_CHANNELS (&w)) + (VALUE (&channel) - 1)) * n;
   ABEND (addr < 0 || addr >= (int) DATA_SIZE (&w), ERROR_INTERNAL_CONSISTENCY, __func__);
   d = &(ADDRESS (&(DATA (&w)))[addr]);
@@ -570,34 +570,34 @@ void genie_set_sound (NODE_T * p)
 
 void genie_sound_samples (NODE_T * p)
 {
-  A68_SOUND w;
-  POP_OBJECT (p, &w, A68_SOUND);
-  PUSH_VALUE (p, (int) (NUM_SAMPLES (&w)), A68_INT);
+  A68G_SOUND w;
+  POP_OBJECT (p, &w, A68G_SOUND);
+  PUSH_VALUE (p, (int) (NUM_SAMPLES (&w)), A68G_INT);
 }
 
 //! @brief OP RATE = (SOUND) INT
 
 void genie_sound_rate (NODE_T * p)
 {
-  A68_SOUND w;
-  POP_OBJECT (p, &w, A68_SOUND);
-  PUSH_VALUE (p, (int) (SAMPLE_RATE (&w)), A68_INT);
+  A68G_SOUND w;
+  POP_OBJECT (p, &w, A68G_SOUND);
+  PUSH_VALUE (p, (int) (SAMPLE_RATE (&w)), A68G_INT);
 }
 
 //! @brief OP CHANNELS = (SOUND) INT
 
 void genie_sound_channels (NODE_T * p)
 {
-  A68_SOUND w;
-  POP_OBJECT (p, &w, A68_SOUND);
-  PUSH_VALUE (p, (int) (NUM_CHANNELS (&w)), A68_INT);
+  A68G_SOUND w;
+  POP_OBJECT (p, &w, A68G_SOUND);
+  PUSH_VALUE (p, (int) (NUM_CHANNELS (&w)), A68G_INT);
 }
 
 //! @brief OP RESOLUTION = (SOUND) INT
 
 void genie_sound_resolution (NODE_T * p)
 {
-  A68_SOUND w;
-  POP_OBJECT (p, &w, A68_SOUND);
-  PUSH_VALUE (p, (int) (BITS_PER_SAMPLE (&w)), A68_INT);
+  A68G_SOUND w;
+  POP_OBJECT (p, &w, A68G_SOUND);
+  PUSH_VALUE (p, (int) (BITS_PER_SAMPLE (&w)), A68G_INT);
 }
