@@ -44,11 +44,11 @@
 
 //! @brief Size of a row.
 
-int get_row_size (A68G_TUPLE * tup, int dim)
+size_t get_row_size (A68G_TUPLE * tup, int dim)
 {
-  int span = 1;
+  size_t span = 1;
   for (int k = 0; k < dim; k++) {
-    int stride = ROW_SIZE (&tup[k]);
+    size_t stride = ROW_SIZE (&tup[k]);
     ABEND ((stride > 0 && span > A68G_MAX_INT / stride), ERROR_INVALID_SIZE, __func__);
     span *= stride;
   }
@@ -115,12 +115,12 @@ void print_internal_index (FILE_T f, A68G_TUPLE * tup, int dim)
 
 //! @brief Convert C string to A68 [] CHAR.
 
-A68G_REF c_string_to_row_char (NODE_T * p, char *str, int width)
+A68G_REF c_string_to_row_char (NODE_T * p, char *str, size_t width)
 {
   A68G_REF z, row; A68G_ARRAY arr; A68G_TUPLE tup;
   NEW_ROW_1D (z, row, arr, tup, M_ROW_CHAR, M_CHAR, width);
   BYTE_T *base = ADDRESS (&row);
-  int len = strlen (str);
+  size_t len = strlen (str);
   for (int k = 0; k < width; k++) {
     A68G_CHAR *ch = (A68G_CHAR *) & (base[k * SIZE_ALIGNED (A68G_CHAR)]);
     STATUS (ch) = INIT_MASK;
@@ -131,22 +131,22 @@ A68G_REF c_string_to_row_char (NODE_T * p, char *str, int width)
 
 //! @brief Convert C string to A68 string.
 
-A68G_REF c_to_a_string (NODE_T * p, char *str, int width)
+A68G_REF c_to_a_string (NODE_T * p, char *str, size_t width)
 {
   if (str == NO_TEXT) {
     return empty_string (p);
   } else {
     if (width == DEFAULT_WIDTH) {
-      return c_string_to_row_char (p, str, (int) strlen (str));
+      return c_string_to_row_char (p, str, strlen (str));
     } else {
-      return c_string_to_row_char (p, str, (int) width);
+      return c_string_to_row_char (p, str, width);
     }
   }
 }
 
 //! @brief Size of a string.
 
-int a68g_string_size (NODE_T * p, A68G_REF row)
+size_t a68g_string_size (NODE_T * p, A68G_REF row)
 {
   (void) p;
   if (INITIALISED (&row)) {
@@ -167,7 +167,7 @@ char *a_to_c_string (NODE_T * p, char *str, A68G_REF row)
   if (INITIALISED (&row)) {
     A68G_ARRAY *arr; A68G_TUPLE *tup;
     GET_DESCRIPTOR (arr, tup, &row);
-    int size = ROW_SIZE (tup), n = 0;
+    size_t size = ROW_SIZE (tup), n = 0;
     if (size > 0) {
       BYTE_T *base_address = ADDRESS (&ARRAY (arr));
       for (int k = LWB (tup); k <= UPB (tup); k++) {
@@ -507,13 +507,15 @@ A68G_REF genie_clone (NODE_T * p, MOID_T * m, A68G_REF * tmp, A68G_REF * old)
 // The routine takes a REF to the value and returns a REF to the clone.
   if (m == M_SOUND) {
 // REF SOUND.
-    A68G_REF new_snd = heap_generator (p, m, SIZE (m));
-    A68G_SOUND *w = DEREF (A68G_SOUND, &new_snd);
-    int size = A68G_SOUND_DATA_SIZE (w);
-    COPY ((BYTE_T *) w, ADDRESS (old), SIZE (M_SOUND));
-    BYTE_T *owd = ADDRESS (&(DATA (w)));
-    DATA (w) = heap_generator (p, M_SOUND_DATA, size);
-    COPY (ADDRESS (&(DATA (w))), owd, size);
+    A68G_REF new_snd = heap_generator (p, m, SIZE (M_SOUND));
+    A68G_SOUND *ns = DEREF (A68G_SOUND, &new_snd);
+    A68G_SOUND *os = DEREF (A68G_SOUND, old);
+    COPY ((BYTE_T *) ns, (BYTE_T *) os, SIZE (M_SOUND));
+    BYTE_T *nd = ADDRESS (&(DATA (ns)));
+    BYTE_T *od = ADDRESS (&(DATA (os)));
+    size_t size = A68G_SOUND_DATA_SIZE (os);
+    DATA (ns) = heap_generator (p, M_SOUND_DATA, size);
+    COPY ((BYTE_T *) nd, (BYTE_T *) od, size);
     return new_snd;
   } else if (IS_STRUCT (m)) {
 // REF STRUCT.
@@ -745,12 +747,12 @@ void genie_sort_row_string (NODE_T * p)
   ADDR_T pop_sp = A68G_SP;
   CHECK_REF (p, z, M_ROW_STRING);
   GET_DESCRIPTOR (arr, tup, &z);
-  int size = ROW_SIZE (tup);
+  size_t size = ROW_SIZE (tup);
   if (size > 0) {
     BYTE_T *base = ADDRESS (&ARRAY (arr));
     char **ptrs = (char **) a68g_alloc ((size_t) (size * (int) sizeof (char *)), __func__, __LINE__);
     if (ptrs == NO_REF) {
-      diagnostic (A68G_RUNTIME_ERROR, p, ERROR_OUT_OF_CORE);
+      diagnostic (A68G_RUNTIME_ERROR, p, ERROR_MEMORY_FULL);
       exit_genie (p, A68G_RUNTIME_ERROR);
     }
 // Copy C-strings into the stack and sort.
@@ -758,7 +760,7 @@ void genie_sort_row_string (NODE_T * p)
       int addr = INDEX_1_DIM (arr, tup, k);
       A68G_REF ref = *(A68G_REF *) & (base[addr]);
       CHECK_REF (p, ref, M_STRING);
-      int len = A68G_ALIGN (a68g_string_size (p, ref) + 1);
+      size_t len = A68G_ALIGN (a68g_string_size (p, ref) + 1);
       if (A68G_SP + len > A68G (expr_stack_limit)) {
         diagnostic (A68G_RUNTIME_ERROR, p, ERROR_STACK_OVERFLOW);
         exit_genie (p, A68G_RUNTIME_ERROR);
