@@ -68,7 +68,7 @@ int store_file_entry (NODE_T * p, FILE_T fd, char *idf, BOOL_T is_tmp)
   for (int k = 0; k < MAX_OPEN_FILES; k++) {
     FILE_ENTRY *fe = &(A68G (file_entries)[k]);
     if (!IS_OPEN (fe)) {
-      int len = 1 + (int) strlen (idf);
+      size_t len = 1 + strlen (idf);
       POS (fe) = p;
       IS_OPEN (fe) = A68G_TRUE;
       IS_TMP (fe) = is_tmp;
@@ -148,7 +148,7 @@ A68G_REF ref_transput_buffer[MAX_TRANSPUT_BUFFER];
 
 //! @brief Set max number of chars in a transput buffer.
 
-void set_transput_buffer_size (int n, int size)
+void set_transput_buffer_size (int n, INT_T size)
 {
   A68G_INT *k = (A68G_INT *) (ADDRESS (&ref_transput_buffer[n]));
   STATUS (k) = INIT_MASK;
@@ -157,7 +157,7 @@ void set_transput_buffer_size (int n, int size)
 
 //! @brief Set char index for transput buffer.
 
-void set_transput_buffer_index (int n, int cindex)
+void set_transput_buffer_index (int n, INT_T cindex)
 {
   A68G_INT *k = (A68G_INT *) (ADDRESS (&ref_transput_buffer[n]) + SIZE (M_INT));
   STATUS (k) = INIT_MASK;
@@ -166,7 +166,7 @@ void set_transput_buffer_index (int n, int cindex)
 
 //! @brief Get max number of chars in a transput buffer.
 
-int get_transput_buffer_size (int n)
+INT_T get_transput_buffer_size (int n)
 {
   A68G_INT *k = (A68G_INT *) (ADDRESS (&ref_transput_buffer[n]));
   return VALUE (k);
@@ -174,7 +174,7 @@ int get_transput_buffer_size (int n)
 
 //! @brief Get char index for transput buffer.
 
-int get_transput_buffer_index (int n)
+INT_T get_transput_buffer_index (int n)
 {
   A68G_INT *k = (A68G_INT *) (ADDRESS (&ref_transput_buffer[n]) + SIZE (M_INT));
   return VALUE (k);
@@ -191,7 +191,7 @@ char *get_transput_buffer (int n)
 
 void unblock_transput_buffer (int n)
 {
-  set_transput_buffer_index (n, -1);
+  set_transput_buffer_index (n, TRANSPUT_BUFFER_BLOCKED);
 }
 
 //! @brief Find first unused transput buffer (for opening a file).
@@ -199,7 +199,7 @@ void unblock_transput_buffer (int n)
 int get_unblocked_transput_buffer (NODE_T * p)
 {
   for (int k = FIXED_TRANSPUT_BUFFERS; k < MAX_TRANSPUT_BUFFER; k++) {
-    if (get_transput_buffer_index (k) == -1) {
+    if (get_transput_buffer_index (k) == TRANSPUT_BUFFER_BLOCKED) {
       return k;
     }
   }
@@ -235,7 +235,7 @@ void init_transput_buffers (NODE_T * p)
 
 //! @brief Make a transput buffer larger.
 
-void enlarge_transput_buffer (NODE_T * p, int k, int size)
+void enlarge_transput_buffer (NODE_T * p, int k, INT_T size)
 {
   int n = get_transput_buffer_index (k);
   char *sb_1 = get_transput_buffer (k), *sb_2;
@@ -253,7 +253,7 @@ void enlarge_transput_buffer (NODE_T * p, int k, int size)
 void plusab_transput_buffer (NODE_T * p, int k, char ch)
 {
   char *sb = get_transput_buffer (k);
-  int size = get_transput_buffer_size (k);
+  size_t size = get_transput_buffer_size (k);
   int n = get_transput_buffer_index (k);
   if (n == size - 2) {
     enlarge_transput_buffer (p, k, 10 * size);
@@ -270,7 +270,7 @@ void plusab_transput_buffer (NODE_T * p, int k, char ch)
 void plusto_transput_buffer (NODE_T * p, char ch, int k)
 {
   char *sb = get_transput_buffer (k);
-  int size = get_transput_buffer_size (k);
+  size_t size = get_transput_buffer_size (k);
   int n = get_transput_buffer_index (k);
   if (n == size - 2) {
     enlarge_transput_buffer (p, k, 10 * size);
@@ -348,14 +348,14 @@ char pop_char_transput_buffer (int k)
 
 void add_c_string_to_a_string (NODE_T * p, A68G_REF ref_str, char *s)
 {
-  int len_2 = (int) strlen (s);
+  size_t len_2 = strlen (s);
 // left part.
   CHECK_REF (p, ref_str, M_REF_STRING);
   A68G_REF a = *DEREF (A68G_REF, &ref_str);
   CHECK_INIT (p, INITIALISED (&a), M_STRING);
   A68G_ARRAY *arr_1; A68G_TUPLE *tup_1;
   GET_DESCRIPTOR (arr_1, tup_1, &a);
-  int len_1 = ROW_SIZE (tup_1);
+  size_t len_1 = ROW_SIZE (tup_1);
 // Sum string.
   A68G_REF c = heap_generator (p, M_STRING, DESCRIPTOR_SIZE (1));
   A68G_REF d = heap_generator_2 (p, M_STRING, len_1 + len_2, SIZE (M_CHAR));
@@ -412,7 +412,7 @@ void write_purge_buffer (NODE_T * p, A68G_REF ref_file, int k)
 
 //! @brief Allocate a temporary string on the stack.
 
-char *stack_string (NODE_T * p, int size)
+char *stack_string (NODE_T * p, size_t size)
 {
   char *new_str = (char *) STACK_TOP;
   INCREMENT_STACK_POINTER (p, size);
@@ -610,7 +610,7 @@ void init_file (NODE_T * p, A68G_REF * ref_file, A68G_CHANNEL c, FILE_T s, BOOL_
   TERMINATOR (f) = nil_ref;
   CHANNEL (f) = c;
   if (filename != NO_TEXT && strlen (filename) > 0) {
-    int len = 1 + (int) strlen (filename);
+    size_t len = 1 + strlen (filename);
     IDENTIFICATION (f) = heap_generator (p, M_C_STRING, len);
     BLOCK_GC_HANDLE (&(IDENTIFICATION (f)));
     a68g_bufcpy (DEREF (char, &IDENTIFICATION (f)), filename, len);
@@ -704,7 +704,7 @@ void genie_make_term (NODE_T * p)
   ref_file = *(A68G_REF *) STACK_TOP;
   A68G_FILE *file = FILE_DEREF (&ref_file);
 // Don't check initialisation so we can "make term" before opening.
-  int size = a68g_string_size (p, str);
+  size_t size = a68g_string_size (p, str);
   if (INITIALISED (&(TERMINATOR (file))) && !IS_NIL (TERMINATOR (file))) {
     UNBLOCK_GC_HANDLE (&(TERMINATOR (file)));
   }
@@ -833,7 +833,7 @@ void genie_open (NODE_T * p)
   CHAR_MOOD (file) = A68G_FALSE;
   DRAW_MOOD (file) = A68G_FALSE;
   TMP_FILE (file) = A68G_FALSE;
-  int size = a68g_string_size (p, ref_iden);
+  size_t size = a68g_string_size (p, ref_iden);
   if (INITIALISED (&(IDENTIFICATION (file))) && !IS_NIL (IDENTIFICATION (file))) {
     UNBLOCK_GC_HANDLE (&(IDENTIFICATION (file)));
   }
@@ -854,9 +854,9 @@ void genie_open (NODE_T * p)
   {
     struct stat status;
     if (stat (DEREF (char, &IDENTIFICATION (file)), &status) == 0) {
-      PUSH_VALUE (p, (S_ISREG (ST_MODE (&status)) != 0 ? 0 : 1), A68G_INT);
+      PUSH_VALUE (p, (S_ISREG (ST_MODE (&status)) != 0 ? 0 : ENOENT), A68G_INT);
     } else {
-      PUSH_VALUE (p, 1, A68G_INT);
+      PUSH_VALUE (p, errno, A68G_INT);
     }
     errno = 0;
   }
@@ -889,7 +889,7 @@ void genie_establish (NODE_T * p)
     diagnostic (A68G_RUNTIME_ERROR, p, ERROR_CHANNEL_DOES_NOT_ALLOW, "putting");
     exit_genie (p, A68G_RUNTIME_ERROR);
   }
-  int size = a68g_string_size (p, ref_iden);
+  size_t size = a68g_string_size (p, ref_iden);
   if (INITIALISED (&(IDENTIFICATION (file))) && !IS_NIL (IDENTIFICATION (file))) {
     UNBLOCK_GC_HANDLE (&(IDENTIFICATION (file)));
   }
@@ -1132,7 +1132,7 @@ void genie_set (NODE_T * p)
   }
   if (!IS_NIL (STRING (file))) {
     A68G_REF z = *DEREF (A68G_REF, &STRING (file));
-    int size;
+    size_t size;
 // Circumvent buffering problems.
     STRPOS (file) -= get_transput_buffer_index (TRANSPUT_BUFFER (file));
     ASSERT (STRPOS (file) > 0);
@@ -1158,13 +1158,13 @@ void genie_set (NODE_T * p)
     exit_genie (p, A68G_RUNTIME_ERROR);
   } else {
     errno = 0;
-    __off_t curpos = lseek (FD (file), 0, SEEK_CUR);
-    __off_t maxpos = lseek (FD (file), 0, SEEK_END);
+    a68g_off_t curpos = (a68g_off_t) lseek (FD (file), 0, SEEK_CUR);
+    a68g_off_t maxpos = (a68g_off_t) lseek (FD (file), 0, SEEK_END);
 // Circumvent buffering problems.
     int reserve = get_transput_buffer_index (TRANSPUT_BUFFER (file));
-    curpos -= (__off_t) reserve;
-    __off_t res = lseek (FD (file), -reserve, SEEK_CUR);
-    ASSERT (res != -1 && errno == 0);
+    curpos -= (a68g_off_t) reserve;
+    a68g_off_t res = (a68g_off_t) lseek (FD (file), -reserve, SEEK_CUR);
+    ASSERT (res != (a68g_off_t) -1 && errno == 0);
     reset_transput_buffer (TRANSPUT_BUFFER (file));
 // Now set.
     CHECK_INT_ADDITION (p, curpos, VALUE (&pos));
@@ -1177,7 +1177,7 @@ void genie_set (NODE_T * p)
         diagnostic (A68G_RUNTIME_ERROR, p, ERROR_FILE_ENDED);
         exit_genie (p, A68G_RUNTIME_ERROR);
       }
-      PUSH_VALUE (p, (int) lseek (FD (file), 0, SEEK_CUR), A68G_INT);
+      PUSH_VALUE (p, (INT_T) lseek (FD (file), 0, SEEK_CUR), A68G_INT);
     } else {
       res = lseek (FD (file), curpos, SEEK_SET);
       if (res == -1 || errno != 0) {
