@@ -110,7 +110,7 @@ void G_cfrac_lower (REAL_T * Gcfrac, REAL_T p, REAL_T x)
 // as detailed in the paper, perform manually the first pass (n=1), of the
 // initial Modified Lentz's method.
   REAL_T an = 1, bn = p, del;
-  REAL_T f = an / bn, c = an / A68_REAL_MIN, d = 1 / bn;
+  REAL_T f = an / bn, c = an / A68G_REAL_MIN, d = 1 / bn;
   INT_T n = 2, k;
   do {
     k = n / 2;
@@ -118,18 +118,18 @@ void G_cfrac_lower (REAL_T * Gcfrac, REAL_T p, REAL_T x)
     bn++;
     d = an * d + bn;
     if (d == 0) {
-      d = A68_REAL_MIN;
+      d = A68G_REAL_MIN;
     }
     c = bn + an / c;
     if (c == 0) {
-      c = A68_REAL_MIN;
+      c = A68G_REAL_MIN;
     }
     d = 1 / d;
     del = d * c;
     f *= del;
     n++;
   }
-  while ((a68g_abs_real (del - 1.0) >= A68_REAL_EPS) && (n < ITMAX));
+  while ((a68g_abs_real (del - 1.0) >= A68G_REAL_EPS) && (n < ITMAX));
   *Gcfrac = f;
 }
 
@@ -155,7 +155,7 @@ void G_ibp (REAL_T * Gibp, REAL_T p, REAL_T x)
     REAL_T del = c * (t - d);
     s += del;
     l++;
-    stop = a68g_abs_real (del) < a68g_abs_real (s) * A68_REAL_EPS;
+    stop = a68g_abs_real (del) < a68g_abs_real (s) * A68G_REAL_EPS;
   }
   while ((l < floor ((p - 2) / 2)) && !stop);
   if (odd && !stop) {
@@ -185,7 +185,7 @@ void G_cfrac_upper (REAL_T * Gcfrac, REAL_T p, REAL_T x)
   if (t) {
 // b{1} is non-zero
     f = an / bn;
-    c = an / A68_REAL_MIN;
+    c = an / A68G_REAL_MIN;
     d = 1 / bn;
     n = 2;
   } else {
@@ -193,7 +193,7 @@ void G_cfrac_upper (REAL_T * Gcfrac, REAL_T p, REAL_T x)
     an = -(1 - p);
     bn = x + 3 - p;
     f = an / bn;
-    c = an / A68_REAL_MIN;
+    c = an / A68G_REAL_MIN;
     d = 1 / bn;
     n = 3;
   }
@@ -203,11 +203,11 @@ void G_cfrac_upper (REAL_T * Gcfrac, REAL_T p, REAL_T x)
     bn += 2;
     d = an * d + bn;
     if (d == 0) {
-      d = A68_REAL_MIN;
+      d = A68G_REAL_MIN;
     }
     c = bn + an / c;
     if (c == 0) {
-      c = A68_REAL_MIN;
+      c = A68G_REAL_MIN;
     }
     d = 1 / d;
     del = d * c;
@@ -215,7 +215,7 @@ void G_cfrac_upper (REAL_T * Gcfrac, REAL_T p, REAL_T x)
     i++;
     n++;
   }
-  while ((a68g_abs_real (del - 1.0) >= A68_REAL_EPS) && (n < ITMAX));
+  while ((a68g_abs_real (del - 1.0) >= A68G_REAL_EPS) && (n < ITMAX));
   *Gcfrac = t ? f : 1 / f;
 }
 
@@ -268,7 +268,7 @@ void romberg_estimate (REAL_T * rho, REAL_T * sigma, REAL_T x, REAL_T y, REAL_T
   *sigma = -mu * y + (p - 1) * a68g_ln_real (y);
   R[0] = 0.5 * (y - x) * (a68g_exp_real (-mu * x + (p - 1) * a68g_ln_real (x) - (*sigma)) + 1);
 // Loop for n > 0
-  REAL_T relneeded = A68_REAL_EPS / TOL_ROMBERG;
+  REAL_T relneeded = A68G_REAL_EPS / TOL_ROMBERG;
   INT_T adr0 = 0, n = 1;
   REAL_T h = (y - x) / 2;       // n=1, h = (y-x)/2^n
   REAL_T pow2 = 1;              // n=1; pow2 = 2^(n-1)
@@ -303,11 +303,11 @@ void deltagammainc (REAL_T * rho, REAL_T * sigma, REAL_T x, REAL_T y, REAL_T mu,
 // Particular cases
   if (a68g_isinf_real (x) && a68g_isinf_real (y)) {
     *rho = 0;
-    *sigma = a68g_neginf_double_real ();
+    *sigma = a68g_mininf_real ();
     return;
   } else if (x == y) {
     *rho = 0;
-    *sigma = a68g_neginf_double_real ();
+    *sigma = a68g_mininf_real ();
     return;
   }
   if (x == 0 && a68g_isinf_real (y)) {
@@ -318,9 +318,9 @@ void deltagammainc (REAL_T * rho, REAL_T * sigma, REAL_T x, REAL_T y, REAL_T mu,
 // Initialization
   REAL_T mA, mB, mx, my, nA, nB;
   G_func (&mx, p, mu * x);
-  REAL_T nx = (a68g_isinf_real (x) ? a68g_neginf_double_real () : -mu * x + p * a68g_ln_real (x));
+  REAL_T nx = (a68g_isinf_real (x) ? a68g_mininf_real () : -mu * x + p * a68g_ln_real (x));
   G_func (&my, p, mu * y);
-  REAL_T ny = (a68g_isinf_real (y) ? a68g_neginf_double_real () : -mu * y + p * a68g_ln_real (y));
+  REAL_T ny = (a68g_isinf_real (y) ? a68g_mininf_real () : -mu * y + p * a68g_ln_real (y));
 
 // Compute (mA,nA) and (mB,nB) such as I_{x,y}^{mu,p} can be
 // approximated by the difference A-B, where A >= B >= 0, A = mA*exp (nA) an 
@@ -366,33 +366,33 @@ void deltagammainc (REAL_T * rho, REAL_T * sigma, REAL_T x, REAL_T y, REAL_T mu,
 
 void genie_gamma_inc_g_real (NODE_T * n)
 {
-  A68_REAL x, y, mu, p;
-  POP_OBJECT (n, &mu, A68_REAL);
-  POP_OBJECT (n, &y, A68_REAL);
-  POP_OBJECT (n, &x, A68_REAL);
-  POP_OBJECT (n, &p, A68_REAL);
+  A68G_REAL x, y, mu, p;
+  POP_OBJECT (n, &mu, A68G_REAL);
+  POP_OBJECT (n, &y, A68G_REAL);
+  POP_OBJECT (n, &x, A68G_REAL);
+  POP_OBJECT (n, &p, A68G_REAL);
   REAL_T rho, sigma;
   deltagammainc (&rho, &sigma, VALUE (&x), VALUE (&y), VALUE (&mu), VALUE (&p));
-  PUSH_VALUE (n, rho * a68g_exp_real (sigma), A68_REAL);
+  PUSH_VALUE (n, rho * a68g_exp_real (sigma), A68G_REAL);
 }
 
 //! @brief PROC gamma inc f = (REAL p, x) REAL
 
 void genie_gamma_inc_f_real (NODE_T * n)
 {
-  A68_REAL x, p;
-  POP_OBJECT (n, &x, A68_REAL);
-  POP_OBJECT (n, &p, A68_REAL);
+  A68G_REAL x, p;
+  POP_OBJECT (n, &x, A68G_REAL);
+  POP_OBJECT (n, &p, A68G_REAL);
   REAL_T rho, sigma;
   deltagammainc (&rho, &sigma, VALUE (&x), a68g_posinf_real (), 1, VALUE (&p));
-  PUSH_VALUE (n, rho * a68g_exp_real (sigma), A68_REAL);
+  PUSH_VALUE (n, rho * a68g_exp_real (sigma), A68G_REAL);
 }
 
 //! @brief PROC gamma inc = (REAL p, x) REAL
 
 void genie_gamma_inc_h_real (NODE_T * n)
 {
-#if (A68_LEVEL >= 3) && defined (HAVE_GNU_MPFR)
+#if (A68G_LEVEL >= 3) && defined (HAVE_GNU_MPFR)
   genie_gamma_inc_real_mpfr (n);
 #else
   genie_gamma_inc_f_real (n);
@@ -405,10 +405,10 @@ void genie_gamma_inc_gf_real (NODE_T * q)
 {
 // if x <= p: G(p,x) = exp (x-p*ln (|x|)) * integral over [0,|x|] of s^{p-1} * exp (-sign (x)*s) ds
 // otherwise: G(p,x) = exp (x-p*ln (x)) * integral over [x,inf] of s^{p-1} * exp (-s) ds
-  A68_REAL x, p;
-  POP_OBJECT (q, &x, A68_REAL);
-  POP_OBJECT (q, &p, A68_REAL);
+  A68G_REAL x, p;
+  POP_OBJECT (q, &x, A68G_REAL);
+  POP_OBJECT (q, &p, A68G_REAL);
   REAL_T G;
   G_func (&G, VALUE (&p), VALUE (&x));
-  PUSH_VALUE (q, G, A68_REAL);
+  PUSH_VALUE (q, G, A68G_REAL);
 }
