@@ -83,26 +83,14 @@ REAL_T a68g_posinf_real (void)
   return a68g_fdiv_real (+1.0, 0.0);
 }
 
-REAL_T a68g_neginf_double_real (void)
+REAL_T a68g_mininf_real (void)
 {
   return a68g_fdiv_real (-1.0, 0.0);
 }
 
-// REAL infinity
+// Range check.
 
-void genie_infinity_real (NODE_T * p)
-{
-  PUSH_VALUE (p, a68g_posinf_real (), A68_REAL);
-}
-
-// REAL minus infinity
-
-void genie_minus_infinity_real (NODE_T * p)
-{
-  PUSH_VALUE (p, a68g_neginf_double_real (), A68_REAL);
-}
-
-int a68g_finite_real (REAL_T x)
+BOOL_T a68g_finite_real (REAL_T x)
 {
 #if defined (HAVE_ISFINITE)
   return isfinite (x);
@@ -110,36 +98,36 @@ int a68g_finite_real (REAL_T x)
   return finite (x);
 #else
   (void) x;
-  return A68_TRUE;
+  return A68G_TRUE;
 #endif
 }
 
-int a68g_isnan_real (REAL_T x)
+// Range check.
+
+BOOL_T a68g_isnan_real (REAL_T x)
 {
 #if defined (HAVE_ISNAN)
-  return isnan (x);
+  return isnan (x) == FP_NAN;
 #elif defined (HAVE_IEEE_COMPARISONS)
   int status = (x != x);
   return status;
 #else
   (void) x;
-  return A68_FALSE;
+  return A68G_FALSE;
 #endif
 }
 
-int a68g_isinf_real (REAL_T x)
+// Range check.
+
+BOOL_T a68g_isinf_real (REAL_T x)
 {
 #if defined (HAVE_ISINF)
-  if (isinf (x)) {
-    return (x > 0) ? 1 : -1;
-  } else {
-    return 0;
-  }
+  return isinf (x);
 #else
   if (!a68g_finite_real (x) && !a68g_isnan_real (x)) {
-    return (x > 0 ? 1 : -1);
+    return A68G_TRUE
   } else {
-    return 0;
+    return A68G_FALSE
   }
 #endif
 }
@@ -149,9 +137,9 @@ int a68g_isinf_real (REAL_T x)
 INT_T a68g_add_int (INT_T j, INT_T k)
 {
   if (j >= 0) {
-    A68_OVERFLOW (A68_MAX_INT - j < k);
+    A68G_OVERFLOW (A68G_MAX_INT - j < k);
   } else {
-    A68_OVERFLOW (k < (-A68_MAX_INT) - j);
+    A68G_OVERFLOW (k < (-A68G_MAX_INT) - j);
   }
   return j + k;
 }
@@ -167,20 +155,20 @@ INT_T a68g_mul_int (INT_T j, INT_T k)
     return 0;
   } else {
     INT_T u = (j > 0 ? j : -j), v = (k > 0 ? k : -k);
-    A68_OVERFLOW (u > A68_MAX_INT / v);
+    A68G_OVERFLOW (u > A68G_MAX_INT / v);
     return j * k;
   }
 }
 
 INT_T a68g_over_int (INT_T j, INT_T k)
 {
-  A68_INVALID (k == 0);
+  A68G_INVALID (k == 0);
   return j / k;
 }
 
 INT_T a68g_mod_int (INT_T j, INT_T k)
 {
-  A68_INVALID (k == 0);
+  A68G_INVALID (k == 0);
   INT_T r = j % k;
   return (r < 0 ? (k > 0 ? r + k : r - k) : r);
 }
@@ -190,7 +178,7 @@ INT_T a68g_mod_int (INT_T j, INT_T k)
 INT_T a68g_m_up_n (INT_T m, INT_T n)
 {
 // Only positive n.
-  A68_INVALID (n < 0);
+  A68G_INVALID (n < 0);
 // Special cases.
   if (m == 0 || m == 1) {
     return m;
@@ -238,13 +226,13 @@ REAL_T a68g_x_up_n_real (REAL_T x, INT_T n)
       M *= M;
     }
   } while (bit <= n);
-  A68_OVERFLOW (!a68g_finite_real (P));
+  A68G_OVERFLOW (!a68g_finite_real (P));
   return P;
 }
 
 REAL_T a68g_div_int (INT_T j, INT_T k)
 {
-  A68_INVALID (k == 0);
+  A68G_INVALID (k == 0);
   return (REAL_T) j / (REAL_T) k;
 }
 
@@ -274,9 +262,9 @@ REAL_T a68g_chebyshev_real (REAL_T x, const REAL_T c[], REAL_T acc)
 {
 // Iteratively compute the recursive Chebyshev series.
 // c[1..N] are coefficients, c[0] is N, and acc is relative accuracy.
-  acc *= A68_REAL_EPS;
+  acc *= A68G_REAL_EPS;
   if (acc < c[1]) {
-    diagnostic (A68_MATH_WARNING, A68 (f_entry), WARNING_MATH_ACCURACY, NULL);
+    diagnostic (A68G_MATH_WARNING, A68G (f_entry), WARNING_MATH_ACCURACY, NULL);
   }
   INT_T N = a68g_round (c[0]);
   REAL_T err = 0, z = 2 * x, u = 0, v = 0, w = 0;
@@ -297,8 +285,8 @@ REAL_T a68g_chebyshev_real (REAL_T x, const REAL_T c[], REAL_T acc)
 REAL_T a68g_ln1p_real (REAL_T x)
 {
 // Based on GNU GSL's gsl_sf_log_1plusx_e.
-  A68_INVALID (x <= -1);
-  if (a68g_abs_real (x) < pow (A68_REAL_EPS, 1 / 6.0)) {
+  A68G_INVALID (x <= -1);
+  if (a68g_abs_real (x) < pow (A68G_REAL_EPS, 1 / 6.0)) {
     const REAL_T c1 = -0.5, c2 = 1 / 3.0, c3 = -1 / 4.0, c4 = 1 / 5.0, c5 = -1 / 6.0, c6 = 1 / 7.0, c7 = -1 / 8.0, c8 = 1 / 9.0, c9 = -1 / 10.0;
     const REAL_T t = c5 + x * (c6 + x * (c7 + x * (c8 + x * c9)));
     return x * (1 + x * (c1 + x * (c2 + x * (c3 + x * (c4 + x * t)))));
@@ -314,8 +302,8 @@ REAL_T a68g_ln1p_real (REAL_T x)
 
 REAL_T a68g_ln_real (REAL_T x)
 {
-  A68_INVALID (x <= 0);
-#if (A68_LEVEL >= 3)
+  A68G_INVALID (x <= 0);
+#if (A68G_LEVEL >= 3)
   if (a68g_abs_real (x - 1) < 0.375) {
 // Double precision x-1 mitigates cancellation error.
     return a68g_ln1p_real (DBLEQ (x) - 1.0q);
@@ -346,7 +334,7 @@ REAL_T a68g_x_up_y (REAL_T x, REAL_T y)
 REAL_T a68g_csc_real (REAL_T x)
 {
   REAL_T z = sin (x);
-  A68_OVERFLOW (z == 0);
+  A68G_OVERFLOW (z == 0);
   return 1 / z;
 }
 
@@ -354,7 +342,7 @@ REAL_T a68g_csc_real (REAL_T x)
 
 REAL_T a68g_acsc_real (REAL_T x)
 {
-  A68_OVERFLOW (x == 0);
+  A68G_OVERFLOW (x == 0);
   return asin (1 / x);
 }
 
@@ -363,7 +351,7 @@ REAL_T a68g_acsc_real (REAL_T x)
 REAL_T a68g_sec_real (REAL_T x)
 {
   REAL_T z = cos (x);
-  A68_OVERFLOW (z == 0);
+  A68G_OVERFLOW (z == 0);
   return 1 / z;
 }
 
@@ -371,7 +359,7 @@ REAL_T a68g_sec_real (REAL_T x)
 
 REAL_T a68g_asec_real (REAL_T x)
 {
-  A68_OVERFLOW (x == 0);
+  A68G_OVERFLOW (x == 0);
   return acos (1 / x);
 }
 
@@ -380,7 +368,7 @@ REAL_T a68g_asec_real (REAL_T x)
 REAL_T a68g_cot_real (REAL_T x)
 {
   REAL_T z = sin (x);
-  A68_OVERFLOW (z == 0);
+  A68G_OVERFLOW (z == 0);
   return cos (x) / z;
 }
 
@@ -388,7 +376,7 @@ REAL_T a68g_cot_real (REAL_T x)
 
 REAL_T a68g_acot_real (REAL_T x)
 {
-  A68_OVERFLOW (x == 0);
+  A68G_OVERFLOW (x == 0);
   return atan (1 / x);
 }
 
@@ -397,7 +385,7 @@ REAL_T a68g_acot_real (REAL_T x)
 REAL_T a68g_atan2_real (REAL_T x, REAL_T y)
 {
   if (x == 0) {
-    A68_INVALID (y == 0);
+    A68G_INVALID (y == 0);
     return (y > 0 ? CONST_PI_2 : -CONST_PI_2);
   } else {
     REAL_T z = atan (ABS (y / x));
@@ -463,7 +451,7 @@ REAL_T a68g_atandg_real (REAL_T x)
 REAL_T a68g_cscdg_real (REAL_T x)
 {
   REAL_T z = a68g_sindg_real (x);
-  A68_OVERFLOW (z == 0);
+  A68G_OVERFLOW (z == 0);
   return 1 / z;
 }
 
@@ -471,7 +459,7 @@ REAL_T a68g_cscdg_real (REAL_T x)
 
 REAL_T a68g_acscdg_real (REAL_T x)
 {
-  A68_OVERFLOW (x == 0);
+  A68G_OVERFLOW (x == 0);
   return a68g_asindg_real (1 / x);
 }
 
@@ -480,7 +468,7 @@ REAL_T a68g_acscdg_real (REAL_T x)
 REAL_T a68g_secdg_real (REAL_T x)
 {
   REAL_T z = a68g_cosdg_real (x);
-  A68_OVERFLOW (z == 0);
+  A68G_OVERFLOW (z == 0);
   return 1 / z;
 }
 
@@ -488,7 +476,7 @@ REAL_T a68g_secdg_real (REAL_T x)
 
 REAL_T a68g_asecdg_real (REAL_T x)
 {
-  A68_OVERFLOW (x == 0);
+  A68G_OVERFLOW (x == 0);
   return a68g_acosdg_real (1 / x);
 }
 
@@ -497,7 +485,7 @@ REAL_T a68g_asecdg_real (REAL_T x)
 REAL_T a68g_cot_realdg_real (REAL_T x)
 {
   REAL_T z = a68g_sindg_real (x);
-  A68_OVERFLOW (z == 0);
+  A68G_OVERFLOW (z == 0);
   return a68g_cosdg_real (x) / z;
 }
 
@@ -505,7 +493,7 @@ REAL_T a68g_cot_realdg_real (REAL_T x)
 
 REAL_T a68g_acotdg_real (REAL_T z)
 {
-  A68_OVERFLOW (z == 0);
+  A68G_OVERFLOW (z == 0);
   return a68g_atandg_real (1 / z);
 }
 
@@ -560,7 +548,7 @@ REAL_T a68g_tanpi_real (REAL_T x)
     x -= 1;
   }
 // x in <-1/2, 1/2].
-  A68_OVERFLOW (x == 0.5);
+  A68G_OVERFLOW (x == 0.5);
   if (x == -0.25) {
     return -1;
   } else if (x == 0) {
@@ -583,7 +571,7 @@ REAL_T a68g_cot_realpi (REAL_T x)
     x -= 1;
   }
 // x in <-1/2, 1/2].
-  A68_OVERFLOW (x == 0);
+  A68G_OVERFLOW (x == 0);
   if (x == -0.25) {
     return -1;
   } else if (x == 0.25) {
@@ -600,11 +588,11 @@ REAL_T a68g_cot_realpi (REAL_T x)
 REAL_T a68g_asinh_real (REAL_T x)
 {
   REAL_T a = ABS (x), s = (x < 0 ? -1.0 : 1);
-  if (a > 1 / sqrt (A68_REAL_EPS)) {
+  if (a > 1 / sqrt (A68G_REAL_EPS)) {
     return (s * (a68g_ln_real (a) + a68g_ln_real (2)));
   } else if (a > 2) {
     return (s * a68g_ln_real (2 * a + 1 / (a + sqrt (a * a + 1))));
-  } else if (a > sqrt (A68_REAL_EPS)) {
+  } else if (a > sqrt (A68G_REAL_EPS)) {
     REAL_T a2 = a * a;
     return (s * a68g_ln1p_real (a + a2 / (1 + sqrt (1 + a2))));
   } else {
@@ -616,7 +604,7 @@ REAL_T a68g_asinh_real (REAL_T x)
 
 REAL_T a68g_acosh_real (REAL_T x)
 {
-  if (x > 1 / sqrt (A68_REAL_EPS)) {
+  if (x > 1 / sqrt (A68G_REAL_EPS)) {
     return (a68g_ln_real (x) + a68g_ln_real (2));
   } else if (x > 2) {
     return (a68g_ln_real (2 * x - 1 / (sqrt (x * x - 1) + x)));
@@ -626,7 +614,7 @@ REAL_T a68g_acosh_real (REAL_T x)
   } else if (x == 1) {
     return (0);
   } else {
-    A68_INVALID (A68_TRUE);
+    A68G_INVALID (A68G_TRUE);
   }
 }
 
@@ -635,11 +623,11 @@ REAL_T a68g_acosh_real (REAL_T x)
 REAL_T a68g_atanh_real (REAL_T x)
 {
   REAL_T a = ABS (x);
-  A68_INVALID (a >= 1);
+  A68G_INVALID (a >= 1);
   REAL_T s = (x < 0 ? -1 : 1);
   if (a >= 0.5) {
     return (s * 0.5 * a68g_ln1p_real (2 * a / (1 - a)));
-  } else if (a > A68_REAL_EPS) {
+  } else if (a > A68G_REAL_EPS) {
     return (s * 0.5 * a68g_ln1p_real (2 * a + 2 * a * a / (1 - a)));
   } else {
     return (x);
@@ -650,13 +638,13 @@ REAL_T a68g_atanh_real (REAL_T x)
 
 REAL_T a68g_inverfc_real (REAL_T y)
 {
-  A68_INVALID (y < 0 || y > 2);
+  A68G_INVALID (y < 0 || y > 2);
   if (y == 0) {
-    return A68_REAL_MAX;
+    return A68G_REAL_MAX;
   } else if (y == 1) {
     return 0;
   } else if (y == 2) {
-    return -A68_REAL_MAX;
+    return -A68G_REAL_MAX;
   } else {
 // Next is based on code that originally contained following statement:
 //   Copyright (c) 1996 Takuya Ooura. You may use, copy, modify this 
@@ -702,7 +690,7 @@ REAL_T a68g_beta_real (REAL_T a, REAL_T b)
 
 REAL_T a68g_fact_real (INT_T n)
 {
-  A68_INVALID (n < 0 || n > A68_MAX_FAC);
+  A68G_INVALID (n < 0 || n > A68G_MAX_FAC);
   return factable[n];
 }
 
@@ -710,8 +698,8 @@ REAL_T a68g_fact_real (INT_T n)
 
 REAL_T a68g_ln_fact_real (INT_T n)
 {
-  A68_INVALID (n < 0);
-  if (n <= A68_MAX_FAC) {
+  A68G_INVALID (n < 0);
+  if (n <= A68G_MAX_FAC) {
     return ln_factable[n];
   } else {
     return lgamma (n + 1);
@@ -722,7 +710,7 @@ REAL_T a68g_ln_fact_real (INT_T n)
 
 REAL_T a68g_choose_real (INT_T n, INT_T m)
 {
-  A68_INVALID (n < m);
+  A68G_INVALID (n < m);
   return factable[n] / (factable[m] * factable[n - m]);
 }
 
@@ -730,7 +718,7 @@ REAL_T a68g_choose_real (INT_T n, INT_T m)
 
 REAL_T a68g_ln_choose_real (INT_T n, INT_T m)
 {
-  A68_INVALID (n < m);
+  A68G_INVALID (n < m);
   return a68g_ln_fact_real (n) - (a68g_ln_fact_real (m) + a68g_ln_fact_real (n - m));
 }
 
@@ -743,7 +731,7 @@ REAL_T a68g_beta_inc_real (REAL_T s, REAL_T t, REAL_T x)
     return -1;
   } else {
     const INT_T lim = 16 * sizeof (REAL_T);
-    BOOL_T cont = A68_TRUE;
+    BOOL_T cont = A68G_TRUE;
 // Rapid convergence when x <= (s+1)/(s+t+2) or else recursion.
     if (x > (s + 1) / (s + t + 2)) {
 // B{x}(s, t) = 1 - B{1-x}(t, s)
@@ -768,7 +756,7 @@ REAL_T a68g_beta_inc_real (REAL_T s, REAL_T t, REAL_T x)
       c = T / c + 1;
       F *= c * d;
       if (F == W) {
-        cont = A68_FALSE;
+        cont = A68G_FALSE;
       } else {
         W = F;
       }
