@@ -78,8 +78,8 @@ void print_row (gsl_matrix *A, unt m, unt w)
 
 void print_matrix (gsl_matrix *A, unt w)
 {
-  unt M = SIZE1 (A), N = SIZE2 (A);
-  fprintf (stdout, "[%d, %d]\n", M, N);
+  size_t M = SIZE1 (A), N = SIZE2 (A);
+  fprintf (stdout, "[" A68G_LU " " A68G_LU "]\n", (UNSIGNED_T) M, (UNSIGNED_T) N);
   if (w <= 0 || M <= 2 * w) {
     for (int i = 0; i < M; i++) {
       print_row (A, i, w);
@@ -141,7 +141,7 @@ A68G_ROW vector_to_row (NODE_T * p, gsl_vector * v)
 
 A68G_ROW matrix_to_row (NODE_T * p, gsl_matrix * a)
 {
-  int len1 = (int) (SIZE1 (a)), len2 = (int) (SIZE2 (a));
+  size_t len1 = SIZE1 (a), len2 = SIZE2 (a);
   A68G_REF desc; A68G_ROW row; A68G_ARRAY arr; A68G_TUPLE tup1, tup2;
   desc = heap_generator (p, M_ROW_ROW_REAL, DESCRIPTOR_SIZE (2));
   row = heap_generator_3 (p, M_ROW_ROW_REAL, len1, len2, SIZE (M_REAL));
@@ -175,7 +175,7 @@ REAL_T matrix_norm (gsl_matrix *a)
 {
 #if (A68G_LEVEL >= 3)
   DOUBLE_T sum = 0.0;
-  unt M = SIZE1 (a), N = SIZE2 (a);
+  size_t M = SIZE1 (a), N = SIZE2 (a);
   for (int i = 0; i < M; i++) {
     for (int j = 0; j < N; j++) {
       DOUBLE_T z = gsl_matrix_get (a, i, j);
@@ -185,7 +185,7 @@ REAL_T matrix_norm (gsl_matrix *a)
   return ((REAL_T) sqrt_double (sum));
 #else
   REAL_T sum = 0.0;
-  unt M = SIZE1 (a), N = SIZE2 (a);
+  size_t M = SIZE1 (a), N = SIZE2 (a);
   for (int i = 0; i < M; i++) {
     for (int j = 0; j < N; j++) {
       REAL_T z = gsl_matrix_get (a, i, j);
@@ -209,8 +209,7 @@ void genie_matrix_norm (NODE_T * p)
 
 gsl_matrix *matrix_hcat (NODE_T *p, gsl_matrix *u, gsl_matrix *v)
 {
-  unt Mv = SIZE1 (v), Nv = SIZE2 (v);
-  unt Mu, Nu;
+  size_t Mv = SIZE1 (v), Nv = SIZE2 (v), Mu, Nu;
   if (u == NO_REAL_MATRIX) {
     Mu = Nu = 0;
   } else {
@@ -252,8 +251,7 @@ void genie_matrix_hcat (NODE_T *p)
 
 gsl_matrix *matrix_vcat (NODE_T *p, gsl_matrix *u, gsl_matrix *v)
 {
-  unt Mv = SIZE1 (v), Nv = SIZE2 (v);
-  unt Mu, Nu;
+  size_t Mv = SIZE1 (v), Nv = SIZE2 (v), Mu, Nu;
   if (u == NO_REAL_MATRIX) {
     Mu = Nu = 0;
   } else {
