@@ -177,7 +177,7 @@ static char *state_file = ".Random.seed";
 
 void GetRNGstate (void)
 {
-  INT_T fd = open (state_file, A68_READ_ACCESS);
+  INT_T fd = open (state_file, A68G_READ_ACCESS);
   if (fd != -1) {
     ASSERT (read (fd, &rng_state, sizeof (taus113_state_t)) != -1);
     close (fd);
@@ -186,7 +186,7 @@ void GetRNGstate (void)
 
 void PutRNGstate (void)
 {
-  INT_T fd = open (state_file, A68_WRITE_ACCESS, A68_PROTECTION);
+  INT_T fd = open (state_file, A68G_WRITE_ACCESS, A68G_PROTECTION);
   if (fd != -1) {
     ASSERT (write (fd, &rng_state, sizeof (taus113_state_t)) != -1);
     close (fd);
