@@ -56,7 +56,7 @@ gsl_permutation *pop_permutation (NODE_T * p, BOOL_T get)
   POP_REF (p, &desc);
   CHECK_REF (p, desc, M_ROW_INT);
   GET_DESCRIPTOR (arr, tup, &desc);
-  int len = ROW_SIZE (tup);
+  size_t len = ROW_SIZE (tup);
   gsl_permutation *v = gsl_permutation_calloc ((size_t) len);
   if (get && len > 0) {
     BYTE_T *base = DEREF (BYTE_T, &ARRAY (arr));
@@ -75,16 +75,16 @@ gsl_permutation *pop_permutation (NODE_T * p, BOOL_T get)
 
 void push_permutation (NODE_T * p, gsl_permutation * v)
 {
-  int len = (int) (SIZE (v));
+  size_t len = SIZE (v);
   A68G_REF desc, row; A68G_ARRAY arr; A68G_TUPLE tup;
   NEW_ROW_1D (desc, row, arr, tup, M_ROW_INT, M_INT, len);
   BYTE_T *base = DEREF (BYTE_T, &ARRAY (&arr));
   int idx = VECTOR_OFFSET (&arr, &tup);
   int inc = SPAN (&tup) * ELEM_SIZE (&arr);
-  for (int k = 0; k < len; k++, idx += inc) {
+  for (size_t k = 0; k < len; k++, idx += inc) {
     A68G_INT *x = (A68G_INT *) (base + idx);
     STATUS (x) = INIT_MASK;
-    VALUE (x) = (int) gsl_permutation_get (v, (size_t) k);
+    VALUE (x) = (INT_T) gsl_permutation_get (v, k);
   }
   PUSH_REF (p, desc);
 }
@@ -97,7 +97,7 @@ gsl_vector *pop_vector (NODE_T * p, BOOL_T get)
   POP_REF (p, &desc);
   CHECK_REF (p, desc, M_ROW_REAL);
   GET_DESCRIPTOR (arr, tup, &desc);
-  int len = ROW_SIZE (tup);
+  size_t len = ROW_SIZE (tup);
   gsl_vector *v = gsl_vector_calloc ((size_t) len);
   if (get && len > 0) {
     BYTE_T *base = DEREF (BYTE_T, &ARRAY (arr));
@@ -128,7 +128,7 @@ gsl_matrix *pop_matrix (NODE_T * p, BOOL_T get)
   CHECK_REF (p, desc, M_ROW_ROW_REAL);
   GET_DESCRIPTOR (arr, tup1, &desc);
   tup2 = &(tup1[1]);
-  int len1 = ROW_SIZE (tup1), len2 = ROW_SIZE (tup2);
+  size_t len1 = ROW_SIZE (tup1), len2 = ROW_SIZE (tup2);
   gsl_matrix *a = gsl_matrix_calloc ((size_t) len1, (size_t) len2);
   if (get && (len1 * len2 > 0)) {
     BYTE_T *base = DEREF (BYTE_T, &ARRAY (arr));
@@ -160,7 +160,7 @@ gsl_vector_complex *pop_vector_complex (NODE_T * p, BOOL_T get)
   POP_REF (p, &desc);
   CHECK_REF (p, desc, M_ROW_COMPLEX);
   GET_DESCRIPTOR (arr, tup, &desc);
-  int len = ROW_SIZE (tup);
+  size_t len = ROW_SIZE (tup);
   gsl_vector_complex *v = gsl_vector_complex_calloc ((size_t) len);
   if (get && len > 0) {
     BYTE_T *base = DEREF (BYTE_T, &ARRAY (arr));
@@ -183,7 +183,7 @@ gsl_vector_complex *pop_vector_complex (NODE_T * p, BOOL_T get)
 
 void push_vector_complex (NODE_T * p, gsl_vector_complex * v)
 {
-  int len = (int) (SIZE (v));
+  size_t len = SIZE (v);
   A68G_REF desc, row; A68G_ARRAY arr; A68G_TUPLE tup;
   NEW_ROW_1D (desc, row, arr, tup, M_ROW_COMPLEX, M_COMPLEX, len);
   BYTE_T *base = DEREF (BYTE_T, &ARRAY (&arr));
@@ -211,7 +211,7 @@ gsl_matrix_complex *pop_matrix_complex (NODE_T * p, BOOL_T get)
   CHECK_REF (p, desc, M_ROW_ROW_COMPLEX);
   GET_DESCRIPTOR (arr, tup1, &desc);
   tup2 = &(tup1[1]);
-  int len1 = ROW_SIZE (tup1), len2 = ROW_SIZE (tup2);
+  size_t len1 = ROW_SIZE (tup1), len2 = ROW_SIZE (tup2);
   gsl_matrix_complex *a = gsl_matrix_complex_calloc ((size_t) len1, (size_t) len2);
   if (get && (len1 * len2 > 0)) {
     BYTE_T *base = DEREF (BYTE_T, &ARRAY (arr));
@@ -236,7 +236,7 @@ gsl_matrix_complex *pop_matrix_complex (NODE_T * p, BOOL_T get)
 
 void push_matrix_complex (NODE_T * p, gsl_matrix_complex * a)
 {
-  int len1 = (int) (SIZE1 (a)), len2 = (int) (SIZE2 (a));
+  size_t len1 = SIZE1 (a), len2 = SIZE2 (a);
   A68G_REF desc, row; A68G_ARRAY arr; A68G_TUPLE tup1, tup2;
   desc = heap_generator (p, M_ROW_ROW_COMPLEX, DESCRIPTOR_SIZE (2));
   row = heap_generator_3 (p, M_ROW_ROW_COMPLEX, len1, len2, 2 * SIZE (M_REAL));
@@ -463,7 +463,12 @@ void genie_matrix_det (NODE_T * p)
   gsl_permutation *q = gsl_permutation_calloc (SIZE1 (u));
   int sign;
   ASSERT_GSL (gsl_linalg_LU_decomp (u, q, &sign));
-  PUSH_VALUE (p, gsl_linalg_LU_det (u, sign), A68G_REAL);
+  REAL_T det = gsl_linalg_LU_det (u, sign);
+  if (a68g_isnan_real (det)) { // Singularity.
+    PUSH_VALUE (p, 0, A68G_REAL);
+  } else {
+    PUSH_VALUE (p, gsl_linalg_LU_det (u, sign), A68G_REAL);
+  }
   gsl_matrix_free (u);
   gsl_permutation_free (q);
   (void) gsl_set_error_handler (save_handler);
@@ -479,8 +484,18 @@ void genie_matrix_complex_det (NODE_T * p)
   int sign;
   ASSERT_GSL (gsl_linalg_complex_LU_decomp (u, q, &sign));
   gsl_complex det = gsl_linalg_complex_LU_det (u, sign);
-  PUSH_VALUE (p, GSL_REAL (det), A68G_REAL);
-  PUSH_VALUE (p, GSL_IMAG (det), A68G_REAL);
+  REAL_T re_det = GSL_REAL (det);
+  if (a68g_isnan_real (re_det)) { // Singularity.
+    PUSH_VALUE (p, 0, A68G_REAL);
+  } else {
+    PUSH_VALUE (p, re_det, A68G_REAL);
+  }
+  REAL_T im_det = GSL_IMAG (det);
+  if (a68g_isnan_real (im_det)) { // Singularity.
+    PUSH_VALUE (p, 0, A68G_REAL);
+  } else {
+    PUSH_VALUE (p, im_det, A68G_REAL);
+  }
   gsl_matrix_complex_free (u);
   gsl_permutation_free (q);
   (void) gsl_set_error_handler (save_handler);
@@ -492,7 +507,7 @@ void genie_matrix_trace (NODE_T * p)
 {
   gsl_error_handler_t *save_handler = gsl_set_error_handler (torrix_error_handler);
   gsl_matrix *a = pop_matrix (p, A68G_TRUE);
-  int len1 = (int) (SIZE1 (a)), len2 = (int) (SIZE2 (a));
+  size_t len1 = SIZE1 (a), len2 = SIZE2 (a);
   if (len1 != len2) {
     torrix_error_handler ("cannot calculate trace", __FILE__, __LINE__, GSL_ENOTSQR);
   }
@@ -511,7 +526,7 @@ void genie_matrix_complex_trace (NODE_T * p)
 {
   gsl_error_handler_t *save_handler = gsl_set_error_handler (torrix_error_handler);
   gsl_matrix_complex *a = pop_matrix_complex (p, A68G_TRUE);
-  int len1 = (int) (SIZE1 (a)), len2 = (int) (SIZE2 (a));
+  size_t len1 = SIZE1 (a), len2 = SIZE2 (a);
   if (len1 != len2) {
     torrix_error_handler ("cannot calculate trace", __FILE__, __LINE__, GSL_ENOTSQR);
   }
@@ -1128,7 +1143,7 @@ void genie_vector_dyad (NODE_T * p)
   gsl_error_handler_t *save_handler = gsl_set_error_handler (torrix_error_handler);
   gsl_vector *v = pop_vector (p, A68G_TRUE);
   gsl_vector *u = pop_vector (p, A68G_TRUE);
-  int len1 = (int) (SIZE (u)), len2 = (int) (SIZE (v));
+  size_t len1 = SIZE (u), len2 = SIZE (v);
   gsl_matrix *w = gsl_matrix_calloc ((size_t) len1, (size_t) len2);
   for (int j = 0; j < len1; j++) {
     REAL_T uj = gsl_vector_get (u, (size_t) j);
@@ -1151,7 +1166,7 @@ void genie_vector_complex_dyad (NODE_T * p)
   gsl_error_handler_t *save_handler = gsl_set_error_handler (torrix_error_handler);
   gsl_vector_complex *v = pop_vector_complex (p, A68G_TRUE);
   gsl_vector_complex *u = pop_vector_complex (p, A68G_TRUE);
-  int len1 = (int) (SIZE (u)), len2 = (int) (SIZE (v));
+  size_t len1 = SIZE (u), len2 = SIZE (v);
   gsl_matrix_complex *w = gsl_matrix_complex_calloc ((size_t) len1, (size_t) len2);
   for (int j = 0; j < len1; j++) {
     gsl_complex uj = gsl_vector_complex_get (u, (size_t) j);
@@ -1174,7 +1189,7 @@ void genie_matrix_times_vector (NODE_T * p)
   gsl_error_handler_t *save_handler = gsl_set_error_handler (torrix_error_handler);
   gsl_vector *u = pop_vector (p, A68G_TRUE);
   gsl_matrix *w = pop_matrix (p, A68G_TRUE);
-  int len = (int) (SIZE (u));
+  size_t len = SIZE (u);
   gsl_vector *v = gsl_vector_calloc ((size_t) len);
   gsl_vector_set_zero (v);
   ASSERT_GSL (gsl_blas_dgemv (CblasNoTrans, 1.0, w, u, 0.0, v));
@@ -1193,7 +1208,7 @@ void genie_vector_times_matrix (NODE_T * p)
   gsl_matrix *w = pop_matrix (p, A68G_TRUE);
   ASSERT_GSL (gsl_matrix_transpose (w));
   gsl_vector *u = pop_vector (p, A68G_TRUE);
-  int len = (int) (SIZE (u));
+  size_t len = SIZE (u);
   gsl_vector *v = gsl_vector_calloc ((size_t) len);
   gsl_vector_set_zero (v);
   ASSERT_GSL (gsl_blas_dgemv (CblasNoTrans, 1.0, w, u, 0.0, v));
@@ -1211,7 +1226,7 @@ void genie_matrix_times_matrix (NODE_T * p)
   gsl_error_handler_t *save_handler = gsl_set_error_handler (torrix_error_handler);
   gsl_matrix *v = pop_matrix (p, A68G_TRUE);
   gsl_matrix *u = pop_matrix (p, A68G_TRUE);
-  int len2 = (int) (SIZE2 (v)), len1 = (int) (SIZE1 (u));
+  size_t len2 = SIZE2 (v), len1 = SIZE1 (u);
   gsl_matrix *w = gsl_matrix_calloc ((size_t) len1, (size_t) len2);
   ASSERT_GSL (gsl_blas_dgemm (CblasNoTrans, CblasNoTrans, 1.0, u, v, 0.0, w));
   push_matrix (p, w);
@@ -1231,7 +1246,7 @@ void genie_matrix_complex_times_vector (NODE_T * p)
   GSL_SET_COMPLEX (&one, 1.0, 0.0);
   gsl_vector_complex *u = pop_vector_complex (p, A68G_TRUE);
   gsl_matrix_complex *w = pop_matrix_complex (p, A68G_TRUE);
-  int len = (int) (SIZE (u));
+  size_t len = SIZE (u);
   gsl_vector_complex *v = gsl_vector_complex_calloc ((size_t) len);
   ASSERT_GSL (gsl_blas_zgemv (CblasNoTrans, one, w, u, zero, v));
   push_vector_complex (p, v);
@@ -1252,7 +1267,7 @@ void genie_vector_complex_times_matrix (NODE_T * p)
   gsl_matrix_complex *w = pop_matrix_complex (p, A68G_TRUE);
   ASSERT_GSL (gsl_matrix_complex_transpose (w));
   gsl_vector_complex *u = pop_vector_complex (p, A68G_TRUE);
-  int len = (int) (SIZE (u));
+  size_t len = SIZE (u);
   gsl_vector_complex *v = gsl_vector_complex_calloc ((size_t) len);
   ASSERT_GSL (gsl_blas_zgemv (CblasNoTrans, one, w, u, zero, v));
   push_vector_complex (p, v);
@@ -1272,7 +1287,7 @@ void genie_matrix_complex_times_matrix (NODE_T * p)
   GSL_SET_COMPLEX (&one, 1.0, 0.0);
   gsl_matrix_complex *v = pop_matrix_complex (p, A68G_TRUE);
   gsl_matrix_complex *u = pop_matrix_complex (p, A68G_TRUE);
-  int len1 = (int) (SIZE2 (v)), len2 = (int) (SIZE1 (u));
+  size_t len1 = SIZE2 (v), len2 = SIZE1 (u);
   gsl_matrix_complex *w = gsl_matrix_complex_calloc ((size_t) len1, (size_t) len2);
   ASSERT_GSL (gsl_blas_zgemm (CblasNoTrans, CblasNoTrans, one, u, v, zero, w));
   gsl_matrix_complex_free (u);
