@@ -1615,7 +1615,7 @@ void genie_bits_pack (NODE_T * p)
   POP_REF (p, &z);
   CHECK_REF (p, z, M_ROW_BOOL);
   GET_DESCRIPTOR (arr, tup, &z);
-  int size = ROW_SIZE (tup);
+  size_t size = ROW_SIZE (tup);
   PRELUDE_ERROR (size < 0 || size > A68G_BITS_WIDTH, p, ERROR_OUT_OF_BOUNDS, M_ROW_BOOL);
   A68G_BITS b;
   VALUE (&b) = 0x0;
