@@ -124,19 +124,19 @@ typedef struct GC_GLOBALS_T GC_GLOBALS_T;
 struct GC_GLOBALS_T
 {
   A68G_HANDLE *available_handles, *busy_handles;
-  UNSIGNED_T free_handles, max_handles, sweeps, refused, freed, total;
-  unt preemptive, sema;
+  BOOL_T preemptive;
+  INT_T sema;
   REAL_T seconds;
+  size_t free_handles, max_handles, sweeps, refused, freed, total;
 };
 
 typedef struct INDENT_GLOBALS_T INDENT_GLOBALS_T;
 #define A68G_INDENT(z)  A68G (indent.z)
 struct INDENT_GLOBALS_T
 {
-  FILE_T fd;
-  int ind, col;
-  int indentation;
   BOOL_T use_folder;
+  FILE_T fd;
+  int ind, col, indentation;
 };
 
 #define MON_STACK_SIZE 32
@@ -146,8 +146,7 @@ typedef struct MONITOR_GLOBALS_T MONITOR_GLOBALS_T;
 struct MONITOR_GLOBALS_T
 {
   ADDR_T finish_frame_pointer;
-  BOOL_T in_monitor;
-  BOOL_T prompt_set;
+  BOOL_T in_monitor, prompt_set;
   BUFFER prompt, symbol, error_text, expr;
   char *watchpoint_expression;
   int break_proc_level;
@@ -260,16 +259,17 @@ struct PARALLEL_GLOBALS_T
 #endif
 
 typedef struct PARSER_GLOBALS_T PARSER_GLOBALS_T;
+
 #define A68G_PARSER(z)  A68G (parser.z)
+
 struct PARSER_GLOBALS_T
 {
-  TAG_T *error_tag;
   BOOL_T stop_scanner, read_error, no_preprocessing;
   char *scan_buf;
-  int max_scan_buf_length, source_file_size;
-  int reductions;
-  int tag_number;
+  int reductions, tag_number;
   jmp_buf bottom_up_crash_exit, top_down_crash_exit;
+  size_t max_scan_buf_length, source_file_size;
+  TAG_T *error_tag;
 };
 
 typedef struct GLOBALS_T GLOBALS_T;
@@ -329,9 +329,9 @@ struct GLOBALS_T
   TABLE_T *standenv;
   TAG_T *error_tag;
   TOKEN_T *top_token;
-  unt frame_stack_size, expr_stack_size, heap_size, handle_pool_size, stack_size;
-  unt stack_limit, frame_stack_limit, expr_stack_limit;
-  unt storage_overhead;
+  size_t frame_stack_size, expr_stack_size, heap_size, handle_pool_size, stack_size;
+  size_t stack_limit, frame_stack_limit, expr_stack_limit;
+  size_t storage_overhead;
 #if defined (BUILD_PARALLEL_CLAUSE)
   PARALLEL_GLOBALS_T parallel;
 #endif
