@@ -28,9 +28,23 @@
 
 // Constants
 
-#define KILOBYTE ((unt) 1024)
+// Memory sizes are in SI units.
+
+#define KILOBYTE ((size_t) 1000)
 #define MEGABYTE (KILOBYTE * KILOBYTE)
 #define GIGABYTE (KILOBYTE * MEGABYTE)
+#if defined (HAVE_LARGE_STORAGE) && (A68G_LEVEL >= 3)
+  #define TERABYTE (KILOBYTE * GIGABYTE)
+  #define PETABYTE (KILOBYTE * TERABYTE)
+#endif
+
+#if defined (HAVE_LARGE_STORAGE)
+  #define MAX_MEM_SIZE ((size_t) 2 * TERABYTE)
+#else
+  #define MAX_MEM_SIZE ((size_t) 2 * GIGABYTE)
+#endif
+
+#define MEM_OVERHEAD ((size_t) MEGABYTE)
 
 #define A68G_TRUE ((BOOL_T) 1)
 #define A68G_FALSE ((BOOL_T) 0)
@@ -79,6 +93,7 @@
 
 #define A68G_DIR ".a68g"
 #define A68G_HISTORY_FILE ".a68g.edit.hist"
+#define A68G_MAX_LEX_LEVEL (INT_MAX)
 #define A68G_NO_FILE ((FILE_T) -1)
 #define A68G_PROTECTION (S_IRUSR | S_IWUSR | S_IRGRP | S_IROTH)  // -rw-r--r--
 #define A68G_READ_ACCESS (O_RDONLY)
@@ -95,7 +110,6 @@
 #define MAX_PRIORITY 9
 #define MAX_TERM_HEIGTH 24
 #define MAX_TERM_WIDTH (BUFFER_SIZE / 2)
-#define MIN_MEM_SIZE (128 * KILOBYTE)
 #define MOID_ERROR_WIDTH 80
 #define MOID_WIDTH 80
 #define MONADS "%^&+-~!?"
@@ -103,14 +117,18 @@
 #define NOMADS "></=*"
 #define NOT_EMBEDDED_FORMAT A68G_FALSE
 #define NOT_PRINTED 1
-#define OVER_2G(n) ((REAL_T) (n) > (REAL_T) (2 * GIGABYTE)) 
 #define PRIMAL_SCOPE 0
 #define SKIP_PATTERN A68G_FALSE
 #define SMALL_BUFFER_SIZE 128
 #define SNPRINTF_SIZE ((size_t) (BUFFER_SIZE - 1))
+#define TRANSPUT_BUFFER_BLOCKED (-1)
 #define TRANSPUT_BUFFER_SIZE BUFFER_SIZE
 #define WANT_PATTERN A68G_TRUE
 
+#define A68G_GC_GO 0
+#define A68G_GC_SAFE 1
+#define A68G_GC_HALT 2
+
 // Macros
 
 #define _SKIP_ { (void) 0;}
@@ -126,15 +144,15 @@
 #define MINIMISE(u, v) ((u) = MIN (u, v))
 
 #define COPY(d, s, n) {\
-  int _m_k = (n); BYTE_T *_m_u = (BYTE_T *) (d), *_m_v = (BYTE_T *) (s);\
+  INT_T _m_k = (INT_T) (n); BYTE_T *_m_u = (BYTE_T *) (d), *_m_v = (BYTE_T *) (s);\
   while (_m_k--) {*_m_u++ = *_m_v++;}}
 
 #define COPY_ALIGNED(d, s, n) {\
-  int _m_k = (n); A68G_ALIGN_T *_m_u = (A68G_ALIGN_T *) (d), *_m_v = (A68G_ALIGN_T *) (s);\
+  INT_T _m_k = (INT_T) (n); A68G_ALIGN_T *_m_u = (A68G_ALIGN_T *) (d), *_m_v = (A68G_ALIGN_T *) (s);\
   while (_m_k > 0) {*_m_u++ = *_m_v++; _m_k -= A68G_ALIGNMENT;}}
 
 #define MOVE(d, s, n) {\
-  int _m_k = (int) (n); BYTE_T *_m_d = (BYTE_T *) (d), *_m_s = (BYTE_T *) (s);\
+  INT_T _m_k = (INT_T) (n); BYTE_T *_m_d = (BYTE_T *) (d), *_m_s = (BYTE_T *) (s);\
   if (_m_s < _m_d) {\
     _m_d += _m_k; _m_s += _m_k;\
     while (_m_k--) {*(--_m_d) = *(--_m_s);}\
@@ -143,11 +161,11 @@
   }}
 
 #define FILL(d, s, n) {\
-   int _m_k = (n); BYTE_T *_m_u = (BYTE_T *) (d), _m_v = (BYTE_T) (s);\
+   INT_T _m_k = (INT_T) (n); BYTE_T *_m_u = (BYTE_T *) (d), _m_v = (BYTE_T) (s);\
    while (_m_k--) {*_m_u++ = _m_v;}}
 
 #define FILL_ALIGNED(d, s, n) {\
-   int _m_k = (n); A68G_ALIGN_T *_m_u = (A68G_ALIGN_T *) (d), _m_v = (A68G_ALIGN_T) (s);\
+   INT_T _m_k = (INT_T) (n); A68G_ALIGN_T *_m_u = (A68G_ALIGN_T *) (d), _m_v = (A68G_ALIGN_T) (s);\
    while (_m_k > 0) {*_m_u++ = _m_v; _m_k -= A68G_ALIGNMENT;}}
 
 #define ABEND(p, reason, info) {\
