@@ -46,7 +46,6 @@ void write_source_line (FILE_T, LINE_T *, NODE_T *, int);
 #define A68G_NOTICE            ((STATUS_MASK_T) 0x40)
 #define A68G_ALL_DIAGNOSTICS   ((STATUS_MASK_T) 0x80)
 #define A68G_RERUN             ((STATUS_MASK_T) 0x100)
-#define A68G_FORCE_DIAGNOSTICS ((STATUS_MASK_T) 0x200)
 #define A68G_FORCE_QUIT        ((STATUS_MASK_T) 0x400)
 #define A68G_NO_SYNTHESIS      ((STATUS_MASK_T) 0x800)
 #define A68G_SCANNER_ERROR     ((STATUS_MASK_T) 0x1000)
@@ -57,11 +56,10 @@ void write_source_line (FILE_T, LINE_T *, NODE_T *, int);
 #define ERROR_ACCESSING_NIL "attempt to access N"
 #define ERROR_ACTION "action failed"
 #define ERROR_ALIGNMENT "alignment error"
-#define ERROR_ALLOCATION "allocation error"
 #define ERROR_ARGUMENT_NUMBER "incorrect number of arguments for M"
 #define ERROR_ASSERTION "assertion failure"
-#define ERROR_CANNOT_OPEN_PLUGIN "cannot open plugin"
 #define ERROR_CANNOT_OPEN_NAME "cannot open Z"
+#define ERROR_CANNOT_OPEN_PLUGIN "cannot open plugin"
 #define ERROR_CANNOT_WIDEN "cannot widen M to M"
 #define ERROR_CANNOT_WRITE_LISTING "cannot write listing file"
 #define ERROR_CHANNEL_DOES_NOT_ALLOW "channel does not allow Y"
@@ -70,10 +68,12 @@ void write_source_line (FILE_T, LINE_T *, NODE_T *, int);
 #define ERROR_CLOSING_FILE "error while closing file"
 #define ERROR_CODE "clause should be compiled"
 #define ERROR_COMMA_MUST_SEPARATE "A and A must be separated by a comma-symbol"
+#define ERROR_COMMAND_LINE "command line only option"
 #define ERROR_COMPONENT_NUMBER "M must have at least two components"
 #define ERROR_COMPONENT_RELATED "M has firmly related components"
 #define ERROR_CURSES "error in curses operation"
 #define ERROR_CURSES_OFF_SCREEN "curses operation moves cursor off the screen"
+#define ERROR_DEPRECATED "M in this construct is deprecated in V"
 #define ERROR_DEVICE_ALREADY_SET "device parameters already set"
 #define ERROR_DEVICE_CANNOT_ALLOCATE "cannot allocate device parameters"
 #define ERROR_DEVICE_CANNOT_OPEN "cannot open device"
@@ -85,8 +85,8 @@ void write_source_line (FILE_T, LINE_T *, NODE_T *, int);
 #define ERROR_EMPTY_ARGUMENT "empty argument"
 #define ERROR_EMPTY_VALUE "attempt to use an uninitialised M value"
 #define ERROR_EMPTY_VALUE_FROM (ERROR_EMPTY_VALUE)
-#define ERROR_EXPECTED "Y expected"
 #define ERROR_EXPECTED_NEAR "B expected in A, near Z L"
+#define ERROR_EXPECTED "Y expected"
 #define ERROR_EXPONENT_DIGIT "invalid exponent digit"
 #define ERROR_EXPONENT_INVALID "invalid M exponent"
 #define ERROR_FALSE_ASSERTION "false assertion"
@@ -100,8 +100,8 @@ void write_source_line (FILE_T, LINE_T *, NODE_T *, int);
 #define ERROR_FILE_ENDED "end of file reached"
 #define ERROR_FILE_INCLUDE_CTRL "invalid characters in include file"
 #define ERROR_FILE_LOCK "error while locking file"
-#define ERROR_FILE_NOT_OPEN "file is not open"
 #define ERROR_FILE_NO_TEMP "cannot create unique temporary file name"
+#define ERROR_FILE_NOT_OPEN "file is not open"
 #define ERROR_FILE_READ "error while reading file"
 #define ERROR_FILE_RESET "error while resetting file"
 #define ERROR_FILE_SCRATCH "error while scratching file"
@@ -114,10 +114,12 @@ void write_source_line (FILE_T, LINE_T *, NODE_T *, int);
 #define ERROR_FORMAT_EXHAUSTED "patterns exhausted in format"
 #define ERROR_FORMAT_INTS_REQUIRED "1 .. 3 M arguments required"
 #define ERROR_FORMAT_INVALID_REPLICATOR "negative replicator"
-#define ERROR_FORMAT_PICTURES "number of pictures does not match number of arguments"
 #define ERROR_FORMAT_PICTURE_NUMBER "incorrect number of pictures for A"
+#define ERROR_FORMAT_PICTURES "number of pictures does not match number of arguments"
 #define ERROR_FORMAT_UNDEFINED "cannot use undefined format"
+#define ERROR_HIGH_PRECISION "unsupported precision"
 #define ERROR_INCORRECT_FILENAME "incorrect filename"
+#define ERROR_IN_DENOTATION "error in M denotation"
 #define ERROR_INDEXER_NUMBER "incorrect number of indexers for M"
 #define ERROR_INDEX_OUT_OF_BOUNDS "index out of bounds"
 #define ERROR_INFINITE "infinite M value"
@@ -131,22 +133,24 @@ void write_source_line (FILE_T, LINE_T *, NODE_T *, int);
 #define ERROR_INVALID_RADIX "invalid radix D"
 #define ERROR_INVALID_SIZE "object of invalid size"
 #define ERROR_INVALID_VALUE "invalid value"
-#define ERROR_IN_DENOTATION "error in M denotation"
+#define ERROR_IS_DIRECTORY "source file cannot be a directory"
 #define ERROR_KEYWORD "check for missing or unmatched keyword in clause starting at S"
-#define ERROR_LABELED_UNIT_MUST_FOLLOW "S must be followed by a labeled unit"
 #define ERROR_LABEL_BEFORE_DECLARATION "declaration cannot follow a labeled unit"
+#define ERROR_LABELED_UNIT_MUST_FOLLOW "S must be followed by a labeled unit"
 #define ERROR_LAPLACE "laplace transform error; Y; Y"
 #define ERROR_LONG_STRING "string exceeds end of line"
-#define ERROR_MATH "M math error"
 #define ERROR_MATH_CHEBYSHEV "error while evaluating Chebyshev series"
 #define ERROR_MATH_CONVERGENCE "no convergence"
 #define ERROR_MATH_EXCEPTION "math exception"
 #define ERROR_MATH_EXP "exp argument out of range"
+#define ERROR_MATH "M math error"
+#define ERROR_MEMORY_FULL "not enough memory"
+#define ERROR_MISSING_STUFF "argument or value expected"
 #define ERROR_MODE_SPECIFICATION "M construct must yield a routine, row or structured value"
 #define ERROR_MP_OUT_OF_BOUNDS "multiprecision value out of bounds"
 #define ERROR_MULTIPLE_FIELD "multiple declaration of field S"
+#define ERROR_MULTIPLE_SOURCE_FILES "multiple source files"
 #define ERROR_MULTIPLE_TAG "multiple declaration of tag S"
-#define ERROR_NOT_WELL_FORMED "M does not specify a well formed mode"
 #define ERROR_NO_COMPONENT "M is neither component nor subset of M"
 #define ERROR_NO_DYADIC "dyadic operator O S O has not been declared"
 #define ERROR_NO_FIELD "M has no field Z"
@@ -157,32 +161,32 @@ void write_source_line (FILE_T, LINE_T *, NODE_T *, int);
 #define ERROR_NO_NAME_REQUIRED "context does not require a name"
 #define ERROR_NO_PARALLEL_CLAUSE "interpreter was built without parallel-clause support"
 #define ERROR_NO_PRIORITY "S has no priority declaration"
-#define ERROR_IS_DIRECTORY "source file cannot be a directory"
 #define ERROR_NO_REGULAR_FILE "source is not a regular file"
 #define ERROR_NO_ROW_OR_PROC "M A does not yield a row or procedure"
 #define ERROR_NO_SOURCE_FILE "no source file specified"
 #define ERROR_NO_SQUARE_MATRIX "M matrix is not square"
 #define ERROR_NO_STRUCT "M A does not yield a structured value"
+#define ERROR_NOT_WELL_FORMED "M does not specify a well formed mode"
 #define ERROR_NO_UNION "M is not a united mode"
 #define ERROR_NO_UNIQUE_MODE "construct has no unique mode"
 #define ERROR_NO_VECTOR "M A does not yield a one-dimensional row"
-#define ERROR_DEPRECATED "M in this construct is deprecated in V"
+#define ERROR_OBJECT_TOO_LARGE "M object too large"
 #define ERROR_OPERAND_NUMBER "incorrect number of operands for S"
-#define ERROR_OPERATOR_INVALID "monadic S cannot start with a character from Z"
 #define ERROR_OPERATOR_INVALID_END "probably a missing symbol near invalid operator S"
+#define ERROR_OPERATOR_INVALID "monadic S cannot start with a character from Z"
 #define ERROR_OPERATOR_RELATED "M Z is firmly related to M Z"
 #define ERROR_OUT_OF_BOUNDS "M value out of bounds"
-#define ERROR_OUT_OF_CORE "insufficient memory"
-#define ERROR_OVER_2G "requesting over 2GB"
 #define ERROR_PAGE_SIZE "error in page size"
-#define ERROR_PARALLEL_JUMP "jump into different thread"
 #define ERROR_PARALLEL_CANNOT_CREATE "cannot create thread"
+#define ERROR_PARALLEL_JUMP "jump into different thread"
 #define ERROR_PARALLEL_OUTSIDE "invalid outside a parallel-clause"
 #define ERROR_PARALLEL_OVERFLOW "too many parallel units (Y)"
-#define ERROR_PARENTHESIS "incorrect nesting, check for Y"
 #define ERROR_PARENTHESIS_2 "encountered X L but expected X, check for Y"
+#define ERROR_PARENTHESIS "incorrect nesting, check for Y"
+#define ERROR_PLATFORM "not implemented for this platform"
 #define ERROR_PRAGMENT "error in pragment"
-#define ERROR_HIGH_PRECISION "unsupported precision"
+#define ERROR_PRECISION_SET "K K precision already set"
+#define ERROR_PRECISION_TOO_LOW "K K precision cannot be smaller than K precision"
 #define ERROR_QUOTED_BOLD_TAG "error in quoted bold-tag"
 #define ERROR_REDEFINED_KEYWORD "attempt to redefine keyword Y in A"
 #define ERROR_REFINEMENT_APPLIED "refinement is applied more than once"
@@ -213,11 +217,12 @@ void write_source_line (FILE_T, LINE_T *, NODE_T *, int);
 #define ERROR_TORRIX "linear algebra error; Y; Y"
 #define ERROR_TRANSIENT_NAME "attempt at storing a transient name"
 #define ERROR_UNBALANCED_KEYWORD "missing or unbalanced keyword in A, near Z L"
-#define ERROR_UNDECLARED_TAG "tag S has not been declared properly"
 #define ERROR_UNDECLARED_TAG_2 "tag Z has not been declared properly"
+#define ERROR_UNDECLARED_TAG "tag S has not been declared properly"
 #define ERROR_UNDEFINED_TRANSPUT "transput of M value by this procedure is not defined"
 #define ERROR_UNDERDETERMINED_SYSTEM "underdetermined system of linear equations"
 #define ERROR_UNIMPLEMENTED "S is either not implemented or not compiled"
+#define ERROR_UNRECOGNISED_OPTION "unrecognised option"
 #define ERROR_UNSPECIFIED "unspecified error"
 #define ERROR_UNTERMINATED_COMMENT "unterminated comment"
 #define ERROR_UNTERMINATED_PRAGMAT "unterminated pragmat"
@@ -225,6 +230,7 @@ void write_source_line (FILE_T, LINE_T *, NODE_T *, int);
 #define ERROR_UNTERMINATED_STRING "unterminated string"
 #define ERROR_UNWORTHY_CHARACTER "unworthy character"
 #define ERROR_VACUUM "vacuum cannot have row elements (use a Y generator)"
+#define ERROR_VALUE_TOO_LARGE "value too large"
 #define INFO_APPROPRIATE_DECLARER "appropriate declarer"
 #define INFO_MISSING_KEYWORDS "missing or unmatched keyword"
 #define WARNING_EXTENSION "@ is an extension"
