@@ -26,19 +26,19 @@
 #if !defined (__A68G_LIB_H__)
 #define __A68G_LIB_H__
 
-#define A68_INVALID(c)\
+#define A68G_INVALID(c)\
   if (c) {\
     errno = EDOM;\
     return 0;\
   }
 
-#define A68_OVERFLOW(c)\
+#define A68G_OVERFLOW(c)\
   if (c) {\
     errno = ERANGE;\
     return 0;\
   }
 
-#define A68_MAX_FAC 170
+#define A68G_MAX_FAC 170
 
 INT_T a68g_add_int (INT_T, INT_T);
 INT_T a68g_mod_int (INT_T, INT_T);
@@ -87,6 +87,7 @@ REAL_T a68g_ln_beta_real (REAL_T, REAL_T);
 REAL_T a68g_ln_choose_real (INT_T, INT_T);
 REAL_T a68g_ln_fact_real (INT_T);
 REAL_T a68g_ln_real (REAL_T);
+REAL_T a68g_mininf_real (void);
 REAL_T a68g_max_real (REAL_T, REAL_T);
 REAL_T a68g_min_real (REAL_T, REAL_T);
 REAL_T a68g_nan_real (void);
