@@ -28,8 +28,8 @@
 
 // Debugging switch, only useful during development.
 
-#if defined (A68_DEBUG)
-#  undef A68_DEBUG
+#if defined (A68G_DEBUG)
+  #undef A68G_DEBUG
 #endif
 
 #include "a68g-platform.h"
@@ -43,19 +43,19 @@
 // Build switches depending on platform.
 
 #if ((defined (BUILD_LINUX) || defined (BUILD_BSD)) && defined (HAVE_DL))
-#  define BUILD_A68_COMPILER
+  #define BUILD_A68G_COMPILER
 #else
-#  undef BUILD_A68_COMPILER
+  #undef BUILD_A68G_COMPILER
 #endif
 
 #if defined (BUILD_LINUX)
-#  define BUILD_UNIX
+  #define BUILD_UNIX
 #elif defined (BUILD_BSD)
-#  define BUILD_UNIX
+  #define BUILD_UNIX
 #elif defined (BUILD_CYGWIN)
-#  define BUILD_UNIX
+  #define BUILD_UNIX
 #elif defined (BUILD_HAIKU)
-#  define BUILD_UNIX
+  #define BUILD_UNIX
 #endif
 
 // REAL_T should be a REAL*8 for external libs.
@@ -64,7 +64,7 @@ typedef double REAL_T;
 // Compatibility.
 
 #if ! defined (O_BINARY)
-#  define O_BINARY 0x0000
+  #define O_BINARY 0x0000
 #endif
 
 // Forward type definitions.
@@ -76,26 +76,32 @@ typedef unt STATUS_MASK_T, BOOL_T;
 
 #include "a68g-stddef.h"
 
-#define ALIGNED __attribute__((aligned (sizeof (A68_ALIGN_T))))
-#define A68_ALIGN(s) ((int) ((s) % A68_ALIGNMENT) == 0 ? (s) : ((s) - (s) % A68_ALIGNMENT + A68_ALIGNMENT))
-#define A68_ALIGNMENT ((int) (sizeof (A68_ALIGN_T)))
-#define SIZE_ALIGNED(p) ((int) A68_ALIGN (sizeof (p)))
+#define ALIGNED __attribute__((aligned (sizeof (A68G_ALIGN_T))))
+#define A68G_ALIGN(s) ((s) % A68G_ALIGNMENT) == 0 ? (s) : ((s) - (s) % A68G_ALIGNMENT + A68G_ALIGNMENT)
+#define A68G_ALIGNMENT (sizeof (A68G_ALIGN_T))
+#define SIZE_ALIGNED(p) (A68G_ALIGN (sizeof (p)))
 
-#if (A68_LEVEL >= 3)
-#  include "a68g-level-3.h"
+#if (A68G_LEVEL >= 3)
+  #include "a68g-level-3.h"
 #else // Vintage Algol 68 Genie (versions 1 and 2).
-#  include "a68g-generic.h"
+  #include "a68g-generic.h"
 #endif
 
 #define MP_REAL_RADIX ((MP_REAL_T) MP_RADIX)
 
-#if defined (BUILD_WIN32)
-typedef unt __off_t;
-#  if defined (__MSVCRT__) && defined (_environ)
-#    undef _environ
-#  endif
+#if defined (BUILD_LINUX) && defined (__off_t_defined) // See fcntl.h
+  typedef __off_t a68g_off_t;
+#else // Reasonable default
+  typedef ssize_t a68g_off_t;
 #endif
 
+#if defined (BUILD_WIN32) || defined (BUILD_WIN64)
+  #if defined (__MSVCRT__) && defined (_environ)
+    #undef _environ
+  #endif
+#endif
+
+
 #include "a68g-defines.h"
 #include "a68g-stack.h"
 #include "a68g-masks.h"
@@ -126,14 +132,14 @@ char *read_string_from_tty (char *);
 char *standard_environ_proc_name (GPROC);
 int a68g_bufprt (char *, size_t, const char *, ...);
 int a68g_usleep (unsigned);
-int get_row_size (A68_TUPLE *, int);
 int moid_digits (MOID_T *);
-int moid_size (MOID_T *);
+size_t get_row_size (A68G_TUPLE *, int);
+size_t moid_size (MOID_T *);
 unsigned a68g_alarm (unsigned);
 void *a68g_alloc (size_t, const char *, int);
-void *a68g_bufset (void *, int, size_t);
 void a68g_bufcat (char *, char *, size_t);
 void a68g_bufcpy (char *, char *, size_t);
+void *a68g_bufset (void *, int, size_t);
 void a68g_exit (int);
 void a68g_free (void *);
 void a68g_getty (int *, int *);
@@ -141,7 +147,7 @@ void a68g_rm (char *);
 void abend (char *, char *, char *, int);
 void announce_phase (char *);
 void apropos (FILE_T, char *, char *);
-void default_mem_sizes (int);
+void default_mem_sizes (INT_T, LINE_T *, char *);
 void discard_heap (void);
 void free_file_entries (void);
 void free_syntax_tree (NODE_T *);
@@ -156,6 +162,7 @@ void init_tty (void);
 void install_signal_handlers (void);
 void online_help (FILE_T);
 void state_version (FILE_T);
+void storage_limit (size_t);
 
 // Below from R mathlib
 
